(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    561054,       9998]
NotebookOptionsPosition[    554270,       9912]
NotebookOutlinePosition[    554667,       9929]
CellTagsIndexPosition[    554624,       9926]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Determination of the signs and magnitudes of all heteronuclear coupling using \
IPAP-MODO-FESTA data.
Automatically determine optimum ratio when combining IP and AP data, \
adjusting ratio and number of points to shift until rms difference is minimum\
\>", "Subsubsection",
 CellChangeTimes->{{3.835342719267295*^9, 3.8353427673607473`*^9}, {
   3.835342957217922*^9, 3.8353429845994587`*^9}, {3.853579885840021*^9, 
   3.853579910287277*^9}, 
   3.8535799927992496`*^9},ExpressionUUID->"e0dd5b4c-3a91-4051-9a25-\
a39ac98e766a"],

Cell["\<\
Automatically determines the optimum ratio when combining the IP and AP data, \
adjusts the ratio and numbers of points required to shift until the RMS \
difference is at its minimum.
Information required:
shifts={chemical shift in ppm}; (each chemical shift to be separated by a \
comma)
widths={width of multiplet in ppm}; (each width to be separated by a comma)
nreps=1; (number of repetitions of that data - typically 1)
filestart=12; (EXPNO in file)
filenamebase=\[CloseCurlyDoubleQuote]data/folder/nmr/filename/\
\[CloseCurlyDoubleQuote]; (filepath of data)
procnoIP=\[CloseCurlyDoubleQuote]1001\[CloseCurlyDoubleQuote];  (PROCNO of IP \
data)
procnoAP=\[CloseCurlyDoubleQuote]1002\[CloseCurlyDoubleQuote]; (PROCNO of AP \
data - ensure IP and AP are processed with identical parameters)

Sample details: 681 mM Fluorohydrin in DMSO-d6
H excited: 4.23 ppm
F excited: -186.415 ppm 
\
\>", "Text",
 CellChangeTimes->{{3.835344344114542*^9, 3.835344495255948*^9}, {
  3.835345752399667*^9, 3.83534578817225*^9}, {3.835416894520056*^9, 
  3.8354170090033817`*^9}, {3.8535743479833965`*^9, 3.8535743941759214`*^9}, {
  3.8535744245888777`*^9, 3.853574427182979*^9}, {3.8535799150722027`*^9, 
  3.8535802318062067`*^9}, {3.853584046988967*^9, 
  3.8535840819842186`*^9}},ExpressionUUID->"c61c22a2-f7f7-4bd3-b074-\
cb3183ff65e0"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"Context", "[", "]"}], " ", "<>", " ", "\"\<*\>\""}], "]"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"vardiff", "[", 
     RowBox[{"tspip_", ",", "tspap_", ",", 
      RowBox[{"ratio_", "?", "NumericQ"}], ",", 
      RowBox[{"diff_", "?", "NumericQ"}]}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"zspm", ",", "len"}], "}"}], ",", 
      RowBox[{
       RowBox[{"len", "=", 
        RowBox[{"Length", "[", "tspip", "]"}]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"zspm", "=", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "len"}], "}"}]}], "]"}], ",", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"tspip", "-", 
             RowBox[{"ratio", " ", "tspap"}]}], ",", 
            RowBox[{"Table", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "len"}], "}"}]}], "]"}]}], "]"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"Total", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"tspip", "+", 
           RowBox[{"ratio", " ", "tspap"}], "-", 
           RowBox[{"Take", "[", 
            RowBox[{
             RowBox[{"RotateRight", "[", 
              RowBox[{"zspm", ",", "diff"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"len", "+", "1"}], ",", 
               RowBox[{"2", " ", "len"}]}], "}"}]}], "]"}]}], ")"}], "^", 
         "2"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Calculate", " ", "variance", " ", "between", " ", "shifted", " ", 
    "spectra", " ", "obtained", " ", "by", " ", "IPAP", " ", "processing"}], 
   " ", "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"getpars", "[", 
    RowBox[{"filenamebase_", ",", "procno_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "filename", "}"}], ",", 
     RowBox[{
      RowBox[{"filename", "=", 
       RowBox[{
       "filenamebase", "<>", "\"\</pdata/\>\"", "<>", "procno", "<>", 
        "\"\</procs\>\""}]}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"stream", "=", 
       RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"offset", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<OFFSET= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"si", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<SI= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"filename", "=", 
       RowBox[{"filenamebase", "<>", "\"\</acqus\>\""}]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"stream", "=", 
       RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"sfo1", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<SFO1= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"swp", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<SW= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"offset", ",", "si", ",", "sfo1", ",", "swp"}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"process", "[", 
     RowBox[{
     "filenamebaseIP_", ",", "filenamebaseAP_", ",", "shift_", ",", "width_", 
      ",", "swp_", ",", "offset_", ",", "si_", ",", "sfo1_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "diff", ",", "dip", ",", "start", ",", "end", ",", "hzpp", ",", 
        "ncproc", ",", "spip", ",", "spap"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseIP", "<>", "\"\</procs\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"stream", "=", 
        RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ncproc", "=", 
        RowBox[{
         RowBox[{"Read", "[", 
          RowBox[{
           RowBox[{"StringToStream", "[", 
            RowBox[{"Find", "[", 
             RowBox[{"stream", ",", "\"\<NC_proc= \>\""}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Need", " ", "to", " ", "correct", " ", "for", " ", "any", " ", 
         "difference", " ", "in", " ", "scaling", " ", "during", " ", "FT", 
         " ", 
         RowBox[{"etc", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseIP", "<>", "\"\</1r\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"spip", "=", 
        RowBox[{
         RowBox[{"2.", "^", "ncproc"}], " ", 
         RowBox[{
          RowBox[{"Import", "[", 
           RowBox[{"filename", ",", "\"\<Integer32\>\""}], "]"}], "/", 
          RowBox[{"10", "^", "6"}]}]}]}], ";", " ", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseAP", "<>", "\"\</procs\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"stream", "=", 
        RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ncproc", "=", 
        RowBox[{
         RowBox[{"Read", "[", 
          RowBox[{
           RowBox[{"StringToStream", "[", 
            RowBox[{"Find", "[", 
             RowBox[{"stream", ",", "\"\<NC_proc= \>\""}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Need", " ", "to", " ", "correct", " ", "for", " ", "any", " ", 
         "difference", " ", "in", " ", "scaling", " ", "during", " ", "FT", 
         " ", 
         RowBox[{"etc", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseAP", "<>", "\"\</1r\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"spap", "=", 
        RowBox[{
         RowBox[{"2.", "^", "ncproc"}], " ", 
         RowBox[{
          RowBox[{"Import", "[", 
           RowBox[{"filename", ",", "\"\<Integer32\>\""}], "]"}], "/", 
          RowBox[{"10", "^", "6"}]}]}]}], ";", " ", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"hzpp", "=", 
        RowBox[{"swp", " ", 
         RowBox[{"sfo1", "/", 
          RowBox[{"(", 
           RowBox[{"si", "-", "1"}], ")"}]}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"start", "=", 
        RowBox[{"Round", "[", 
         RowBox[{"sfo1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"offset", "-", "shift", "-", 
             RowBox[{"width", "/", "2"}]}], ")"}], "/", "hzpp"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"end", "=", 
        RowBox[{"Round", "[", 
         RowBox[{"sfo1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"offset", "-", "shift", "+", 
             RowBox[{"width", "/", "2"}]}], ")"}], "/", "hzpp"}]}], " ", 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tspip", "=", 
        RowBox[{"Take", "[", 
         RowBox[{"spip", ",", 
          RowBox[{"{", 
           RowBox[{"start", ",", "end"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"len", "=", 
        RowBox[{"Length", "[", "tspip", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tspap", "=", 
        RowBox[{"Take", "[", 
         RowBox[{"spap", ",", 
          RowBox[{"{", 
           RowBox[{"start", ",", "end"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<Chemical shift = \>\"", ",", "\"\<Subsection\>\""}], 
          "]"}], ",", 
         RowBox[{"Style", "[", 
          RowBox[{"shift", ",", "\"\<Subsection\>\""}], "]"}], ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\< ppm\>\"", ",", "\"\<Subsection\>\""}], "]"}]}], "]"}],
        ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{
         "Do", " ", "optimistion", " ", "in", " ", "two", " ", "stages"}], 
         ",", " ", 
         RowBox[{
         "otherwise", " ", "fails", " ", "to", " ", "find", " ", "global", 
          " ", "minimum"}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"res1", "=", 
        RowBox[{"NMinimize", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"vardiff", "[", 
             RowBox[{"tspip", ",", "tspap", ",", "fratio", ",", 
              RowBox[{"5", " ", "fdiff"}]}], "]"}], ",", 
            RowBox[{"fdiff", ">", 
             RowBox[{
              RowBox[{"-", "len"}], "/", "5"}]}], ",", 
            RowBox[{"fdiff", "<", 
             RowBox[{"len", "/", "5"}]}], ",", 
            RowBox[{"fratio", ">", "0.8"}], ",", 
            RowBox[{"fratio", "<", "1.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"fdiff", "\[Element]", " ", "Integers"}], ",", "fratio"}],
            "}"}], ",", 
          RowBox[{"MaxIterations", "\[Rule]", "100"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"res2", "=", 
        RowBox[{"NMinimize", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"vardiff", "[", 
             RowBox[{
             "tspip", ",", "tspap", ",", "fratio", ",", " ", "fdiff"}], "]"}],
             ",", 
            RowBox[{"fratio", ">", "0.6"}], ",", 
            RowBox[{"fratio", "<", "1.3"}], ",", 
            RowBox[{"fdiff", ">", 
             RowBox[{
              RowBox[{"Round", "[", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"5", " ", "fdiff"}], "/.", 
                 RowBox[{"res1", "[", 
                  RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "]"}], "-", 
              RowBox[{"len", "/", "10"}]}]}], ",", 
            RowBox[{"fdiff", "<", 
             RowBox[{"Round", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"len", "/", "10"}], "+", 
                RowBox[{"5", " ", "fdiff"}]}], "/.", 
               RowBox[{"res1", "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"fdiff", "\[Element]", " ", "Integers"}], ",", "fratio"}],
            "}"}], ",", 
          RowBox[{"MaxIterations", "\[Rule]", "1000"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
       "Print", "[", "\"\<Variance and optimised shift and ratio:\>\"", "]"}],
        ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "res2", "]"}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{"ratio", "=", 
        RowBox[{"fratio", "/.", 
         RowBox[{"res2", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"spp", "=", 
        RowBox[{"tspip", "+", 
         RowBox[{"ratio", " ", "tspap"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"spm", "=", 
        RowBox[{"tspip", "-", 
         RowBox[{"ratio", " ", "tspap"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<Input data\>\"", ",", "\"\<Subsection\>\""}], "]"}], 
        "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"ListPlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"spp", ",", "spm"}], "}"}], ",", 
          RowBox[{"Joined", "\[Rule]", "True"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"len", "=", 
        RowBox[{"Length", "[", "spp", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"zspm", "=", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "len"}], "}"}]}], "]"}], ",", 
          RowBox[{"Join", "[", 
           RowBox[{"spm", ",", 
            RowBox[{"Table", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "len"}], "}"}]}], "]"}]}], "]"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"diff", "=", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{
             RowBox[{"2", " ", "len"}], "+", "1"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "\[LessEqual]", 
          RowBox[{"Length", "[", "diff", "]"}]}], ",", 
         RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"diff", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "=", 
           RowBox[{"Total", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"spp", "-", 
               RowBox[{"Take", "[", 
                RowBox[{
                 RowBox[{"RotateRight", "[", 
                  RowBox[{"zspm", ",", 
                   RowBox[{"len", "-", "i"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"len", "+", "1"}], ",", 
                   RowBox[{"2", " ", "len"}]}], "}"}]}], "]"}]}], ")"}], "^", 
             "2"}], "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\n", 
       RowBox[{"Print", "[", 
        RowBox[{"Style", "[", 
         RowBox[{
         "\"\<RMS difference vs displacement in data points\>\"", ",", 
          "\"\<Subsection\>\""}], "]"}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"ListPlot", "[", 
         RowBox[{"diff", ",", 
          RowBox[{"Joined", "\[Rule]", "True"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"min", "=", 
        RowBox[{"Min", "[", "diff", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "\[LessEqual]", 
          RowBox[{"Length", "[", "diff", "]"}]}], ",", 
         RowBox[{"i", "++"}], ",", " ", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"diff", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "\[Equal]", "min"}], ",", 
            RowBox[{"minpoint", "=", "i"}]}], "]"}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"Style", "[", 
         RowBox[{
         "\"\<Expansion of RMS difference vs displacement in data points, \
with parabolic fit\>\"", ",", "\"\<Subsection\>\""}], "]"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"dip", "=", 
        RowBox[{"Take", "[", 
         RowBox[{"diff", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"minpoint", "-", "10"}], ",", 
            RowBox[{"minpoint", "+", "10"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"dipfit", "=", 
        RowBox[{"NonlinearModelFit", "[", 
         RowBox[{"dip", ",", 
          RowBox[{"a", "+", 
           RowBox[{"b", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"x", "-", "x0"}], ")"}], "^", "2"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"a", ",", "b", ",", "x0"}], "}"}], ",", "x"}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"Show", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Plot", "[", 
            RowBox[{
             RowBox[{"dipfit", "[", "x", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", "1", ",", 
               RowBox[{"Length", "[", "dip", "]"}]}], "}"}], ",", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"All", ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", 
                  RowBox[{"1.1", " ", 
                   RowBox[{"Max", "[", "dip", "]"}]}]}], "}"}]}], "}"}]}]}], 
            "]"}], ",", 
           RowBox[{"ListPlot", "[", 
            RowBox[{"dip", ",", 
             RowBox[{"Joined", "\[Rule]", "False"}], ",", 
             RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "}"}], "]"}],
         "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<Interpolated frequency shift with best match is \>\"", ",", 
         RowBox[{
          RowBox[{"-", "hzpp"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"x0", "/.", 
              RowBox[{"dipfit", "[", "\"\<BestFitParameters\>\"", "]"}]}], 
             ")"}], "+", "minpoint", "-", "11", "-", "len"}], ")"}]}], ",", 
         " ", "\"\< Hz\>\""}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"-", "hzpp"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"x0", "/.", 
            RowBox[{"dipfit", "[", "\"\<BestFitParameters\>\"", "]"}]}], 
           ")"}], "+", "minpoint", "-", "11", "-", "len"}], ")"}]}]}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"shifts", "=", 
   RowBox[{"{", 
    RowBox[{
    "4.6938", ",", "4.226", ",", "3.8118", ",", "3.3976", ",", "1.9885", ",", 
     "1.4095"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"widths", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.05", ",", "0.16", ",", "0.065", ",", "0.055", ",", "0.18", ",", 
     "0.10"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"njs", "=", 
   RowBox[{"Length", "[", "shifts", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nreps", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"filestart", "=", "11"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"js", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", "njs", ",", "nreps"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "filenamebase", "=", 
   "\"\<V:/dropbox/Coral/_Projects/_Publications/IPAP FESTA/Fluorohydrin \
data/data/GDP_fluorohydrinDMSO_thais/GDP_fluoridrina_thais/nmr/\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"procnoIP", "=", "\"\<1001\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"procnoAP", "=", "\"\<1002\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"getpars", "[", 
   RowBox[{
    RowBox[{"filenamebase", "<>", 
     RowBox[{"ToString", "[", "filestart", "]"}]}], ",", "procnoIP"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"starttime", "=", 
   RowBox[{"AbsoluteTime", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"jnumber", "=", "1"}], ",", 
    RowBox[{"jnumber", "\[LessEqual]", 
     RowBox[{"Length", "[", "shifts", "]"}]}], ",", 
    RowBox[{"jnumber", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"rep", "=", "1"}], ",", 
       RowBox[{"rep", "\[LessEqual]", "nreps"}], ",", 
       RowBox[{"rep", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"filename", "=", 
         RowBox[{"filenamebase", "<>", 
          RowBox[{"ToString", "[", 
           RowBox[{"filestart", "+", "rep", "-", "1"}], "]"}], "<>", 
          "\"\</pdata/\>\""}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"js", "[", 
          RowBox[{"[", 
           RowBox[{"jnumber", ",", "rep"}], "]"}], "]"}], "=", 
         RowBox[{"process", "[", 
          RowBox[{
           RowBox[{"filename", "<>", "procnoIP"}], ",", 
           RowBox[{"filename", "<>", "procnoAP"}], ",", 
           RowBox[{"shifts", "[", 
            RowBox[{"[", "jnumber", "]"}], "]"}], ",", 
           RowBox[{"widths", "[", 
            RowBox[{"[", "jnumber", "]"}], "]"}], ",", "swp", ",", "offset", 
           ",", "si", ",", "sfo1"}], "]"}]}], ";"}]}], "\[IndentingNewLine]", 
      "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"Style", "[", 
    RowBox[{"\"\<Coupling constants\>\"", ",", "\"\<Subsection\>\""}], "]"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"TableForm", "[", "js", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"jslb1", "=", "js"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"timeused", "=", 
   RowBox[{
    RowBox[{"AbsoluteTime", "[", "]"}], "-", "starttime"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<Time used = \>\"", ",", "timeused", ",", "\"\<seconds\>\""}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"meansdandsdmean", "[", "x_", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Mean", "[", "x", "]"}], ",", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"Variance", "[", "x", "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Length", "[", "x", "]"}], "-", "1"}], ")"}], ")"}]}], 
      "]"}], ",", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"Variance", "[", "x", "]"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Length", "[", "x", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Length", "[", "x", "]"}], "-", "1"}], ")"}]}], ")"}]}], 
      "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"nreps", ">", "1"}], ",", 
    RowBox[{
     RowBox[{"reslb1", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"Length", "[", "shifts", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"reslb1", "=", 
      RowBox[{"Prepend", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"shifts", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"meansdandsdmean", "[", 
              RowBox[{"jslb1", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Length", "[", "shifts", "]"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Shift / ppm\>\"", ",", "\"\<JHF / Hz\>\"", ",", 
          "\"\<std dev / Hz\>\"", ",", "\"\<sd of mean of J / Hz\>\""}], 
         "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"TableForm", "[", "reslb1", "]"}], "]"}], ";"}]}], "]"}], 
  "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.833448292510956*^9, 3.833448473320225*^9}, {
   3.833448567630739*^9, 3.833448597926832*^9}, {3.833448726706624*^9, 
   3.8334488386106873`*^9}, {3.833448894130322*^9, 3.83344899381962*^9}, {
   3.8334490263559*^9, 3.833449034371501*^9}, {3.833449208176523*^9, 
   3.83344924369489*^9}, {3.8334515420085583`*^9, 3.833451676813837*^9}, {
   3.8335325651614*^9, 3.833532637209276*^9}, {3.833532759034121*^9, 
   3.8335330239765873`*^9}, {3.8335330927635307`*^9, 
   3.8335331455943604`*^9}, {3.833533397697961*^9, 3.8335334255106373`*^9}, {
   3.8335334594455547`*^9, 3.833533507765386*^9}, {3.833533539339788*^9, 
   3.833533659575992*^9}, {3.833533697198904*^9, 3.8335337340891523`*^9}, {
   3.833533780205265*^9, 3.833533893496993*^9}, 3.833533985781467*^9, {
   3.8335340192182083`*^9, 3.833534070521394*^9}, {3.833534125296022*^9, 
   3.833534125914562*^9}, 3.833534226165428*^9, {3.833534380477125*^9, 
   3.833534380818433*^9}, {3.8335344656134453`*^9, 3.833534519575261*^9}, {
   3.8335346317293777`*^9, 3.83353463272573*^9}, 3.8335347268726482`*^9, {
   3.8335347781741343`*^9, 3.83353485994346*^9}, {3.833534904539554*^9, 
   3.83353494839614*^9}, {3.833534999551011*^9, 3.833534999698493*^9}, {
   3.833535037301165*^9, 3.833535103927022*^9}, {3.8335351368517733`*^9, 
   3.833535139414091*^9}, {3.8335352378369083`*^9, 3.833535337311174*^9}, {
   3.833535394550235*^9, 3.833535454170685*^9}, {3.8335361679797087`*^9, 
   3.8335362375090513`*^9}, {3.833536274111115*^9, 3.833536278469448*^9}, 
   3.833536449477241*^9, {3.8335364826240788`*^9, 3.8335365448917313`*^9}, {
   3.833538035225528*^9, 3.833538077529106*^9}, {3.8337034631307096`*^9, 
   3.833703463865309*^9}, {3.833703506926898*^9, 3.833703553753542*^9}, {
   3.833703617125688*^9, 3.833703688345792*^9}, {3.833703718670663*^9, 
   3.8337037764894876`*^9}, {3.8337038223632317`*^9, 
   3.8337039123907833`*^9}, {3.83370394998801*^9, 3.833704007351994*^9}, {
   3.833704056375489*^9, 3.833704136756112*^9}, {3.833704176289364*^9, 
   3.833704289758876*^9}, {3.833704391066206*^9, 3.833704429891245*^9}, {
   3.833704972721045*^9, 3.8337049956209497`*^9}, {3.8337050367076*^9, 
   3.833705038457287*^9}, {3.8337053194184847`*^9, 3.833705411458173*^9}, {
   3.8337070792528667`*^9, 3.833707127605337*^9}, {3.835337695095479*^9, 
   3.835337749538929*^9}, {3.835338577798208*^9, 3.835338620041452*^9}, {
   3.835338653990897*^9, 3.835338823765335*^9}, {3.835338865410541*^9, 
   3.835338962622757*^9}, {3.83533899622244*^9, 3.8353390024553337`*^9}, {
   3.835339165977964*^9, 3.835339170838904*^9}, {3.835339226586821*^9, 
   3.835339252159419*^9}, {3.8353394292671547`*^9, 3.835339457784766*^9}, {
   3.835339500275881*^9, 3.8353395120074873`*^9}, 3.8353400097312202`*^9, {
   3.835340043255178*^9, 3.835340049105363*^9}, {3.835340320155546*^9, 
   3.8353403214856653`*^9}, {3.8353429884303017`*^9, 3.835343088575757*^9}, {
   3.835343169936596*^9, 3.83534322437465*^9}, {3.835343746121127*^9, 
   3.8353437642293177`*^9}, {3.8353445222541227`*^9, 3.835344552148288*^9}, {
   3.835344620203895*^9, 3.835344716850436*^9}, {3.835344824168634*^9, 
   3.835344832897682*^9}, {3.835344894608045*^9, 3.835344999609126*^9}, {
   3.8353450692229977`*^9, 3.835345143285017*^9}, {3.835345243601369*^9, 
   3.835345244855967*^9}, 3.8353452928938713`*^9, {3.835345339394802*^9, 
   3.835345341993548*^9}, {3.835345390387436*^9, 3.835345394595192*^9}, 
   3.835345505879159*^9, {3.835345633336461*^9, 3.835345726337473*^9}, {
   3.8353458377226467`*^9, 3.835345843828887*^9}, {3.835372061030136*^9, 
   3.835372071264954*^9}, {3.835372109388467*^9, 3.83537218434414*^9}, 
   3.835372522290762*^9, {3.8354170700934362`*^9, 3.835417083829755*^9}, {
   3.835417167922065*^9, 3.835417196326001*^9}, {3.835418223179352*^9, 
   3.835418229883106*^9}, {3.835418393819128*^9, 3.835418488516716*^9}, {
   3.835418519132303*^9, 3.835418537842663*^9}, {3.83542543494832*^9, 
   3.835425472964828*^9}, 3.8354255498612223`*^9, {3.835425690259713*^9, 
   3.83542571399114*^9}, {3.835431541550761*^9, 3.835431541640277*^9}, {
   3.852979611453643*^9, 3.852979691319852*^9}, {3.8529797654116774`*^9, 
   3.852979781170024*^9}, {3.852979821986277*^9, 3.8529798368790913`*^9}, 
   3.852982940810091*^9, {3.8535786610591493`*^9, 3.853578743107206*^9}, {
   3.8535791499440546`*^9, 3.853579151302937*^9}, 3.8535799422709336`*^9, {
   3.8535838939871745`*^9, 3.8535838969618187`*^9}, {3.8535840894390697`*^9, 
   3.853584130737338*^9}, {3.853584516530961*^9, 3.853584516874854*^9}, {
   3.8535845600040336`*^9, 3.8535845615726595`*^9}, 3.8540967765697684`*^9, {
   3.8540970494140425`*^9, 3.8540970495514555`*^9}, 3.854097911909184*^9, {
   3.854097942268117*^9, 3.8540979670227947`*^9}, {3.854099281627038*^9, 
   3.8540992848367324`*^9}, 3.854099439084408*^9, 3.8541000544287663`*^9, 
   3.867474821673673*^9, 3.867475319116505*^9, {3.8674826497948093`*^9, 
   3.867482695495367*^9}, {3.8674827290966625`*^9, 3.8674827489847865`*^9}, {
   3.867483498723894*^9, 3.867483503881317*^9}},
 CellLabel->
  "In[185]:=",ExpressionUUID->"83ce1c8d-1a22-4fa3-84c9-6c6be868c2d5"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["4.6938`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[4.6938, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.867483511642747*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"547f5675-0e26-4afd-a7ce-051c01557c40"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674835475074387`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"b208e14c-7028-4edf-8a19-9f96457a0889"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.6355279799221689`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", "141"}], ",", 
     RowBox[{"fratio", "\[Rule]", "1.224936596982989`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.867483547517412*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"415d8572-859b-4172-b1f3-3ebfe97aa327"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674835475233955`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"4c69ff9e-0ce3-4a98-a9d3-f8f44c4efaef"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw92nk8VPv/B/CpVNqkUleLGtrUVU3atOmVJO0TskSabJFtbGMwODMjuUUh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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1mXlczNsbx0eWssetZB9rcS1FyBKfKBFd06aiZVq1N+17TTODhCQVUgzp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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 656.}, {-0.0008040066004232627, 2.3780957868514156`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.867483547580245*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"9abd0f1a-6f6e-4ba8-b3fa-d39629795fe1"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.867483547977184*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"e9da16a1-2474-408c-9e08-869236f624ce"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxF3HlcDe/7P/DsSYiULFHWsiZJtryEpEhIkspp1Sanfa/TftrPhiSEkCWy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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1313.}, {0, 1885.6661350760357`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674835481158133`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"a352f2ea-f21e-4b0e-a5f4-2ca0cea56737"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674835481217995`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"bd31e611-ff65-4166-9db8-88f469f5901b"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV13k4VN8fB3BbSCohlWUaM3NnxhqayJLzUcpaUfEtviGiZGuh+lpKSqIs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        "]]},
      Annotation[#, "Charting`Private`Tag$3741689#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7Ps1di+r+ynjABVw0H86h3/FY3Eon8OB0WN7
3MoIYShfwKHGxkkzbxMflC/iMOdXadu0U+xQvoSDXeaMwqk/GKF8GYenL06Z
Pyr9ZQ/hKzgENJ++/F3xM5Sv5FC59G7mrrevoXwVB4WKR8XnPzyF8tUcItbq
HbMLewLlazjM+HK4qEzlOZSv5cCzP3xaVMw7KF/HwVDb6Yr7ny9Qvp5DAkt8
26bvf6B8A4d1j1hMN/YyQ91n6GD0oiOFbxMnlG/kML9GZ0tkiQCUb+zwbslh
H7uZIlC+icPj0MU+/h6SUL6pg5b39H2vG+UcABfhWyU=
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 8.389563442022945}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674835482465105`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"c926965d-67df-445e-926b-1c8b422a0576"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", "5.3842256842107075`", 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", 5.3842256842107075`, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.867483548252511*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"b80e8da1-ddf2-43b5-a8ab-1edb13a9cc11"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["4.226`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[4.226, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674835488039646`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"22129811-4356-49fd-b1d4-5d9f36c619ed"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674836240239153`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"61a9a99c-7626-4209-af3c-53b81cb74ce0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"39.81782795127961`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", "1278"}], ",", 
     RowBox[{"fratio", "\[Rule]", "1.011958226813355`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674836240279055`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"3a3f31f8-cb6b-4d31-be85-c4a4adc9f756"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674836240318933`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"eb67ba2c-e4d4-4824-af40-d82843f7300b"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw8XHlczF+4HoQQDUL27IOQFEV4ooiiEKIwUhTRtJe2aZ/2afZJGArZQ5KQ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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw8XXlYTd3bDlEIoYhCKoQQhcw3iko4KSRpUirNo0rDaT7NZ6pO6eVIiEIS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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 2098.}, {-0.02908086096135515, 3.4326464251276523`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.867483624123648*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"17e53593-dba9-4d7f-85cc-208a18799106"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.867483628210721*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"2c36d894-17fe-4c14-ab92-d8e329f0e1cc"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxM23lcjN/7P/AkVLYQQsgeQpGE8JIkJCG0SdKmkmnfmfZpn6ZpmqmQPd5J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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 4197.}, {0, 2054.233751470772}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674836284101872`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"923b5769-bd81-466d-b3dd-4f0ac81b8546"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674836284291368`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"408dfdc0-60a6-47bc-b7a7-44ce6ae987de"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV13k8VOsfB3CubkSLkspWmJkzYwllkiI+3DMjUtFFosiY7GsohaJIlKUN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        "]]},
      Annotation[#, "Charting`Private`Tag$3813016#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7I91xoU7b0hxgAo4MOVzv0l7kgjlczhEbKuJ
YVgeB+ULODy8GjN1G0sUlC/iwLaWT+vMq1AoX8LBkHEWk3NiEJQv46Am+y/B
7Z4flK/g8OiLv+9mEy8oX8nBI7b5ntF5NyhfxYHh3uTHbVtcoHw1BxEHiWnr
XjhD+RoOeW8+69zKgclrOezimBmRYw/Tr+Mgv0O8izXGE8rXc/hwn/X0tN2+
UL6Bw9aTKZtsVwVC+YYOXMZrDvrwwtxv5JBekrfn6P8IKN/Y4eHC3RJZlbFQ
volD857b59otYOFj6qC2br5A0rtkBwCxplSV
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 182.0590424090475}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.867483628619629*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"dceeed0b-f052-4e08-ba0f-6c4aeca1a009"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", "48.74763411226208`", 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", 48.74763411226208, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674836286405745`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"26f28fd4-f57b-485e-b1fe-1977d94b7d83"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["3.8118`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[3.8118, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674836290764065`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"1b02a878-5e45-4dab-86c5-b7123ad099a7"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674836637721453`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"0c2ee018-bba4-4b5d-8eec-6e0559d9f560"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"19.28348178006048`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", "56"}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.8864294969679133`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674836637761345`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"f94a11d3-edc0-42ba-a1ad-646a84ac6143"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674836637781286`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"bf409200-f7a6-4373-8a50-bc4a6bde87b7"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1m3lcjO33xydEthZriLInSZaI0EcqpVBRCtVEpb1pn/a7mqYpPYy1BZls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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9m3lczdv3/4uQkHMzpXIdU0I3KZQMvcxxK2mW5FSaB6d5rjMPmUKRrqEI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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 853.}, {0, 2.0143150620831065`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.867483663868887*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"1b666216-f749-47e7-a38c-68739c4e152d"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674836645251317`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"fadd77f3-68a0-4a9a-b013-45e1b22d6ee6"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxF3XlcjN/7P/AQkiSKQgghKZIoCa+SJKFoQ5KkEtp30bRP+2zN0jvJHkL2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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1707.}, {0, 519.2415840831613}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674836646740046`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"75078197-9f60-4e2f-99e9-9254bf5ff5cf"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.867483664680987*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"7b3724b1-5999-4fc8-900a-8ebcc5691bea"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV13k4VdsbB3CiRK6UpJA4x9kHEdqbRPGlTCVpUG7KVIbIUIhfSaJQChki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        "]]},
      Annotation[#, "Charting`Private`Tag$3884026#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7N/c+pu2aqu7A1TAwWGzauBMU1con8Phhfov
Y+G3TlC+gMOyrrBpUvcdoHwRh2+xrNovZOygfAmHG44T5hn9toLyZRw0hCo3
RsdaQPkKDi7dKTYf3cygfCUHk8X3dx/aZQLlqzjopV+PvL/LGMpXc1CO53Oe
5AHjazicZVdhiEmB8bUcOFMUFr3ihenXcXi9q9FTxMUUytdz+Hlb2foGizmU
b+CQZx9dn+lrCeUbOpgk/gx1krKB8o0cbAWfzLdOt4fyjR2KjLw/X5juCOWb
OMzJuvZecbszlG/qsO0Vl9lePjcHACk9T9Y=
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 52.16118904242324}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.867483664779722*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"9aa51359-1930-4557-9708-96dd42f901b6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", "2.1242904736905124`", 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", 2.1242904736905124`, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674836647927413`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"ba55854f-027c-40ca-8406-295ec80612e9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["3.3976`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[3.3976, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674836654154205`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"499444eb-ea10-48f0-8642-4d1238e446a1"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.867483696330169*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"714492a3-1063-4618-8139-d47dfeff2280"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3.0915098169871023`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", 
      RowBox[{"-", "2"}]}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.6`"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674836963411393`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"fdd0caad-6996-4d3c-8dc6-4ea855b37e01"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.867483696347123*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"703afbf3-73c4-4e9d-94d6-9b50f3e35faa"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9mnlcjdv3x9NFZSxCxg6KZMqQuhn6iAjhkGbDaZ7r1Gkez5hEA4mIZGyU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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9mnlcjdv3x5OpEJkjcqIyRYOpMvQRUcbTQANxUtHcaR5OwxkzhBtXVKYi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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 722.}, {0, 2.12717537578125}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.867483696406963*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"ed0c0b0d-05fc-47e0-9e2d-cbe170fba44a"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.867483696932559*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"03471da8-c3f3-46a4-b717-cdeb2a0696dc"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxF3HlcjV3XB/DMSQghhBCSEJIy/igJIUmSJEnS5Kg0D6f5NJ8xIQpxZ0oS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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1445.}, {0, 649.1240898193382}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.867483697020325*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"103136f2-cfa7-4c75-bff8-483ab1e8fa9c"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.867483697028305*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"e0476248-9959-44e0-aff4-d580b22d085a"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVl3k01N8fxgnpy8wYTEjCMJ+xZEuTUPEojbVSX0tRiiSSrVQSpZBSRERI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        "]]},
      Annotation[#, "Charting`Private`Tag$3955254#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7PsP+tZp33dzgAo4fFk3X8WawxnK53CQnvz+
k9knOyhfwMFRu/iqQqUFlC/iIJH38ebpnUZQvoSD2TeL1m192lC+jIPFjTrV
p6nKUL6Cg9vJzXfm6EhB+UoOiwXUPR/nCkL5Kg4qX7iiGHdzQvlqDseP76zP
3M0B5Ws4uLcqiwjf54fytRxqPG5q5rSIQ/k6DkuXt57qr1eE8vUcvkh+tJoh
pQnlGzis8FopoWljCOUbOnQ9uXgse48ZlG/k0HnsZ4zYHxso39hh/hPts0c+
O0L5Jg5ay7Vu/NriCuWbOtT7vHB+u83TAQBiGlXk
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 56.572027337331654`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674836971390076`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"250dadad-5e28-4ff5-8179-e4fc2f6c4ded"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "0.06334718652116751`"}], "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", -0.06334718652116751, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674836971540303`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"eee4673b-f3fc-42c5-8a04-1e77152a0707"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["1.9885`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[1.9885, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674836977819147`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"ff9a9a3e-9b26-4bc8-9341-d6432e89f97b"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674837853790264`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"db0d11f5-b219-41d4-a9b6-0bfe49da0339"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"29.184110799143866`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", "735"}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.9693749548147261`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.867483785383016*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"cdee925a-dd82-4c7a-9362-b80438e7c005"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674837853860083`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"f0159633-00eb-431b-9f84-2ab583161fcb"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw0m3tcjFsXxwchpELIPQohhCT3n4QQiiIJIyHdTOl+ne5TTTUzTdNMwrgl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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw8nXtcTN3795MQohAqSRRCCEmSfKQISYhSYUqUSk3no5rO03lmmmrKKYTQ
TYiSJAkhRKEURkJIQgjh2d/HtX/+8Xrbe6+1rvNaa/Zexjt7r90mKyMjM2+g
jMz//v73p2vR2umTl6T0N79M/4DPE5vXL106i1ge524ZBEVPtVv0j5VQ7Xxk
Zs8IH2JlcJf3mac9dhexCs7bJv8a5hBDrI5N0qTlU/3iiDXRx/5ElN/QWOIJ
MGo62xl+PYJYGzsMuLxTVmz7k9Bmd+lz/86VxDo4GaFy/u4RexrfVETz68Of
cV2IdSGetfu3L3cj8Qx0SfwGqo1eQc/rwU/H4OR3eS/iWegKu8DRywkmno2p
px4tqc8LJ54DtfrD7SP/hhDrw+u7ifqetb7Ec1HxKK3jS5YzsQEsTc4sSbtk
QTwPggSHJ44rzYgNkRaMi8O1txDPh1LQXcvsOVxiI8Rtm9fpFxdEvACBAXeD
Zj1k+zeGu5Pgd3lwAPFCnChaMPrlI1diE0hSO9XPnZ1DvAimoo0usnq2pA9A
TtfoQU8EMQ+o7HO3I3wue/9iBPXfXOJ53+0f8xajfyP/1/PPgXTdFLGzp3ye
k0764ZlinWvagEl7w+j6Emyo0Vae/IHGx1uC4Q/+Jhmc8abrZnjxykjiPd6T
rpthjMHlb0en+9F1c0iNzsRuMid/4JnjT3d5699c1n+WQqI2qTfPIomuL0Xp
2Y0bp6sn0/VlmKEV7jevKIGuL0ORnvwM5cgoum6B/Su+GOlxSB6eBZYdHCq4
ZrmTri/H85uzJ188yo5vOUy6PPfu1PWn6ytgV7j5dVc7yctbgb6Kqpm3ZvPo
+kqczDu3Jl6fHf9KbL6v6DlrLWsvS1ifNR4ZYkP+wrNEY0XLhznP9Mg+q/Dd
ZtHOOavXkX1WQW/LjHDljrF03Qr1IVtKVyxyoeetsF61fc41R9Y+qyHz2WdB
yohIur4aG4OGzovayo7PGjnb5zzNGknjhzUChe+46mXkfzxrGL85+U3pF8V7
pTVkmkJ+vkr9aPLv+TUokvtdt7B8Cj2/Bg8afxxfp+hEz6/By70nSnT6k7yV
a5CiIOja7M3qfy08Lti8ebWJ7IO1eFNspWesS/bjrYV7pKHisKAUen4tvNxf
xH5KZe27Dirnz0jumyTS8+uw4vhZnzhxPD2/Dk3iO5G8LMovlevwc+3PH8YK
bL6xwZ72D30sl5I/wQaxT0NvKfxg/cUGx1efqheaUH+VNvA1/JjtcD+Vnl8P
56K//VTC0+j59VDK7vdt0B4aL289pFd+V/hE8On59Zht5Ba2fBubDzfgwrrx
vlxT8g9swMnF7cnjK0Pp+Q0QuIcOyuiifFq5AbI/R1j9jWaft0Xo8RdLY4NY
+W1R7vND1/wKjYdnC/uEkfte3hDQ87ZI+hOLTdHEMnb4fLjJeWoAyQM7vG7b
7VwwmcbLs8OvxsGDckui6Xk7FAdlCdc3s/lwIybte/bJuITyEzbiz4b3K42v
sPG+EepGvf41cuSPlRvRt2pa+KUyNp/Zo8a48tzbeyQv7GF46uifZzWsv9qj
/S8CRWkkbyVz/5oM8bf5ND4ZB6QNvGiQr8GO3wH2w9XLWsJIPp4D5E8s/q9w
rpCed4ARbBJcl7LyO2LCTb52f9a+cMS3lwentS2j/niOsHG7vrlkBcV7pSOe
7qy2D3q2nJ7fhMATw3+83e38Lx6xCZ/k7ixUebyT4nUTdl8sUbKV3fGPKzdB
c5nL1I0bllD8bkbC8LKSb7/cqf/NkG7sm2HXj+KTtxnb0qqMVmez/rMZKXkj
JprvJPvKbMGpDCONxQNJHmwBeLJ+m2aTPnhb4LXsr1TnKcVD5RasbfV2O7Kf
ra8cxD1W+ib1ofqlyUHzXq1XLo/Z8XAwveDQ3M1tlA84HOS/ufg5+BjrnxxM
PKytXdJJ/pHHwc5jb9btTWT740BUXKNct4VYyoFSQMbnHV50v4wTdLkBCWVd
VG81nSAeOMDg/W3Kt3BC4+iMHye7t1L/zPUbl58l9dL4eE6oXPF3+aS/5F95
TjBOam1c9JL0V+mERWVnWw7ZUrxLnSBI/OCja8PGvzMaS8S/nUdQPtJ0xrMT
rvoNj2g8cIZv5MSz0Zdp/sFxxqDwt35LH7D50RkvQ5InrpxA/pznjKyySSN7
VlF7lc44vlQ5c8UhyidSZ/CivSYNKKD8ILMVr3++lqtwTqf+t2JEdZtr2ADW
nluhEeeTPauErnO2wipM61arFzFvKxbe2SqsPUqctxWrTk55v1+WjfetcDza
rzWvgq5Lt6JRu3rmu+Ws/7ig1e1ud+MT8n9NF3y84qN3fTObT1ygPeKXXsZH
Gj/HBQIhf5/+MDY/uKAmZiDyDOj+PBcscTrp09lOXOmCS//NsEhPo/ulLpB9
MCDikCer/234rnFze0Eu5RPNbTBRiNp37TzpF9sgOpXK+X2e6htnG2JnTrkp
82gH9b8NZxf+dB4sS/bK24bSO9+9rQvYfLENOl2mbTqmND+QboP1Icvw3XPY
/L0d9/tFKSffY+XfDoV1f3XMath6tB01UW423m40Xs522Kzqv/HLW2Ledpzw
8jlbW07t523HoLMhL+utRdT/duglWsnuTs6m/rdjVJZzbMz3XOrfFV1z4udr
a+2m/l0hPmA5WL2b7ocrCl+oDk8rpvY4rkhTmJhb0cHOd1zRMu9porsBjSfP
Fe/uS69P/8nma1f47A83OraYjT9XHHh8dMSTSWz9dIOP1en35sHkD5pueLX4
yuI/29l65oae2hW/hzrT/Rw31Jec9w4tYeujG4zHls0Vzaf289wwKK5q5agC
Nl+5ofrHnpquYmpP6oaUc7dC7g7LoP53wORp1RLTr5nU/w6UyzjmTWzJov53
oO174eOXfLrO2YHf2xbJP75E+uDtwAfTbePF/+f/O7D59Kvak2PZ+cIO2DV7
mFwdTSzdAfcdp6xvqNH9Mu7gjNb/tL2E6oOmO+PPx6ftSqfxwR3DWjQVywPF
1L87ohfmbTXfQsxzR/OwUWP2n6D789wx9NOxqmWNrP3dUbin6Of3qcRSdzzw
GmHwUEL9yXig98Q4lboPFK+aHviZsctqsTIb/x74HLJWf14a6Y/jgfxx0+1b
hrD13QN3El/ePHqIld8DiqFr9rbeYOudB8Re99Vr2PFLmf62/fp8oZv0K+MJ
z6W2FwYslVD/nvB1HrzRtpn1P088HIV5OS9Z/XvC69XcVf+B5OV5YqlXoN4r
DeovzxMjUuYsGrSVzT+eCJ2QOCpqAV2XMiynPX6dEmv/nbA8qjfsbDONT3Mn
1H8cTHl7kfrDTkznBeY/82b734lFWlNXrgpl9b8TB+++WT64kdX/Towf0W/d
MB+6XrkTVS4zmtuFJK90J/RO1tk9P59D/XtB7DatZ+r1PdS/F6THXl5fnLuP
+vfCYLurkf0yiDleyL/zsX/rC7qf54UCnfUKWR4Uz3le8OyTMXGYDemz0gv2
HQNMTwSw8e+FFbXj+69ToOsy3ngGUyuPchqPpjfKXfgJeEP5AN643t6hfGoE
2783bkfaP9mnnEf9e+N7qFP/1OkHqH9v7H24YfAw94PUvzdOLhsT6HTqEPXv
DSuj4z+q8vOpfy4+m2uMcaonVuJidfyIHb2v6X5NLopS7WQmd1D7elyoP+v3
5+EtVj9cbLto0/V0GclvzYXfaO+Cl1KSl8OFoaat6kN7kpfLRW1N2KZwc5KP
x8X+cQ5jKibs/8cCLvq5XVtQMJCVh4vGykcPDjkSF3Hx7FHHf91ckr+SC9Wl
PybYHtj7j+u4qLr/bFnXPRqPlIufTf30Lk8m7uJi+IQV2p+9yX4yPmjV6DXY
nkbtKfnAbNLzjiEWrPw+iDCa8/G0x2GS3wf6yzdnPDU7QvL74HZPWajTSbpu
7YPx9SnK+1VInxwfmJ/bV3PMiuzB9UHfpPWd18aQPDwfzG9RCRj/h/oX+GCH
qM03YgDdn+eDMAPDx0mfaDxFPninsG6T7hrqv9IHFw/aGKyqKSD5fSDfXHbO
dOwJkt8HJn//9kme8x/J7wNV/kDZ2q8nSX5fnK8NOmurXUTy+6Je0Pi1MIlY
0xe1ipt/8s8S6/nCInRM07arxPDFZP0R3l9/E1v74mSO7X9OZ0+T/L6w3bUk
Wl7zLMnvi9ClGUFXVp0j+X2x58J/RtsGlJL8vnDy0FLf9aaM5PeFTp8Ll8J3
XSL5fSEWTDFpC75M8vsi3udhy1vnSpLfF/71RZ7nrhNLfaHU71Wf2UOukPy+
4DXv3zbTjljGD91Roianc8RKfjjR5dLwQLWK5PfD69CQOb/difX8EH84rFpG
QAw/zD49ZNiiKGJrP6hrnMx5v4qY44cel9vRTcrEXD+o7Jvj+qqb+uP5QV/p
/rLG38QCP2yY9eqY+lS6P88PAf4JtWEuxEV+GNKc/mxRFnGlH7NisGz1OEdc
54f+aW2fb90iljIcPcZpUwdxlx/UWgrDPGdeJfn9UT1+9G7fXGIlf0i8F2dY
jKsm+f1hUClz2OcAsZ4/7FoUl3j3u0by++OQWYnLYRBb+6PR3eN9OoeY449C
F5M+QbHEXH+oLBiap1ZLzPPH3+i5z4abXSf5/dHicHWh2xPiPH8UNWfeVHe+
QfL7o3TsQuWX+cSV/pj0Nebmt1DiOn+EW5bnn31Kz0v9obtT++L799RfF3P9
wEnHxqckj0wASgd9mLyuk5U/AB9SPLa8XkKsGYDep4YeT1+y9g9A5b5HqRbF
rP0D4Fn24GZhEmv/AFhsEJUJF7H2D4CCWoBGwyWyLzcA06daVz0YwNo/ALtn
1eyYNJv8VRCAzYdiCvqcriD5AzBFtmSaySTW/wNQsj+iua31IskfgKQty/r7
fKV4qQtAjffjpZytxNIA3PZco9s8g7grACmHQlIerCeWCYSp66zhn28TKwVi
T7L3udwAal8zECu+7/VxmFpO8gdiu3RP4p1KYgRidp/ur9PG0fisAxF76X1G
wTJiTiDOxBoM9rUj5gZC1srrahAbz7xATG1a/663iVgQCLnt+hluAaz8gZDx
bZijZEDxXhSI4U5iHdlONv4D0bdVVDrTiI3/QPxNyCly2cLGfyCmuKp9uBNI
3BWIzsqJVe8PEMsEod81x7WN/dn4D4L2S6NTJZXEmkHoSR6tur+BtX8QFKT+
SxX0yH8QBIv0hm7b06z/M/f3vjpRO5f8kROEoM0JQw8eqSH5g/DiQt4wzb83
Sf4gfCtc86Rz+W2SPwiLRj7tKyupJfmD4C+s3evw7Q7JHwSl1U8u3nC9R/IH
Qa36d2qkbx3JHwSX9Y7Gf/Xuk/xBGBO2tdblHXFXEPDMza12zwOSPxgduuZP
Zy+vJ/mD8S5ySojDJ2LNYJwLjHu0PrOB5A/G/ouecxfPfkjyB4PvufC7ylVi
62D0yf0yWmPJI5I/GOEfb2omFxFzg5F9+lu81tDHJH8wDGRWtDY7EwuCgQ+l
xo0lxHnB2JSQdrh8ZCPJH4wRf2aLd0QTVwYj6c6XKzf+EtcFo2oTP3B/chPJ
H4z03mE3lDSfkPzBeKTw9blNMbFMCHbbV6U8WNhM8ofA+ONyk5bTxJohyOqr
orFcvoXkD0Hn5fj9USbECIHwJX/x843E1iEYmpMp7XEl5oRg/qm7v3vCiLkh
WBjOPWh3jJgXghblRQ8v/iYWhKAttkTHK/wpyR8CwcqwbeKxz0j+EHT0Ndly
4D5xZQg+H/DflZ/wnOQPwbJvZ57VqUpJ/hBcHfs2XX4HcVcI8vXM10efJZYJ
hbefw/W7vcRKoRDNStqks+wFyR+KuvXD5KKFxHqhGP3FYkfEY2KEItYi4qfJ
iFaSPxShj9w53xcRc0IR9zku5rYDMTcUeeHn7r11JeaFYpL3quFPthMLQrH0
zu8XA+yJ80Lx5PHFT4NBXBSKkYmj0x8rE1eGoibRxudxPY2nLhQRKw5M/RlK
LA3Fylez898rEHeFIvB6r9FkISt/GK7PyC3cO4yVPwwblnS7/JhO+tQMw8ld
vVPfrSB964VB5uKgfVuCyD4IQ8utK0uUWXtah2Gh3ZRDfg/JfzhhuGf92qKl
h/yNG4bv06c8e6tKzAvDf8N/FT9eSv4qCEPN+5gRU9PIn/PCIDdpeZzTN4qH
ojDEa3KTpoQQV4bB8bVwa60ccV0YPk2yX5MeQ/EmDcPZ1qGGglcUn11h0OxX
W83RIZYJBzgx3gV2FN9K4ZBKAzX6pLLxz/B2fW56C+ULvXBUDvJsbF5PjHCY
2E5+MP0n5RfrcHRlpjtaXybmhEPJL00xMIuYG47AFSu/JfsT88IxW3F4W6Mt
sSAcy8V/LrpZEOeFY1p91ofYdcRF4VD7HRb1Jpa4Mhw2JoNj9F8Q14Xj+JB+
B5e60Pik4Rh2ZnfWkb4kT1c4ahRXHXM8SyyzC3/GD/Fd7c7KvwtlzRbaf7RI
P5q7IK/WvE/jObHeLiYeBq7wyyX9YhdGdAb9GLiW9G+9C93ZHT77/hBzduHM
c3Mjj2yyJ5dpv13Xct5IsjdvF76pPUi64s/afxem1+98rFNCnLcLbZNX91sg
JS7ahQKZ15ktX4grd6G081OKfjdx3S4o7VjddfIFm/92oSl4rSSvnLhrF4p9
Mt/OSSCWiUDdwpljZFn/U4qA7tJiS+EfGq9mBJLyt3RtKibWi0DB6jG3sZ0Y
Eej7111JcyixdQQqFuivLj/Eyh+Bz+KF+vvGE3MjsPX0u0vnE0l/vAgsLXCV
HfSG9CuIwBLxplNyK4nzImBks17R8gbZpygCK4L2nbmznbgyAm5q0i9+U4jr
InBew3jtVTliaQRQfS9q0VvW/hFYPj4tZsAt1v6R6N+9qOn1Qbb+RUJkqFxV
H8L6fyRsLcueazsQ60ViErf1bfRaYkSi9d5An7UuxNaReH1o7+rRycScSPwZ
dUpuYRkxNxLe6V8XPmgj5kVC5emJO3vY8QoiEfFjXeShscR5kQj9o10/1JiV
PxKnlpmNnL2TlT8SutrXfk0qYeWPxGXV3jlWI0h/0khU2yfJV3ix8R+JfolW
2neL2PjnobzetPJjNbE8DzPie+w2HiJW4mHCaR9ngQ2xCg9/9i+fY9pJ/Wny
oCF8H/M1iViHB12V+8e2g50v8MAtFX2/qkJsyMO2b3Wb3YcRg4cKwcakQeOI
LXjY7a8kV6BPbM2Djpae6qPlxHY8RO886m2/iZjDXG+QXeTlR+zGw/q58Vaj
hMRcHu5/OT54I6ufYB7uOr88/UpKzONhrtJNZ7O+JB+fh6668TGXh7P+yEOg
iUZFa39iCQ/+SQsKVj5l7cPDWk2TbYIc4gIexNzu2xmmrL14uLpzxgTpM7J3
KQ8fwu/LdfsQV/Iw9um0tRW/KF/V8ND69WoTQonreAh+0U9uTgflt0YeNui2
7R7G5kMpY7/SmT3hZ2n+186D5hmHRTUjiLt4aLcuT5735e4/7uHB4P70M7/v
0XxSJgotdmMlhZdovikfhS97/Z6NL6X5qFIUBJb5SUUXb5H9o5j5w5KY+Tdp
/qoZhXZpjP6HNzS/1YlCIH9DyictYr0ojLtzxORSEs2HDaMw6rr0ff/JxGCe
d1zxyOAPrdcsonBy/ppTLkp03ToKDb/UOg7YE9tFofjEWqclT9j5dRR6xM8j
UtOpP7coDL+wesXeCBofNwo31OL6WJ+k8QdH4fjZSXPvTSR5eVGYk7B0QuNb
0gc/CjL1kryqnzS/FjDynPoxuGMK6VsShcb7cYp9A8k+eVGoz568+G4z2bMg
Co+W/Hi3Zj35S1EUDv8XkFn4lPJdaRRyE68tn+bLzl+Z/v54Tu0cTvOBmijs
iSx5VVdF84c6pj1BgjonnuYbjVE4X7rx8gsnmp9IGfkGDMr2OEHzl/Yo7CsR
HmwpYuc7UTjYmaDrXk7zpZ4orMhKag65/pLsH42/8r+4vdfayP7R0FcZ57n5
zCuyfzQE5eHmu+Jek/2jcaQxUOad8RuyP3N94JjzX5uIdaJhnZTdEMBpJ/tH
Q8OqQfFsA7FhNHQyhvnbzH9L9o/G2MHz+mqlEVtEY+jHM7HT64itoyE/5Ncg
k1/EdtEo3eDW59fgd2T/aDgOrPK80IfYLRpnRqYoT3hO93MZefRXha85Rhwc
DYXrT7bWbyPmRePkOZuBPirEfKZ9fdXsT1dovIJo8McdHJDIyiOJRpZR9tA3
n0jevGjMkvHJ/xtAXBCNQVfXH53yifRVFI3ew7fFGzyJS6Pxarn8547PpN9K
pv/RcivepBHXROP35nFnqs2I66Ix+KciR2MYcWM0jGaus5n6luwlZfQtWHEO
FcTt0ZCrnr5lYgxxVzQOzXOS+6lH3BONtTdVZK/fZO0fgxFXtUcF2RLLx+Bn
WTbK35C/KMVg6PJBE4LjiVVi0H1oX6jWfGLNGMjeHjh74G/yN50YmN5vTuit
YdcLMTDZyRXtZdcPhjHINTrWf4oVu36IwftBa84d/0X+axGDhldhAvO9xNYx
6Pr19uup+cR2MahZ8UWQd5L8nxMDpcItbh2faH7uFgON6wNuRM8n5sZA/8Hq
ZcZhFD/BMYhb8N3nVSG7/orBNfM/Frm3KN74MYiY8M72fRPFoyAGs8NMoza2
0/xIEgOznPURav3Z+VkMLixp7N+6iOK5IAYPYs7EnM9l5+sxaB240idjBHFp
DMyj9kfHHKR8UBkD26DxamMWEdfEYL3zmBEXX1L+qGP08c6oz69U4sYYOAWc
E/sas/U9BmPyzT9ffE/1pj0Gjjxh8UB2vd4VA13vgWolM4l7GPnGpmRvOcfO
f2JxYXXnm7WTiOVjMXSyiuRkMuU3pVgUWVfMdf1K+U8lFtpPdZ0OsPN3zViM
8g50u6dMrBML99XNEz8/ovqjF4uHrR/3xJ0mNoxFU/VghR2ZxIhFcoHWmqQA
YotYHOg/5cLuVcTWsbCXXRnlr01sF4u71X6C+/LEnFjoldho/hpI7BaLxu+r
rT/MJObGYqmescmXQOLgWNx/uk71Wx0xLxaOIzVvdkyj8fNjMfWTb5lFKLse
icWh/yxuL7zA5v9YCBKmhLd8YtcnsagIW5sm1id9FcSizGOKTpyQuIgZz4Gj
u0XD2Pofi+viXR/K2PVHZSxk5D4/feZN9qmJxbRzpwasXsjaPxa+t10Vd6qS
fzTG4pbSNq+9g8ifpLHwrF8sPTuW/K89FtkenbJfNrPz/VhUPThaPu0B+XNP
LJofNwn1vcj/ZeJw3L/lo58GxYt8HIrC8muX3KL4UopDu4wrJ/IUxZ9KHEQu
hR/lPNn9gTgUxitEBWtSPtCJw2aZC/a6jcR6cTjPWbHnwz7KL4Zx4NpoifPD
KB8hDhyDxSYDd1J+s4jDLaO0R807KF9ax2F04nzXYBfKr3ZxWHNgrdYEa8rH
nDi8Ptqw5uxEyt9ucXg20G7CtVds/o/DI3l7YV421YfgOCyd93b3ZfP3ZP84
qD27JD70g5gfh3fcLrknpR1k/ziUOpS/QewHsn8cZqhd69y+sZPsHwdbp9Gn
3+h/JPvH4WZastW0QV1k/zgouW4euzWMuDQOjZcP6Hz9QFwZh519XP7b4PSJ
7B8H5SlLqqc3ENfFIXfRqGspZp/J/nFIinvQeqmIWBqHCaofezVVvpD9mfG+
7rEPDyPuioOltYO5UwtxD6OvvNlDbi7oJvvHY+/mk6ZCCbF8PKZPO6N0tpNY
KR6GG5o96ud9JfvHw/rdh+xpO4k143HXPc59VBKxTjyO/OQqjU8j1ouHx6X/
srN2ERvGIzeoRE2dQ4x4HLrWu7B+IbFFPLTfdPSfrU5sHQ/3CbeNvvyi8djF
4z/kpgxvIubEw6VuhYm0kNgtHoLqIeZmPsTceDT2OmZf1CIOjodENayx9Drp
gxeP16LCvfc4xPx4pn6ZHh75k/QriMeUmrmruiXEEub+aR3VzYuI8+KRWjHb
9UEH2asgHvfuaxd15RIXMfpb+S32ixlxaTws1/oE57xh7R+P485Ge85EE9fE
Y91/yupxKsR18Wh7m+IzxI78qzEeFkbzVL/tIv+TxsOt+Mk0mYPkn+3xmLRs
362/l8l/u+LhNEr7q3M9+XcPo0/+7oUhTygeZBKA212hAxspXuQT8KVr25YF
Dyi+lBKwzetmwbZ7FH8qCbhz+NgR4QOKT80EROg3mlY1UfzqJMBeZ/O5Cc8p
vvUSMGDhvvsFLWz8J2CN8+mvlnWUH5CA+KyqlYkVlE8sEsC1HZmad5qt/wno
m6Q3oMCD8pFdAgy/m30/VkD1nJMAmekHar9oUD5zS8DKj4Ih66vZ/bYEnNwV
ZHIijvJhcAI45ru1n1tTvuQlIHucffjDsZRP+QlYqsS/X/WJXf8lQO3780Mr
mik/SxLg8el6Tz67n5CXgINzH9cc1WLn/wl4IYmp2xvD5v8EqDxp2z2f3R8r
TcDaowckI4PY/asENF8xnqT5mepRTQJ+POSdKuWy+/kJsIrhDA3tS9yYgD2D
vF0mh9H6RJoA06fD9LRtiNsTEO62+KxHInFXAkx8bvhHdhP3JMA8+p2clR61
J8OHovYNHdk1xPJ8yD0c3HbahliJD95P+1VvzYhV+LjXkL/UZx6xJh8bQioE
qux1HT7slPPHCkLZ+s9H9dRDPqufsvWfD6WjWmPrt5L84GPpu4Mr7WVJXxZ8
fL74/eiRM8TWfGg6lF2tCyb92vER3He3eLcTu/7n44FU//X6MLKXGx+JSrKP
7e6wvzfwsf2rrdKHtWTvYD4aVt3bGtnL7r/xoZ/Rm5N7np3/8SEtDL31w5f8
S8DHqDOi3rYZ5H8SPma6xbyvCCH/zOMjzOq/mZ2u5L8FfLhwffwV3dj9aj7S
BintUgwj/y/lw0p+Qdv13RQflXyEvpwcOPUKO//nw/lv9TW3VoqvOj5Oum+d
fuMnxV8jo7/2lyIMpniV8pF77k3rOFWK53Y+SmbIa26dSvHexcegpFd69xdT
Puhh9ON0x6zakfKFTCLaUpKvXvKjfCKfCKtsmwKPXZRvlBJxuKNUz3I+5SOV
RFQeS/EVFBBrJkLt+Brf1UMpv+kkQs72wUgrL2K9RPQev5V5oJbYMBH9v6bt
kdel/IlE+A4I/vQxhdgiEap1PaXeH4itExGfq5OluYLys10ijIIuDNuyn5iT
iJ7ptgax74jdElH2YPqNC1PZ/J+IM35ybxc5sfk/EdobRy0YJyTmJaIgXhpm
V0HMT4Rw6NUBxR3EgkSYZV6r8dKgeiRh7u9X1q61jjgvETeHqF90SSAuYOSb
XBmx/hxxEfO8s8oH60fEpYkQmAxbqfGKuDIRf1ZF3Wx9TlyTiJSx98zf1BDX
JSL46oa0E4eJGxPxeWPxwuBwYmkirj8t3LZlDXF7IvziTsyT1SbuSkTLh5fC
BR9Jnp5E6LSYZPY/wdb/JHzepGratZqt/0lwG3xx4+4npE+lJOw5dcqhYhWx
ShLTvtfWI6fJPppJ2LDGv2bHMGKdJIwJ9NghH8TaPwnKP/fXGbSTvxgmoc34
6COjbcRIQs2hIUqhDeRvFkkY9UC9ObaN/NE6CWl17+LDuslf7ZJgPWHm3c39
iDlJyCvwfq6nQf7tloTJMhedNi4j/+cmoc9dVZXpcez8LwnPDtiOz29g1/9J
WD29aq2yLrv+T8KC5HDH/ZHs+j8J5Q2SE0NuUPxJklC4ZHTcYFl2/Z+EqvOx
b9MMKV4LkvAo4c+4cUEUz0VJcFmv7HC9huK9NAmKiSWe2bPY+E/Ct4SMtI2F
lB9qkuB4ImqVnS5xXRJ2N/fesD9I+aSR6U+e99xFlliahAfGI7wvs7/XtSeh
N+Ju4b0A9ve+JDy9EapXPY3yV08Shg49ebF8O+U3mWTkLu5JiSui/CefDLdh
nAseo6h+KiVjQvbn07f3Uf5USYZc2+fl31dQvdRkrrvvbdBn1yc6yahuDYvM
7Mf+XpKMZ7pVgsaB7P5vMpqn7d+zdyy7f54MecXxxsMN2fyfDBO5lWfHsfub
1snQL9PefdqLXf8l44wD2v9oUT3jJOOni9WhehHt37klQzN8RrOnKe3vcZOh
tys1+6QJ7WcGJyNk+NM92RG0H8hLhsWd9Ufet9F+IT8Z2vdHljmsIBYk491x
Q5shqbS/KEmG7KFCLf4+2n/MSwbfzcrsRCLtXxYko2mt+n55L3ofoCgZv4JX
fun1pfcFSpORt6jyTWwpvV9SmQyDvkkjXS2Ja5LhMF7nUulk4rpkVHm8OJmp
T9yYjDpZS931dsTSZLi7VEtW7CJuT0ZscurAAAlxF6OPkNQU0+PEPckQPjEs
+XaRff8nBcH9Z79WbCGWT0Fi43uZaWNovEopKKtVHbQlkVglBZpjcvcbzSH5
NFMwlztNS0OD5NdJwaLRiTEzzEk/eil41jl4j2EO6c8wBSVCl+OO/Uj/SMHb
szxD+WCyj0UKOvqFllV1kP2sU2Cc+3qSyIf2r+0Y7gwZ9moYu/5PgeBVUdSv
YeQvbin4b0fzvWpT8iduCo55aPcffYD8LTgFcjH91Yaqk3/yUvDO1U2+m/09
j5+CrBGnSioGkL8LmPZaZheZb2T3f1IwJem+2vtsio+8FBilDQ6610TxU5AC
SF7ixjyKr6IUnJzyp3hcJa2vS1NgWJJT8tyA4rOSGV/9SYXZyhS/NSmoCPES
zH7D/p6dgvTvE6/cOcDGfwqKu7U3TF5E+UGaAr5hR3zbNeL2FPjOdJo+xpzd
/0vBpEVP+m28w+7/pcBG8/UjrR2Un2RS4bjYbJ1IhfKXfCr6fFcsGcTO75VS
0WJ4WHV/Ajv/T4UznOWMZlB+1EzFjH5Gun+qiHVSseHpyv2mlpRP9VKh4fXh
pvQhsWEqs37jNb1wp3yMVPT/FaJwV5HytUUqNhu4Jm2qJLZORZJefrW7D+V3
u1TYa82/8GAkm/9TofBYrCY8ROyWig51q3UJo6h+cFNhHPVm+QNv4uBUFFWs
CY84Q8xLhYo1R6HiOTE/FUara1Tru4kFqfBvvLLp4ntiSSqaNRzs5SvY9T/z
fIRf63g34oJUHFk2ffqY9zSeolSUHw/SNrIkLk3F8QV5v86JSJ7KVIizck/r
XiN5a1LxaY+83+p20k9dKrbvbXq88S/przEV7qsUhhQOYed/qfi8ZPqlMSqk
/3ZGH5bTAqu0yV5dqWjt7zBAfT7ZsycVS0+FDU2wZe2fBk/0nfF8F7v/n4a1
V05m7zpC/qSUBhnDc9m7b7P7v2lQ+Th2RPZ7dv8nDQerSo40DGb3f9MgW7ZV
6mdI/q2XBrXgY1o6faj+GKahKTT7rs8L9v2JNGy7vHrsuzHEFmnQyPc5EVDA
vk+Rhud9h3GtfIjt0jB33a/QqZvY92vSYPrmv74X2Pdv3NLQbBR4VMeJfd8m
DYKS5xN1gomD05Bywf3Ah8Ps/m8avrXJWg9+T8xPQ31Oi6e3MTv/T0PP6Roz
QRyxJA3O4+YklRex7+ekYVrkvFVDTxMXpGEG58DecD4b/2nIFZoFCJcSl6Yh
pOu/RYtliCvTYHUm23HcNeq/Jg1/rvWLOZRNXJcGu52WqzI9iRvT8PrlAlvp
LGJpGrbG9g0ey+af9jSs+BiyV4dD3JWG0bqTPGbVs/t/aZg05YrRgmXs+0/p
mDBIiTOwjvKbfDow+3X640D2fYB0KI3YF33OgFglHcPvP3M3kyHWTIfXw9tV
+6ooX+qkY+F+0Z8of/Z9gXSUfbi68r4KsWE6pIoT1LTLaf4A5nqfy36PPIkt
0qH3w6Dlyyz2fYp0+KqOvVvfj9guHSqKrzxmPWbfL0vHLa3RXqMExG7piEX1
K5lx7PovHaV7n14r30X5PjgdZtuNbJ+eYX//TUfTFPuWojtUH/hMf4PFsiuf
U/0QpMOlvsrUs5vd/01H582DQ8aOYPd/06Gv010WaUz1qCAdstNFljKtVK+K
0rFj6vVZHa40PylNR+HehY0/Vai+Vaaj/9CZfRz6U/2rSUdm3dV8kTHVxzpm
/Ntbf5y5RPORxnQcdS6r/8gjlqZD+cwQtRtBxO3p4GQnjxBnEnelw2/vNVv1
h8Q96bBSfBk2eD61LyOAc96VKcE3iOUE0A6TZPBiaDzyAozSdjgiv4PGqyDA
cIfdx8btJHmUBBjxfr1TRjTJqyzAyePSB8L9ND9TEWCfxa2YlRzSj7oAM49f
XrLmC7t/IECstn/scz7pU1sAK/3VfmfHkv51BHB33uG18TixrgCKN7Y8Hj2R
fR9DAI6hKedLHLG+AOrzb8tdZN/vMBSgxa/77aMeYmMB5EcnJRWOYd8/EODI
nVsr57HvK5gJsF//zPQf7H68hQA2WSfv1/xHbCnA6C+/deW/se8nCDAwxrK1
ryn5l40A0Vy/z5IUYjsBqsK8Gw4/JHYUIGPaiwP8Caz/Mu0Xjz6UHEbsIoC4
Qr7x0hvWnwVIWzih02sH+b+nAPqPwioH/2bfpxFg6kaL8ou5FF/+Auzaqqh5
aj673yWA1+eOZqt64nAB7BeKU667sO+fMfIMcXTz6iSOFeDRoKldVT7sfogA
KQOF++d+JE4RYKjfHbfPLuz7iox8qr+Hf75LLBaANyNf/t1kNl8KcCxilMkG
d+I9AvRri5yoIWTzpwBRGvvj32YT5wtgeezh4X3s73UFAlyo51W7LiAuFMAu
1MNd4Qn1VyRA+pU5inWbiYsZfa18qvKqgcZbytg3U3fk8OXE5QK8rwnw17tO
8lYK0P+N10/FtcTVAoTb1C/b2UH6qhFg40LH2joBce3/xnfG94wR+76VAN+O
Tbb7+Jb03yDABAu3T2aHiRsFqLzy5sn2EOIWAaatbfWUDSCWMv5dH/rpyCHi
NgG+3wrRnTKI2m8XYL65f+bKI8QdTHsDTjgf9GHfZxVA0vam+fE2kq9bgNlV
d22LIkkfPYx/+SbHdVeQ/noFOLPRzGONFtVjGSEMxDMuqNhQvZYTIiUwc5ne
eKrn8kJw5vX+PNdFrCBEVUlewOIy9vdhIRwbtjfPCab5grIQ2NSyL2EKzSdU
hND8c8DZ4j6xuhCRCkpTb/jR/ENTiPJVUs1vw2l+oi2E8cFh+HmCWEcIm7Ft
drx5NJ/RZfrf9NPicyGxnhBKZeXn5QbQ/EdfCJMjEumUZez7BkLERvTaPAog
Nhbi+uajaiP2E0OIhntn3tfVEpsJsSk9ZfbVPuz7CEK4LdtpHjCP2FKIN+sz
r9zgsO8nMOM7u/XSbW9iGyGmOW9dquvIvq8gRFLKhbLvk4gdhXA5u+fz8yb2
9ytmPAd/T7GOJnYRovryqmuPpxK7MePr1rE1fUTyegqhsz7/V0MEMVcI/741
HX3UiP2FyHaxXCbeR/oLFqL+ya6yUYOIw4VwivTpKXQm/fOE+DMrVDeqmOwT
K8TzKY4ToEDMF6IfRvUe9SH7pgjRM2qRocor9n1dIWZu4l31cCIWC9H94+yL
YS/IXyRCPDWW+yDeSrxHiKX7dvMCu9j9UyHm7n7SnJ9JnC9EeG/UhJHOxAVC
HDewfDRsC3GhEAvu8RCTTFzEtPduckJCM3GxEKW2SkU5xtRfKTOegS4zHfcQ
lwuhvSbyUGcncaUQd50TpyvOpvFXC5Fv3bD/jQdxjRD97+ineh8hrhXCOrXq
2qW3xHVC1ORNimuZR/ppEGLFo4FbSpKJG4UQZ4T/0GombhFidmoU/7ga+/6G
EIuNOwumLSZuE+J90JpBncvZ9zmEKEKU/X594g4hDJP7mDzoy67vhGg9JnaT
u0jtdwuh/8fknuom4h5Gnwntw0ve03h7hSjYbOO2iX3/WkYEb9mdNe33SB9y
IpxvXSc/YSIb/yJscD7lZulK+lUQ4c0b/6odM9nfh0U4O9Vylwe7X64sguLc
kK2teZSPVET4E/bpbet1yl/qIoRL3g1S/cTuH4nw02tH0IkpVO+0RVDrqojc
F8C+TyjC9/bz5Usb2PovgpGJwnPBYpov6IngMMBpQZ0/zTf0Ragu0nm1IJrm
K4YiJM1fcCqjguY/xiLMOLLwx8Rl7PtnIrxccivtyjzazzATQdzqPar/XtoP
sRBBoLJtyAEP+v7DUgRL7vKBRVH0fYi1CKXzdFaePUPfk9iIcO7SppGDz9D3
KXYiBFb2N9O+Sd+3OIrgYbLpaEcFfV/DEaHq+TqnibUXKP5FCL04vu9LXfoe
zk0El6D9eS//nKf4FyGvYijvih4xVwTJ25rHh5Poezp/Ed5ts4m8dLuY4l8E
vS+CCQdr6fu7cBEsDBaUzBefofgXYULUdI1z6+h7vVgRDp6JKz66kr7n4zPy
z+nq7bPmFMU/o9/JquPuPKDvBwUi1HSWWzVdIhYz+stcqPI2llgiQvFp/rFD
Z+n7wz3M82GfTz3VKaT4F6Hxzu6HoonHKf6Z51WX9xZNoe8ZC0TgmDhFBJyh
7x0LRag92b0t7zd9b1kkgplC+48/XcTFIqg3z6qdNovuLxWhrePU90N2xOUi
aL/r8ylqJvv9pAjKxWvVPK/R89UiKJmUzp7rRFwjQvBXhd8D1hLXMvpYfUzl
bgVxnQiO847ZJwuovQYRsO8Xr3/sUYp/Efhffl67YEvytIhQdG3oxZU/iaUi
yMWMnDdt7zGKfxEa+mdPrNlH+mhnxms6MMLIlvTVIYKh7afI/S9Jv12MfPiY
pTiA7NctQmFoVm5OEdm3R4TYmBeTE2eQP/SK4DwsKzFrI/mLTAbWzlgXN0Kf
/EkuA5qT15Yve0UsnwEFD4McxYMlFP8Z+NagfK0onfxTKQNdBaMzDxSR/ypn
wN7fPmzsK/qeTCUD7hsUIvX+kL+rM+3N1Nld9Ji+H9PMwD4FickEd4oP7Qxs
tlYfl3qLWIcZX2Z14BMV+h5MNwPbV7Q6+7gS62UgOrD8neQ4sT7zfOfmG+cu
EBtmoLEze/kcZ2LjDOxY+SbpQRS1jwzgfHrDA1Uaj1kGMuYoFGyzpvFbZGDA
VdWBt7aQvJYZsJVKtHLDST/WGfC8ULEj6grp14aRd77tYLVpFG92GaifuNF3
/GGyj2MG1pje42hoUnxxMqBdNnZWzBKKD5cMKJfvmj0nmezvlgHuEFunKHvy
F88MFG9Z7tX0gPyNm4H80s9tiQ3kj/4ZkHsbHPSwL3FwBtTFRx26vtD3w+GM
PkI97750pu+LeRlw+b7XJHIbfX8cmwG96XanTO7T99H8DPACDdq39KPvp1OY
8TyeLO1jQ9+rCzLg5rDq4sN2ui5m9Gkh+e9AX/o+XMLYO+9K4Pp91P6eDPSe
njhyZCr7fXcG/I8denTaljg/A/I6slFGP+h78IIM1MRtmWV6l74XL8yARb/6
Cn1v+r68KAN1psHXUr7Q9//FDE+Zzz3WQucNlDLtmWloHexDXJ4BaYmT9dUG
9nyCDBh+uam1keXqDChtnWE6p424JgMc8dz3bzfR87UZKLKoS1lzn85zqGP8
3ylr8pY9dD5BA6Nf1/GPjkhIP40ZUGm60nFIifTRwsiTmlPq0pfklWaAn2au
tWg92aON0d+GqqXmz4jbGS5wu/XmIXFHBrrHVqxYWUjcxdgrzv+E4l3ibkae
yd535u8ge/cw8aKzIXXCWvoevTcDlsNP+IwaTf4hI4Z9/8fiDfOJ5cSQGzJ9
u9SL7pcXo2HJY4Pi29S+ghjGW+ZO87/Efi8vRvD9oTbXztH398pitMtE3tVZ
SPZSYfiynsTBkfxDXYw6i3uuriJiTTE4E+1Xp94l1hajVONYAqeT9KcjhkXi
tW8nTMneumJoqhQt+PKM9K8nhiC2+1KTFp1Poi9G0YYwT/MxdP6OoRjS5lSx
Rj6dJ2csBq/veJ1bEjo/BmJULq7rFmrReUJmYiBs7lTfEDrvx4Lh7ad4+iPo
fCFLMWQcUnJKjtJ5P9bM9RP9T7T+oPOhbJj2tQvy7VbSeYJ2DF9706akQue7
OTLPV9RFOHjTeWoc5vrxlbH5PXRemgsznuLdot05dB6TG9P+pPwtLz/SeUae
zP2h9SlrlOn8Fy6jT1WTwq188k9/hi/3vS6cQ/4YzOh3+ZrqSDHpL5zRz4eC
524iOo+BxzA6vjd5EMeKoRSrYX02h+7nM/2lbN5kcozOz0hh+PXU2GJVYgHD
T3SipWbEYjGsbYvl/WzoeQkz/sn/7V6ymOy5h7HX+oqD4kbyjzym//0DtDyv
UXzki+GWqeO59R75VwFz/x3VyZP/ULwUMvZP/Oq1o4b8sYiRd8XDCU4TyN+L
xSgY+t5uohZxqRg9E8sTVskSlzPju3LVqlaeuFIM+RGj+k0KJq5m/Jn3ISuX
S/5fw/iPR/4Vmxds/RdDT2ToOCKZ6nudGCqfdBY4jqL63cDYLyR1zpy5lL8b
Gf10iYLeXSFuYfS74HxAWS2xlOl/0pIlvwXEbWIYcuUne21g678YEuezlm8t
iTvE4K+Tdyv0J+5ixvPfzbup+4m7GX3VHJm1iq0fPYz982w295Mn7mXaXxJh
X8qOVyaT6a8r/ncnySOXCZ5DEvfPa6ov8pnA2DAtOwtihUyUaonqVCcTK2Wi
5vfupOXWxMqZaBQ59w2yJ1bJhHQOT2/WA9KfOvN88I11I9j8opkJTemo2Hez
yJ7amQjm3FSqkZI/6GRCJrasI2s9+Y9uJiSlMuqyl+h8Fz1mvJrTitaeIv/X
z0SP65ib8+dT/jZk2v9q9eqolM7HMc6E3eDO/Iez2fN1mPu5Q2ds3UlsxvSv
kH59oDmxBfO87jmdvXr0vGUmitrf35hUQ+cJWTPPz32yWWpN513ZZEJF2V3n
0y06j8kuE1ynhilRd+m8NUdGn3tnz4tMp3zEyQRnn+hpsBmdb+XCyHNTyHmk
sp7in5G/vnXMUwVHiv9MVMa7Rdpcp/zCZfTre/rPzlo6v9Gf6f9irsDoCp1/
FZyJvCdXt4zKp/OZwjMh3+8/rUdX2POrGHkqj06pZs+vjGX681W7PcecziPl
M/29iD2hLud++f9zCjPesYM0/avC/7GA0U/cA9OdvVH/WJwJvVsOz3q9iCWZ
sE755WjRf9c/3pP5v1//VLYKg/5xXiYEIwoGO1YF/uN85nmbjzbcqdR+AdN/
v8x5HRox/7iQ0V/VVJdjJfx/XMTov3PCYM7I1H9cnAl+Rs2E4NXp/7iUue6t
OPLheeJyxt8dE18XhhFXMvopu7Knrpm4OhNKwcfRWiD4xzUMm7aUn90j/Me1
jL4d9Hq2DhX947pM6Oha/gLoegOjHwebtoIqGk8jM/6jQh3ZrPh/3MLoa427
QcEp0oeUaU8uRFu7wOcftzH6t1xhNdmazgtsZ+Qddnxs4zHvf9zBjLdx5y3D
7JB/3MU83/y54a8B6aebGe/v2PwrsxP/cQ/jf/r9EtWMaDy9THshaWpLM9P+
sUwWNO80+zy0oOtyWeBdvVIw5yo9L58FaZOa2Dsx9h8rZKHyt9JsxSlkHyXm
/g9H5x8Vefxj5SzIyN/aoi2eRPHPXPf1udai70Hxz1zXX9BkbUr1UzMLKB2U
G/WYzn/TZu6vVN3+7TvFiw5zf0bAxeRKOg9SlxlPbgX3wkCq73rMdcVVOb66
5M/6DOdtmqV4jOLRMAvcRsv4wW4Uz8ZZEEzrmysaQfkDzHWPcVsuDqJ6ZZYF
vYcLgmofUD20YMbz1uxe1y7KP5aM/HsnfNc+RGydhaLU7soLo2n+YsNcT5rk
sjGd6psdM16flUlJ6yifOTL3K7woPqFG9YyTBU5oh2rwJqo/Llmwjkr5uegc
5Us3ZnyDFkdkybLz/yzGPwefSLegfM5l+numGG0jofWhPzP+A6d1TD/T+jA4
CzWmx0aY59B6I5yx9yCZ1S4ptB7hZaFH4+jYa/q0XozNQkGYRWJ9MjGfac+q
y/fHf8QpWeD/5Q5MbiAWMJx8ePE4E1rviLPQOH/1pWZFWg9JmP4P1BxzXkTr
zT2MfLMvje4S0vopLwsSWJ7sPUPry/wsBL9YYJNhR+utAkb/3xflfNpKXJgF
efHC80s76f4iZvxx909rLyAuzoJhn0uDErKp/dIsuEkej1xoQFyeBR1urdPl
McSVjHydGRwDLeLqLOStG1syXJW4hmn/b+n0cS00/lpGf0cv9c/2Ja7Lgkrx
6RiXAcQNjD26Tequ1pH8jYy82Ry5sZ3ELVkQ6ygKda3pfmkW9tTO3518gbiN
8YeSSZdbG4nbmfstNvkbcYk7GK69lGgfQO11MeOX4yaNViP9d2dBLrvPaqcS
sm9PFnoHX/94O5/s35uFhvO/xtkqEctko/3Hqk2hDbS/I5cNvQuaQ4Y9JZbP
httctaWpacQK2dDRuHtPz5P8SykbEmWfZnsn8j/lbHCVQs9XXaP5hUo2ZJ5m
bUmdTvMLdeZ6+qrK/HHk35rZkKtZ4KbaSP6vnQ2B0qxh4/SJdbLBmVT2wZ1d
3+hmw+Jdufyj+cR62ShvuT26nxHFk342cN+vLKCM1o+G2eAfvp0zsYnWs8bZ
KBhj510TTvEKRn6DIdqSQRTPZtmou2KSrO/Jxn82pDYPhLPGE1sy+ilcPvRj
POULa2a8h8YIZ02j+a9NNqxDWw8d+kXrUbts1Ezd97uKPf/OkWlPyypmXi7N
HzjMeNfoeeU/o/rswjw/pN+u/xZRfnNj9Gf1e8f6Ilp/eDL3T+n7q2A5nYfK
zQav7tmnSzPX/Mu//tnIO3TBY3cQ1ZNg5vrhgbOfbwv7x+HM8798H/l9jPzH
POZ6+dVX7x0i/nEsw02RP8NaqD7zs1H5xf2Ngp4X1X9mPIkvtnv8daD6z7Dk
9+aTRYZU/xkuHmLcL2AmxT/Dnge7ZlQsoPhn2GnckITjphT/DN86YOv9bhXF
P9N//bZOM/4Gin+GlUY5LrtuT/HP3J+fX1vlQdeLGLaTO3DCdzHFP8NaYivH
R6D6zzDvSM7wFWup/jOs6mrb886M6j/D42ZFDIhcR/Gf/b/19hUX9vzrGqZ/
zeXrMl/R+cu1zP2Tf3894U31pi4bmocGWNuX0XmYDQw/sLlj8Z3Ov2xk9Je6
bsydSKpHLYx93r6+v8iQ1qtSpr3Xc1aZ5NL8so3xjznOL9JCyH/amXh53bul
TIP8ryMbXXl/UtMekj93ZSN4lOfj/9u/6Wbis9896y0PKR56mPgcst/ylZTi
pZeJHweD0TWtFF8yEvB1/nB3zmTX/xIEB0cPNXrKzv8lEGjXLdQoovqjIEHR
9oY6RQOqP0oS8IZuDh46gM6bU5Ygr+ZeP5/+xCoS6F3e8H0Hj+5Xl4AzTr7d
XIlYUwJuP+E6rY3E2szzXiXmW4vpeR0JKt1fcKtlKN/oSuB2JCpX3pY9j44Z
z5moPSuiKN/pM+P3ijEINKb6ZMi0Zzy6dGEMsbEE1gvPPksWETPVx849ZZpF
LbGZBO0H5l5viaN8asGMd93ND2ObKd9aMu1vL1EX7mH3/yRobJyuk+1M9clG
AmRrNHHLaT/UTgKZVSLVTvY8LkcJNCvi3fQciTkS6BgP7YztYPf/JSi4Fi3I
CCV2k8Di5DENkS2xpwR19taHHXKJucz4g/4UTFKl9vwlqKlub22OJQ6WoPTk
suUZWcThEqjs+G92rgExj7k+tt/VlXxqL5bhs31CmhpIHj5j/wLbX+0c4hTm
+tX7fx3M2PP6mPHdz+3PsycWM/606JtJ7zpiiQRt7xd0XH9B9XmPBIZzpwxu
aGXrP2PPsU+Ozgqn+pbP6Ed3yo8fQ0jfBRIUX3NY4jeQ7FEogWNYRW5KOdmr
SAJd1Q/psbp0vVgC/WnrPUcPp+dLJQjfoDurq4e4XILy5akp99n6Xcn0/66v
xVVz4mrGntdVbt2PpPtrmPt3akjPulH7tYx9m2YIUuyp/zpGn7axvn5Z5H8N
Esgff/jnyxTiRub5nPsjD3WRv7ZIkKtbeU/2JLFUAjnH0a9H6xG3SdAQvM/a
o478vZ2x93n1/c9a2P1/Jp72jcrv84Jd/zP6DivzOjqT6m030/8j7eSb76ne
9khg3OFnv0aWuFeCFq0+z13Z8ytlctC4IWLthTQ2/nNQWDV9Rv5Ldv8vB+WJ
365IXIkVcqC28rzuGFP2vNAcSC0fTNoeRKycg8pV368bNRCr5KD/mk3fdvwi
Vs/BN91ryQ0Cdv2fA6P2N1bmHmz9z8FU7+mtu4sof+nkwD89IGaEmOq5bg5S
VAoWLXWl/KeXA+XGwgtnIqie6+dAblOiYtFjqueGObDYem+F2h1i4xzYtIRK
1PyIkQN5O0murjrlV7McJE16NcOykvbPLHIwY+ISnbUKlI8tmfZd2+rCFKie
W+eA89Q8UG03rS9sGPn3mYsTn9F1uxz0SOrKTcfSesMxB7z4crn7cjRf4DD9
l/d1KzcndmGuJwYOUp5P97vloHbyzozJxtS+Zw6z3tGywgSqN1xG/7dKxk5b
SOsj/xzkxW+flJdN52EH50BvXFPgKz1a34fnoDT00SndWzS/4OVARajUmXSL
/v+DWKb/quIF23JpPsLPgR3vXPfJS3SedArT38RFxuff0fn+AuZ++1PHZcet
pvhn+PHT7iTPrf/qq4QZb99fN/TkaX24h+FXy65/fUj/30gec3/fgucjltP+
Rz7Do42Sfnyi9WBBDgTXQut2jqLxFOZA6cARDc+XVE+LGPlaLr/5eoG4mNG/
37DfsiD9lDLt7d5k+mQoyVfO6GdKqvl3HnEl096vqxnCU/R8NRMPZ8prRsSx
+/85cJtv/SW6gexRm4PgK2PmTc4kf6nLgebfOcnHmsj/GnJQNPfghEobWv81
MuPRujDUz4uut+SgK/mj6ghF8j9pDrBw++MvRtReGzPei2c3Rh0nbmfar3i3
Yjqfnu9gxp+17aaFB+23d+VA8ujRFMFStv4z46uYVemUztZ/xr9w3stmFVv/
Gd6/f9/JYGKZXPA3Je09BWK5XPCatbxCu+h5+Vy0568bpnyLWCEXNaX3wgLb
iZVyYdf4dcFKA3peORelo6z0N+wiVsmFtVbPzP4JxOq5qFM6MtvIhFgzF9IH
I87IXqH2tJnxxC8Umtix8c+0X+qsbMX+PqTL9O80ar/FZ/Y84lymXrwI69Gg
/KGfi7wZhf6aQsovhrlQaj5raPqI8ptxLgTWLdsfxrHn9+ZCL3owT55LbJYL
rsfghshiut8iFz2PNswZeI7as2TG3zR9ju1b6s+aae/nD0vzAmIbRt4T2mKF
PnS/XS50Tqkr1ZcQOzLteeVObXOl9jm5TD3erzzxIrFLLixGebhr7GbX/7lo
nDsvdZspsScjz7V5Stu0ibm5kISq9596nv39j7Hf4bB+RbMp3wcz9lC//XFo
MNWH8Fx0hY2q0lOkesLLRYFr18jRDlRvYhn9Otyetr2J1nv8XFju53k1TaX6
lJIL+eHj5F5+p+uCXMicLvb00SEWM/0/U7vxfSP7+z8z/orKxU/r2d//mf6/
/UwcKSHOY+wfN93rjxdxPqOvvoOWRykRFzD6FIxV+ruWxluYC47FZE7WUpof
FjHjH5rUcGkG1cNiRp/6m2/HbCZ5S5nx7v9xaPNg4nJGf0eFVyax9bKSscee
vByXROJqRn7xnyDby8Q1jD9M3Hf5OXu9NhfVo70uuDax5y3nIn/XOBm3p6Tv
hlw4LiiwH91B/tSYiwZFA3kTW+KWXPjfLJ4RzNZfKeOvc+KiGvYQtzH6cq4Q
moyh9toZfd08/XW9D3FHLnRXBXet9ybuykXxlcinb9SIuxl9nJilPeE4tdfD
2K90fOLc7cS9uQj/9OrRSNb/ZXZDHPct7o8Cu/+/G8Hh24++vEv8/2q69ria
lrffCQndECW3CglJV12knpJEoVKE0Ekl6YakCJuKJNnoJPba67KloiRKyklC
OiEVkiSJolAUURLeeX/7WX9+PzPzzMxzncuz1siLIN/Kttghil//i8A9zC9F
WIRYRQRWx40/CbwQq4ogTCOwZJk3tlcXQa325WVNX/jzfxEEVTvfXrOBj/8i
sGdij/j18Of/pP+p5rL/8v8b1xVBqmtffo03b/8ioDJSdhov4O1fBPGj0gVy
/vz+XwRdbsEHhx5CbC4ClWyVG583ILYSkf1XbeGUIvSXIIKea569yr14Pmcv
grTY0reiSPTfjiIwN9cybYnC/b4zqe8R97L5Gq4HXERQ2fqTrO/4+E/m71hw
o84O93OeZHxr83KrLiD2EgH8tV1YNB7XB94iKE7ap9aXjfeZviLIPLBOW5KH
9ANEoLuCLXI6gzhIBPWbc8zWWWP9MBFZTwS3ubci/XARuLg7zDzD4P1gJOkv
VtMvpx3jXbQImqM9J95JwHguEIHBSCW7ymt4vxhL2rdl/lxiijietD9r4GB8
A3Ei4W/MjlaBO7YXkvbm1nl7vZF+MhnPWH1qViD2nyqCmvbYawr1yB9KBJ7i
YeHnNuL6iiXtD6p5aNtjfEsj/NrWv+zVJZRHpghyVXXsbH+gvLIJP379tXRQ
I/8/eBFojvnUM3Uc6k++CEp/94ujZREXEnoXpw9+8wfrF4uIP3QTXd7I/x+f
jPdHtaymE3//JwL1fQ7aZ1L5+z/Sf4bcYJthaC+VIrJfCPw0ZTV//0faVzlI
jm5E/a8VgdDnQlc071/qCb0+VV39VsSNIugLtG1+epG//yP6Hb87g5WgP2sV
gaPQz/9QAfq7dqJ/LcdF2++gP+wg5c/GK8czfP4PkeemRaFPjdH/9hD6lo/m
bjiIuI/w5/J/7SuvIB4g8s1cucGKP++ToaDvTW3pxe/8+R8F2Ver8yfIob+X
p6B96ZsXcf38+R8F3uNfGcTkIlYheIrs2JGWiFUpAM+WoxplOD51CgS7F2zb
k4h4AgWeN/eYXeTLNSmQf2k72C0C20+lIGCsekK2FfavS4FJbcIay1uI9SjI
n0Pf0tLG/ZUBKR9RURCzmN//U6Db3CrrbYXYnILUcbUvItUQW1EgPBG+3l0G
MVBQ1mljWDESsT0FHbd3BD5citiRAoNLCmMKRIidKfB9t/nRiSeIXShwmbbz
yLcaxO4Usc9J2/NjEHtSULq7n879juP3Ivywa5AbWMzn/xD+B9/UFDji/H0p
0Lwpmn7DAfkTQOpvvPzzfQbKP4iCCq23v777IQ6jIFe7vfB0MOJwws8Pd6tF
lxFHUsAqJiQoGSG9aAqoE6HXgb8fEJDy5Kz8Py3YfywFa1Yn9W/cwuf/UTDq
kvHtk8V8/KegbvzpW5cKEQspMNcecTvQDnEy4e+qUBvqXz7+E3naJwY7BKE+
U6T/bzMGlfH5fiyZ385Vmmp70H7SKOhS1Lo1/wnaVyYFsctlnOxmY3k2ReLp
nOa9hmhPuRTYp321y+Xvx/OJvIOMAuU/Iy6kIDJ9eO64csTFFFTeWL7k8nM+
/hN9efK5dME+pF9GgeqFpePfz8T+K4g8Aw+PaDHh7Z+CL8HXpxy9xOf/UXD7
kN4Raz5fsJaCmrbQVeqt6D/qKZAsbk9NfYH+pZGCsZd0ay5OQ//TTEH4Zk11
/1e4v22loJjSFFg4YfxpJ+O/Froy+xDGnw4KZETFFgr26D+7CL9WBmyJZnB/
0kPm3xr39OI0LO+jIC1tZ9BpRdxfDlDg+G7oavY0//6LGLwCJfNHBCIeLIZW
568y20XYXl4MYT37T2aeQ/oKpH7jlVYHZcQqYiiL17GsnYRYVQzqLzbsdrmC
WF0MaUUKTkJXpDdBDI0zNZyOb+Xf+xHDQOCzzxV3sf5UMcSHiO/8Dsd4pyuG
rgp4YjAG452eGLxtuq4ZhGD8NBBD6vQX3QcnY7mJGHTfLrKb6YH0zMVQ/+te
pFcu8s+KlKvkRutv5d9XEYPL381vHj3k4z/p/8hexXEZGG8cxdDz9HjmjX0Y
P5zFIFPeYDLEGOXnIoaKiSdUusbx638xWc/llm7bzq//xSB8/KUjyAb1x4vg
vceiJpqjvnmLIVdi/9D2E+qjrxhq0h5azf3J5/8RejRMERhifAgi45/Yedgv
n7//I+PxSvdt/4Dtw8n4O3MNe1YgjhRDu35ySKQLv/4n4/3YHjbuF2IBoRd/
fey+2Ug/Vgx9R5PiLyagvcYT+R+m2OVl6E8SSXmh8clFvH0LiTx2Fz9XO8av
/8VgFTHru/sC9AepYiidft9JmT//osTg/s/sfam8v2TF4Pm8++rmW3ieliaG
cDNJbdcBPG/LFINql83G/lr+/E8MkV0yD7elIM4Vg+a7lzlbnmP7fDHYK/Wm
qjYj/UIxGPw1fY2mLOJiMn/FgkEf43A8pWJIj5qx8+w+xGViSPyad+tbOeIK
MchdtZ4pGYbtK8VwP/zki6NfsbyGjO/lY9em1YhriT4vXyjjnIn8qReDwir/
QSd4/9dI5v/7XrCgno//hJ8qdrrKx/j8HzHE7hjKrs1CebSLYVL05ydrMvn4
T/j1aNrduceR311iWLnf1mWlMfbfQ/RnfO1ht0Q+/ovBekjt3UEK2H5ADAn3
wnoDhHz+Dw0Vajf3TRmH+jmYhk9edQ8vHUF9lqdhRHFUoYU7n/9HA2WTNy/M
FrEKDY7r0t+pXeD3/zQIbAYvGsrnZ6nToCRrNTFqPL//pyHri9zrhnS0L00a
zimnHDepxvOMqTScvNIzcyP/HpouDbHwyP+ND64P9WhwDvpteOEulhvQ0LNz
yye5WLRfExrcG5Iij4uQvjkNdhPfj9nO7xesSP+v51vWvuPX/zR0x/l9+eqN
/teehlecRaRgHZ4vOtLwoXyfh8to7N+ZhgaVH/I/1vH3/zRA5OO62fP5+38a
ZJ29q9a/4u//aUjxOeBzfQzOz4sm66dpbzq/In1vGsJmhoQcXIz1fWnweFE8
x7QQz38CaGjtbbJQXY/+OYgGoe6L7Fl26D/DaJinoNuQW404nAY9ycK2UWfR
30XSoDjkx+h5pTjeaBr8G3Jyekfx7y/R0FUeFuHzDccfS8Pre1tuOe7E+vGk
/7ltNuftkV4iDXmfO17azcf+hDR4GrrcCO9Df51Mg0P9cM+N/P1VKg0+9oLr
Z+chpmiY4/jn5apj6K+Jc9umpq55RBn9eRoNy8bdU+9pxPf5MmlYV9WU9/cT
PJ/LpqH0+TxjtRo838ulYcCi4eKadrxvy6fB6skqiWkR3q8W0rDi44m/g6/g
/qOYhsAhfis/zOHfZ6PB8K+cnbbPsf8yGoLH50ROUMH9VAUN72c8VZtmgPQr
abj/p8veYg7uf2pouB72WPuHCe6Pammw9Emceukn5l/V02AQe0kz7gOOp5HI
40On8Is6/x4bDU3j8znDbv78j4YN8erdjrZ8/Kch6UOK3Q0z/vyPhsjdOSF1
ZqgPXTRM6hq10YvD+fXQYBYautY5GM9L+2igg0uiujLx/nKABqMNOh6F8fz7
qwzM6M72FO3F96QHM6DxYKP/DiWcjzwDqUU6te4FOB8FBpa6yvZPdEX6KgxM
L+HO3ghDeagyENE9zmJcOGJ1Bu6dO5dXNBjxBAbOFcV9/PYPttdkoPnJprhh
+oinMvAppmnRrwTcT+oy4K9gZ/R2F9636jHwLKronrc2jseAgWgbPy39ATzP
NmEg5OKuFPejfP4vA0qBbhnmvxBbMaA168uQS89QfsBAz0PQGzUL6dkzcLzp
2viCP1jfkcxnREjd3UbknzMD8rfS/cIG4fm3CwMG2cUekxPwfWx3BpIPub2x
csJ8PU8yPt9rK02OYT6dFwM51dVNHRX4vrQ3A6HxUdODGOS/LwORt58r2n/m
7/8ZeMLYnO2/ivMPYkDZITXc5xuON4yBp9xBRddO/vyf8CujIrG7HPORIxlg
/dMFfZ7+aP9kPlf/lr8ydB3aPwMm86raHrT4of0zMFbucd0GO5xfPAO5rSPm
OoTheBIZ8G2dc+M5/z6mkIGM66zj+k68z05m4Hdq09Bvqmi/qQx0h5dMtuHf
a6YY0K92sPYKRntiGbh9TFKxThHlncaApPxI1tk4lE8m4Ze/2zOlAOw/mwGL
qNOex28izmXAsnBnqJYN8iOfAeplksKqKKRXyIDZKr9iShb7K2YgrJvW3LcT
zydKGXj39tVQKgLts4zo37GY36I0HH8FA5XuqSkBdxFXMqCz9NAoeI31a0h/
pXltp71wfrWk/pg9/Wc/oL+qZ2D/rrt6g9z5+38GWus87htP498jJeXZr2fL
BSK9VgbyxRkTrvL5AO0MFAxZpfDTF/1TB9G37nijZ/vRf3Ux0CHTuNXpOeIe
BgQRgglcCOI+BsqivX4IkrD9AAM/szSSejP5949ZiPz3QUPdeMSyLBhdbjqR
IYd4MAsrt59c9Jm/f5Jj4WM1G/TdC7E8C+XFR9LNZBAPZ+GNeqKhx0vklwIL
8harFA7swvkqsZBX/rrqzEnef7DwZ2fFu3t6KL9RLAzLCA1ynoHyVWXhRc/l
udV8/vtYFmQ2bI2wWoD6oc7CJuHoGPcNaB8aLMRHHMkTOSH9CSzoUiXfKVvU
10ksHFrjcKVqgPc/LFS8GvEwphb1RZuFb64z4rT598KnspBQ2jb+pD5iHRba
MuaEudvz/omFR5WjR2e+R/ozWSj0bL/UFof6oMfCopgZDhp/oTz1WUgz+X5F
/wTyy4CFf9JcKnwOIjZiwThazlQjDt/3NGFBoO6m0KaF/JvLgpg+6mczEvs3
ZyF1Vobl2ovIH0sWrrV6Vp76jvd9VixEaLRcSkrG95qtWSg77zPf2xLv14CF
BqcWTZOnmG9px0Lw7mszhmggPXsW3ltUhQxSQf/iwMLBgR3hFeeRviMLZxJq
LD9exHiyhIUlXjlfa3zRfziz8Gzy6IbqeMxfWkbkddj2jsUybO/CQr56wWJL
RZS3G+HH5ca1EYrIb3cWnI9ol8+2w/muZOEoS/VFfEd98ST6dHDpF2ESjncN
C5ZVq6dbvMf7Ty8WTGf59CqOxnzr9SxoLhZOaczE7yu8WQj7rj0n9DTW92Eh
07S9MP8kjseXBY/cvjeaC1C+/izMW21suc0Y5RtA9HP5hf2qbxEHsqCxPPf8
P9PQ3oNYeOI6BvKn4XxCWPC5X5qa3o7xJIzoi3qR8JY+8m8bC+713rKjXZFf
4Sx8TZ+3qzcf5RdB6Jc/MngrxvlGEnvIfVF9tA7tYRcLUxMa28xdEUezkGX7
4Gb0BOxvLwtfBAVLTZTx+xYBC7tCsnNWnHKT4gNkPPsjT4ULnW7+D8eyYHty
6NPOluVSfJAF9ax/n/sec8L4wMKeh+2drVaYL5XAQsmtmAWK5dhfIgtCe63E
cAbllcRCrUtHUx6ffy4k+jr6bX/fBBzvCRZyg4cHtv+H8TCZBcPkptv5bvge
eAoL4aoHfmv9547xhcgzQueizlt9KT7Dgsqi7oxV2oYYbwi/Hys6j+pfJMU0
CzbmG7vVd+H4WRaaRY39KaLukv9hCQv6I8MkjwM2SOebxkLHzl/9CvWYT5fO
Qu/+RR/er90lxZksvBPvnZKcifncF1jw9RtI7ubzs7NZGJh1cNYjG3wPPofY
8wzryz6bFTF+Ef80fpqSjQyuB66wsFD7+YPj31Ef8om/8N+1+c1clH8BC1bt
W6J/7Eb7KiT6eWPTsNByXH9cZ2Fi+MJZqQYOGO9YiA58RCutWSbtv4SF3+cm
9qhre0hxKQvtf27oUcPnSfFtIp/JZyZNscPvD8pYMCiabvyaxu+jylmoqTS6
16uN64sKFsbMNrPISUD7uc+C3JZ3Mj6LcLyVLJzSrVkw/S7Ks4oFyatWGcPz
OL8aFm4LKw6YnUR6j4l/WL328oA+6mctC1vzI//8eYXyr2Oh1M1DeZoH5pPX
s5B06mdSrBPqXwOJH0drD4/g7amRhZvVK16GdKK9NJHyxM0PN4/i32Nnwewl
/T4AMP6+YaEzsKPT/Dj631YWtvm5bbtXguXvWHiqEToAdzB+tLMwLsloyj8q
6E8/sPChu8162nDMZ+hgYXDDxko6YomUv5+If1WMHtq22FuKu1gIajzhonTA
WYq/sNC1XEfx4lVvjOeEH6FftxUKcT7fiTwsxorlWtFe+kj71+8fPB6G65t+
4i9XJzYOq8V4McDCqEM/w73von/6zcL4QWZX1f7l3//mIGiiGaPkgliWAyX1
rfLe8dh+MAcaTzKjzn5G+nIclJZUHJo9Eucvz0FCT+3wl/z6ejgHy3ZE/f6l
iv5dgYNREtvJ54xQvkoczB4jX3RmCPpfFQ60hEfO1j5BfR7Fwf7EqiHnL2E8
UuXg7VMtJ6hHfzGWg0muSzc9Por+VZ2DgspbX017cfwaHJwPEgrMYhFP4OBC
+zPT5jwc/yQOBKv8YnfnIT1NDlYUTN6xqRD1Q5uDStl9Uy42o/5O5cDqTueG
kHM4Ph0OPEr+ua57H/VNlwP7W+atwfKbMP5zcK369vBPW/D7Pj0OnpYJVnec
BYz/HOwNFNlt+GaG8Z8Dy3CjvQteYz6rEQcLBXFDa4tR3004oIfD5X3qaD9z
ORjbHXtP0Yjf33BguL5u/4YE9K+WHOgZyXxybUH9sOLAX23LpFkHMX5bc6Af
lV66zg31CTj4a+Mh4c4CnI8dB+blcXYH1mL/9hy4xWov/TkRyx048NyW0BPy
GuXpyMHlsqOzTO/j+JZwMPeXT0xoPNqDM+HP3LirZUaIl3Fw5bxOXEoo1nfh
YMbx+H9jSpG/bhyw1v5jNwajfrhzJN7vmvFfRCjGf6IvVEzWq0r8ftOTgx1N
hT8G5eL3k2s4aF5hytz8azHGfw7qX45JM7uA8Ww90V+TBB2xhY8Ue3MQ57Zk
YsXgACn2IfwwbTn8vMlfin05iPDdqpb/AO3Vn4OBb4OuePS4S3EABy2bPs4+
HIn514EcdJyvnJKrg/nRQYRe9sO+V4lIL4QD36yFqbWnMB6EcZCd3TnCYXqQ
FG/jQP2HrX+x6XopDudAVjhuz9S3SzD+k/5j1m5JH4TxIpKDz30ddefuojx2
cbBpi5ZgHb++ieZgvfNdUc059Cd7OUhObTzzbLSnlL7g/+1xmGZRCca3AxxM
Ph4WeqAmHOM/0b/K04X6Avwe6SAHGY7X9mdZYb5XPAdpTcv/m7wd1ysJHMT6
KbWVbuf3ixxQLVX9IysRJ3FQXOWkpX0L9U/Igbedb6urMdI7wYHaf4ZplFmY
tL9koi9Gw+7/VsP4msKBwZU3nwxvYL56KgfTlb+1pxvh92NniD1Y/zJRW/O3
FFPEH8kMjtx/DvWBJvo4Rbl4iA3qC0v0tSE4bSaF+eUSDkzEarrx01SlOI0D
Gz1B1TF3jJfpHOwr+Vn4/D3mr2USfdtWrBR4UgXjPwc3t3tq+AVifn42B1sV
fvjPOIvrzxwOLi3zm9IZgfqfy8Ea8b1M9wOIrxB6b1pyep3QHvI5iNQ9v+dI
BtpfAQcjjZ9/KZ+L9lBI9MV6V8U8E5T/deK/zQuyFm3C9VcxBw+vfdxr/x/6
hxIOfqcfq9yngfGvlIN15183f9VEfJuDjf2axTR/3lNG5OlU5F/jgvZbzsGu
f73KXLQxPleQ+c7Ib9x/Eud7n4OsZ5o2P4Wob5UcnPI4bZ2zDNcnVcQ+xNbr
hyojP2rIfOfP10odh/72MbGHTvfb3pPRX9VyYDr01rDKXPTPdRxY/DqSOIPH
9ST+/Ox1eqGCuIGDQMGwF35bMX40Ev2vvVlnfgTH38SBaNOYE5QL9tdMxqPM
GrfcR318Q/zZo+s535OQ/60cxETot8fkIn/fcdCatsJkA6C+txP9/eF+vIlD
eh84ODC+9vu64zieDg6q8x9tV1fGePOJg5JUpchVjzB+dnGgmlFS3K6F8ekL
BykBreaBT1AePYTekQs7RDZY/zuRR5b1mguySK+PgypNi+F9NNpXPwenQz5M
On0A5z9A9P/qkPCUY6hfvwl/ahp9TORwPjISSJUMHFVQQH8vK4EnoQGPvRtQ
foMlMGv9vMW7RuH+QE4CQ1cPGbbzLdqTvATCeqc1p5e4YvyXgMpdlVUxBWhP
ChKoyfRqu7oAz7+USPmaQ8lbUzA+qpDyhJSsvNPmGP8l4J3xR8Myw0VqT6oS
WOI8S77PFNfjYyXgOPZFivfAailWJ/UpfQvZ+VMx/kug7Ol5Ye1XPO+aICH+
y23h3XUoz0kSMIyav5N7jetVTdLe5Oi950vRX2pLQFP5cJZwk4UUT5WAvXaa
oGXGDml/OqT8x5e69QfjpFhXAu7zbEIuHkyU4pkSGB1q+io4DL+n1JMAmycf
eHI1fq+qLwE3/xW3BTL4/Y2BBLoyaN9eW/SvRhKQmT53ztKRX63/h03IfP8E
ho6tx+9j5hL+OQtGOj42kNY3l8CiS6p79Np8pdiS8DNCqdgvZrsUW0lArCXr
enJ7pBRbk/L1skZVExGDBE74yslFDUV/byeBLM9xQ+Sd8Xsfewlo9GSZ0HYY
Hx3IfKsiDBfIIXaUwDaHffuftmB+7xIJqPevf9bbg9+rOktA6etm51Av9OfL
JBDUmmZYooPxz0UChSuGfRmrvkmK3SRQ9efm7u0f0X+7S2DZCUonZyHG35US
kIxqmmDuivHbUwIdv+90Jcf7SfEaCSwo7JrAGWC89ZLAda/4VtF5pLee9Fdy
6GlMJOqXtwTOyVeV38kzlfLXRwI/i0zaX17F/aUvkfeNYS5Os3F95i+BB1dP
/R1nvECKAyTw6o7M32P07aT0Aok9WDp9PfMO1wdBEoiYK/DsT8H1R4gEFu5I
ffHJytXm/wDsiYFF
       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 2359.}, {-0.019144627403265453`, 1.40134550052353}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674837854573236`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"2a55708e-4fa3-47b1-b608-82097a274ba1"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.867483790598983*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"744d543d-5a6d-4fef-8ae3-85ff6ca0f908"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxM23tcTF3bB/AQkiSEEIoQQkhC+CEUIQlJkRSlg07SSU3ngw7TzFRzCCHk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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 4719.}, {0, 574.7865046493553}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.867483790713195*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"4be56be8-c6db-489f-98b6-7db7e1a555e3"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.867483790728154*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"82e25108-e87b-4b93-ac0a-57ee4ff8ca48"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV13lYTG8bB/AUouIXUaR9Zs5MizajkDN9q2k1kiVbCZMWLSqKUEmWKClp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        "]]},
      Annotation[#, "Charting`Private`Tag$4026126#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7PUkNnHqKbo5QAUcJO14/6UcdYHyORxchS/c
3NvpDOULOBQULKxyzneC8kUcLleeP/+ozBHKl3BQ+LtuTf5CByhfxiGzqemo
9317KF/BgePm+0KfI3ZQvpLDiqn/cx98soXyVRymV9/n3JYN46s5XNRc+khR
H8bXcIhxOXFOwRbG13Jo+qzzIGkqjK/jcPGsmVa4Ocx8PQfm1w7Zhkow+w0c
+CZe31yiBXOfoUOZlOMS6ecwvpFD/eVPLe7HYP4xdkgO2ZzCdxzmXxMHteWm
SskvYOFh6qCV7zlZStPVAQC+cFJL
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 48.685139210849954`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.867483790824896*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"ac3b5002-851a-4fbe-b66b-fc18a4e89fa3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", "28.025403680282682`", 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", 28.025403680282682`, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.86748379083786*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"7863c4ae-63af-4bea-abc6-789be5d0a912"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["1.4095`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[1.4095, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.86748379142178*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"0cf10cbe-d095-42cc-90b1-eebfef45eab2"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674838419240675`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"8bb3d0bf-01b9-401e-898f-bf49676a751e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5.851451355231861`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", 
      RowBox[{"-", "20"}]}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.6`"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674838419350376`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"3ae718f4-621e-44b7-b501-6258ced6ee25"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674838419420195`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"6ab69e16-41f4-4f0a-83db-32a97db1c395"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9nHdcze///w+KrCQrWSFURJkZ1YNCiDaVtKQ9TnvXaZ12nRHKSBSVWWb2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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9nHlcTN//x8cehSQURShCFEIIL4lCtKtITdqTFtrXqaaaaqpZoigkJISs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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1311.}, {-0.00496546796875, 0.7262408609375}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674838420198107`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"a06906e3-c296-4528-a50a-d598f2141324"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.867483843617588*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"6c5ef827-bc96-4cac-9511-9af0abcfe800"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxM23lcTG/7B/BUCCGEEIokhCKE8KEkhFQqRAstkrTvy7RP+zQzTdOUhBDi
mz0JIZU9hBCyhyR7CL95Xl339Hv+eV7v72nOdT73dZ9zzLnPaDpvtXSRl5OT
m9dTTu5//9/xv9Z5fQ5/7DbOyhn0HzCxae9JHZmVUPFwkGOnVbD5/L0+nVZF
RcO3c2NlVsP7hu8enVZH2O9zPTqtgeQ5Qp62zKNQ3lX33RiZtXD+7aKendbG
8/zqHloy64B7NHTCaJnHY8/qsjOjZNbFyqb4T52ehO/3N1R3/r0elAx1Bnfu
Xx++6L6983imIMd1unJnvqnIGJ7TtXN8DPBuAM+009Nw3lOzsvPvpyPu5/zz
nXlnQMumuaxz/4Y4WSrS7/RMuMnnend6Fsb/SvXr/PxsvHQc9LFz/0bwOFnv
MV7mOTA9rmk/Qea56HN2+cJOz8OgXuovOo8XGHlWeY1s/xyg0cViXuf4zseR
bYZumrLt8yHm9OeNlG1fAEv5rKEycxZgu0JoS+d2Y3ie6MPt/LwxVq/3H9U5
/ia4lhb/S2aOCZRH52/r3L4QrWf7a8j6x1kIpQP91TRk203hdG7L+hGy7aYo
7SopHS7bvgj129wyOrcvgp1nj6rOz5vBwPz+uc76ZpjWKyKvc/wXYy1HUyQb
b85idK25b9E5fktwQTzua+f2Jch50f7/zoelkLSJ1neO71J4vfqX0tlPc3yz
FDZ3ft4cS4YFru3s1zJsaxYtmCTbvgzfo2be1pNtX44dY8OWTpFtX45Zht0g
s9wKLMg4dlz295wVmPX652jZ/uQskJAxbJGsHiwwzsynvvN4LPB6+qXlsuOt
sMDOT3WVneOzEkMuL1GSbcdKiEYuPduZdyXsKv8ky/ZXsRKG+KzfOX6W+FWf
tldmWOLJC11l2XzmWCK/xj5T5gpLmFjfWtU5PlZYF5S0VFf2eSsomljMmCj7
vBU0nI5dkbnCCv3rXC/LLGeNyFC+lsywxl6Nun+y/XOs8TX+0c7O+tZ4WNXD
ufP4V6F185l4WT6sAv6bMq1z/FYh71Pc5s78q/CNZ/6nc37YQCW0+lBnfhvs
fLZ8ZWd+G3DnZj7orG+DlDf9nDvz22JA/x2DO/PbosVpxrDO/LZIy43wkPW7
whZlPY3rJ8s+b4fP3Z7115d93g5FS98dl5ljB8l4hU0yV9hhq86xbp3zbzWC
57450Tl+q6F2KuFt5/Gvxnj/hQad+VdDd+y1sZ3zZw1O2CbqyK6/WAP36aeX
yMxZA86cG7Nlf1+xBhabG6w6z5+16Ltq58PO+bcWymZK6zrn31p4lms/ku2v
Yi3y7owo7by+2ENRszpedn2CPYQa8Tc6r2f2CAs58Up2/aiwhzZ31FmZ5dYh
QL93g8xYB536S5zO68061MxZpyS7HlWsw5F6jvFQ2efX48klxexBss+vh71m
2L3+ss+vh+fJmi99ZZ9fjz4Htu/oI/u8A8wedFeUbYcDxLsSBSqyzzsgOsp/
pWx/FQ6YNN1yzgDZ5x3RbcV/1bLtGo7oJy+U7yfbnyOmdL2RKKvn6IgZvUxn
KMv274iBUVNf92QucMQ3bW7XXrJ6jpjpb7Ra9veNjvBrS/zWW1bfCWZ963Nl
+9dwQui/T2ay7XCChHOwoIesvhOEDxN7KMrqO8G+V1LcH0tW3wnTTWet+8Fc
4QTbB1MrPjM3OsEu+8vyVmY5Z2gsHtf4kVnDGaoLDwhk2+GM4p9l+p+YHZ2h
+3riHtl2jjM+xUW6tsjqO0NlwtmCd7L6zqgvE458LavvjNu7ZjY/k9XfAA3l
Rc+eyOpvkJ6BsVsey+pvwPQrffJldtwAhdPdbZ/K6m+A2pa+2c9l9TdA63Sv
A29k9Tdg0Qt7fVm+xg0Yfn/6rZ+y+hshf9m4qrts/DfiVM6XQjXZ+G9EVnu/
PbLrjeNGZM8utoFs/Ddi9d2Q6bay/m/Eo2GcDz6y/m/Exytn+whk/d+I5LjD
gWdk/XeBp8OOlV9k9V1wYffAPtOsWX0XHJXve5/D7OiCXSP7j7jDzHFB6nj9
/jqrWH0XDB42eUoEc4UL/EZuGnGbudEF29902aBjw+q7onnHn6QYZg1XuH5d
0vacGa6Iq89XWGrL6rvi9IKEjDJmjivk0lVs9exYfVfcdGs+t5+5whWNFm9q
dFaz+q7YOO2maD+znBtOdElx1F/D6rthnlPN3bPMcMPGPQGrrdey+m4oKbIM
/MzMccOctb3rxfasvhtK9ZLqTdex+m6IWuTn3s7c6Iajc26/LlvP6rvjUa/u
EfEOrL47dmq7XnZ0ZPXdcW32pqaVTqy+O1qF27XXObP67kjJK7oWt4HVd0eW
Y3VczUZW3x3Hqw6fGOPK6rtj1v47d8RurP4mBLxPHDByE6u/CZZLVzw86cHq
b4J7j60TXDxZ/U34ePzQ9/FerP4mvA+8mtrbm9XfhJrMFXV9fVn9TTAd0PhJ
35/V34TnA1Z89Q5k9T3wXLX3gepgVt8Dlhsmz9ILY/U9sPGqKGt3BKvvgfsm
vYZpcVh9D+SXCRT3xbD6HjAc7NpPP57V90Co5tepJxNZfQ8U1gnUDZJZ/c2Q
z+jSb3sqq78Z87L3X/uYzupvhuWXB3Eamaz+Zihu8+s1WcDqb0ag012uehar
vxmiiVbdm0Ws/mYsbdTlF4hZ/c3Y/4VfPlvC6nvic3Ww+plcVt8ToqqEW6O2
sfqeQMqgco98Vt8TJyx+nhNsZ/U98dPobFh+AavviS26PjPTdrD6nhj2N8d8
w05W3xP/TE2Xa+1i9beAF/cw9w6zxhZM/71kvn8hq78FSwK6zuixm9Xfgi2a
NSezmDlbILzi5jN8D6u/BTpaMe6FzBVbcK3tXeKkvaz+FgyajS7nmOW8cO/0
3FrbIlbfC+PnfDv5kxle+K7V437hPlbfCwGHXUSr97P6Xihb8yByyAFWX/r3
Y6/z3jBXeKF00+sf1cWsvhfenf1jdO4gq78VuklGVrcOsfpb0fr1zCe5ElZ/
Kw7sc4pdcZjV34qrG6ZuO3OE1d+KI+uv5Cw9xupvxfYfwjc/j7P6W2G6Z/Ld
mpOs/lbYdQ/qWXqK1ffG3DyudtVpsoo3uLkDPrWeYcfjjXB723HTK8h63vB7
kBwtvMCOzxtT9/fQUL5EtvDGz4ty0/Or2fF6o0+teunSK2Rvb/jvL6gZcJ0d
vzc2/fIr+XyTzPOGTz/F0c9vszzeqJg3oPHhXXKJNzwG/3l3r57l88bwqY6j
7jwi13rjw1uTdTefsLzeGOEzS/n6M3KrN45aDhp3/SXL74M5LeN23XjD8vvg
4Q2u2Y13LL8PTBuvutV8YPl9UJ+ywuZ0K8vvg+8eO533fWH5fTApM+iv+DvL
74PSPcdu8X+y/D6YkjFgaX47y++D3gMmNp75x/L7oEzQImiW30D5fXCi7+hZ
I7qRS3xgvirn5oIe5AofGAfcD12qTK71ge1g/olJfcmN0jznBpS/7Udu9cHz
CeU/I1XJcr5olu9R/3kQWcVXese9yzEbQtbwhYeOjRxnGFnPF9zDLQ6i4WT4
4l/b5dDEkWQLX6yb2RRjoUl29IW2YtSHT6PI3r74la7QtlWLzPHFj1eTqm+N
IfN88Uf09L+RY1l+X5z0srB00mH5fWFy84xS3jiW3xdGayf9vTWe5fdF2eWs
YfK6LL8v8gQ7r+pMZPl9MWtOjvP8SSy/H/7N0Lm+aDLL74fnu2xUZumx/H5o
W8vXHqLP8vthkNrgD03M8IPl8S6a/01h+f3AG2Z0zmcqy++HbiP8zKYZsPx+
WOG61eU3M8cPNlXNyy9MY/n94CrxXRA/neX3w3FdF5W5M1h+P/ibFS1/w1zh
B1OFzbMjDVl+P/iU2TopzGT5/SCym302hLnVD0q/Fyq+Ypbzh/EDy3eLZrH8
/uhWcNV4F7OGP5pG89W/M+v5g3towq65s1l+f/i/OLUqjNnCH9rnH1ceYHb0
x9Jx00Jrmb39Yfrn9ZB3zBx/tIhyV7cx8/zx9f79pJ/MBf4Q/6wa/p65xB8G
wsVKV5kr/LHSzGdeDnOtP+RHhgjsmBv9oSUJcujD3OqPp9yuU8+zPHIByM4c
3itIlj8A64If1U2V5Q9Ajr5rXRsbL70ATGhXmH6JGQF4f8cpPZvZIgB3biVn
bGV2DIC+RNRvBbN3AI743Hg/k5kTgHzTqGoDZl4AbGdM3mvMXBCAhFwLxU3M
JQEwyrneZw9zRQAMjBa0/GauDcDzGWrYwo6/MQCLtxy985e5NQBl987/OcHG
Qy4Qivw/+blGLH8g7vXecOO/OSy/dLv33sTPc1n+QOg/rXJzAMsfCO3kvi6f
5rP8gVh5/eXkPcYsfyB22IkdOAtZ/kC8PrJHNXERyx+ILkKF7xcWs/yBePm8
pnqmOcsfiNPW7effLWf5A5E+9sXZ6ytZ/kBEK9j3vGfN8gfi6z75vB+2LH8g
ikJrRumuZfkDYfNqclDAepY/COX1cvENTix/EMK6VQZvcWH5g9D/8S/tqZtY
/iDsL1V7P3ULyx+EMfpqsT4+LH8QjjTfe/g+gOUPgvFjo0G7Q1n+IJg9rgot
jGL5g2DR3Dv2exzLH4QBp12f70tm+YOg1Nul7AqP5Q9Cz3sxk9Zns/xBaH3Q
M9gxn+UPQsCfzYFVu1n+IOwd4fM++iDLH4Sbgw8aJhxn+YNR2rX7lqtnWP5g
DPywYu/yKpY/GCGlSmtUbrL8wSjZvKypXz3LHwzxf5P+WT1j+YNh7fly0r13
LH8w8t0WGWZ/ZfmDseZd8U/hX5Y/GK6FEbOvKm2k/MHgz9aX6A8gFwTjTc2Y
G6eGk0uCYai4+NUKHXJFME40PJnzeAq5NhgZjXaBy+aQG4OR+t5PVbCI3BqM
gC6fQvatJMuF4N6GnX0Fa8kqIXBw+Bdn7ULWCMHIHZd8PnqR9ULAC5v+aX0w
GSGYuafpaXY02SIErpZDeKnJZMcQqEaGPNQXkL1DsPL0cnFMLpkTguDP9mFR
u1j+EMR3d1o14QDLHwKN/uKm+CMsfwieLxtqwj3F8oegPrhGbUwFyx8CRfk3
4cuqWP4QVNUd7tZ2leUPwS/DIWnat1j+UOj0+xf65i7LHwruq4/9LB+y/KHY
yxvtFfWE5Q9FtFfTtNjnLH8oOMe7HnZ9zfKH4tac6WN13rH8oSgrHdt49gPL
H4rXtp8URn1i+UPR4D3/9/KvLH8o7G21dMx/sPyhkPs16an2L5Y/FNC6/P5D
O8sfCu1tFTjwj+UPBf/EN56DvAvlD4XTg60Xu3Qlt4ai5+Ype2O6k+XCoJf6
wfROD7JKGHzkL91/14usEYaP6yrSL/cm64Whn151VFBfMsLgqHB8n1w/skUY
itZtXu7dn+wYhpjTkSnXB5C9wzC+dY/t0IFkThgOb3n3w3oQmReGh3JZP0IH
kwvCcL44bFiqGrkkDPzQ0i6pQ8gVYdi/aeKP6KHk2jB8f6HvFTSM5Q/D3MJL
bQHqLH8Y5uv/KIwfzvKHQ1wyZ2HxCJY/HOOXjT3yYSTLH46hoV1zzTVZ/nDI
95w99+ooll/6+YzHUZu1WP5wHPOwMpqkzfKHI7po+pT+Oix/OJ5mx8wYMJ7l
D8cd129bxuuy/OFonnD65IpJLH84ipwm/AzTY/nD0afXlckHprD84dh0KN/7
sQHLHw4Xue9ug2aw/OGY0rRJsnYmyx+Obn+8hx+ZzfJHIPSp+Kj6XJY/AsIY
vnYuWP4IpP7rZzzBmOWPgLzD075XF7L8ESh1cdcOM2P5IzCXO7l13lKWPwJl
A3v01lzO8keg4YXmV+2VLH8ELHer77O1ZvkjkC7q+vGoLcsfgW2r+gVNX8vy
R6D4/X/X7q5n+SOgPOr6Kq4zyx8BOZOL4WauLH8Een71bBnkwfJHwPHyiQc/
t7D8kejNUcr56cPyRyL1iPM69UCWPxLFb0x+O4ey/JGwlt+/pyaS5Y9EF9vq
4aaxLH8kTH/ffn0vkeWPhFGl4FtEKssfifm986cuymT5I7HUYN4jExHLH4n9
2+w8k3JZ/kicnpAQprGD5Y+Er0Lz+h57Wf5I6M8e5Dj9IMsfiaPPrRZlHmX5
pcej2H+DQhnLL83XnG4cUcHyR2H0H438X1UsfxQ+udz7yLnO8kfB+vq8HkPr
WP4onFGRt7z+kOWPQtOUsluSZyx/FL4KVv4NaWL5o7BsC8/V/iPLHwWvihiX
Kd9Z/iiMu3psysd2lj8KPc4NXpus4Er5o2B5pHTL3x7kkijklU1cYqpCroiC
8O4x9bWDyLVR6Ovq4mWgTm6MgvfI9zOvaJJbo3DgUZJw8FiyHAc31o3pra5L
VuLgwP5B+x/qkVU4mOPx/YXNNLIaB1v/4xtlziRrcNDqr+ARP4esw4GW6/KF
E+aT9TgYrXBJPdSEbMiBaGdwtuciMjgo2R74SX4J2YyDTadtly4wJ1twIA7Z
HaS/nGzHwVD3ayPuriA7cjDN+Chn4kqyOweOVuPNZ1iSvTnIOGex+CNzMAfJ
vNIHNlZkDgffLlYeCWTmcvBM7ofOemYeB/+qeRjJLObgkfVS18tsfwUcDBHZ
+rkwF3Gwyqliwjd2PCUcqC6PrwxkLuXghIb85XcWrH8cvPG3NVjNXMNBjMTz
/m2Wr5YDFYVxCl7M9Rwsd/hTPo+5kQOekW6ENXMTB2vnbOlfzNzKgeajIaaz
2f7bOLgSumvIF2a5aKSPWah3hR2fUjRaHy72vcjyqETDbWw/5xaWXy0ajRcz
GxxXsf5HY+ZiRZWJtqz/0YDHRH271az/0SirlsTdW8v6H40TcjeRsZ71Pxo3
dDSfuDqx/kdjsOXhoiUbWf+j8SNhtHCGG+t/NF4bL+k304P1Pxp9d9e9ctzC
+h+NqtqLBuXerP/RECn7fVziz/ofjZ8KN6/+CWL9j8bthgN1p8NY/6Nxt2rT
ac8o1v9oTGkRBMvHsv5HIy3Myy4igfU/GnkPr9U2JbH+R2PhVpVxVmms/9HY
+ad2aiWP9T8aVpcupc8Qsv5L9z8redy2bNb/aDgW7Sh5KmH9j0bXIr/VH7ax
/kdjFO/6prMFrP/RsB3zxc9mF+t/NCYu81pesZv1X9rPA+ZLuhex/kejIiOg
j/5+1v8YCE2ePJ5VzPofg5J72WbDDrH+x+C6fp1c9X+s/zEI+v3gw7TDrP8x
2HixS4nLEdb/GGhNvsmxO8r6H4MnX63C+x1j/Y9B/gKTEh4zpPU+Dlp8i9ks
BpL9C+WuMlvEoOe73sMDme1iYKo55PlNtn/HGDQbDu/3mNV3j4G379VV+9jx
ecegn3Z6H5MS1v8Y5DaN6l7O8nGk+/+i+WHYQdZ/6fHPXnzG/QDrfwwu73MP
3LmP9T8Ghr2yHKr2sv7HwO3viZxbbLyLYmD2peLhBdaPkhi0+q5rlexg/Y+B
taKrj/121v8YhMzsZdmL9bcmBtf8el0olvU/BiMmZI5bJGb9l453smv5syzW
/xiMC3xhEitg/Y+B4riJbnqZrP8x4Dn8XfwunfU/Bmt+Pb90KJX1PxbfY57v
DU1m/Y+F4++NHsu4rP+xWFthUqrL5rtaLP7+dq0bE8f6H4v+O4wvLY1h/Y/F
JbNg/yMc1v9YXD/9cJE7O58MY7GuuOasdyTrfyxm/t5z70IE638s1DN5J8yZ
LWIR6d815Hc4638s3so7e1xkdozF/uVNBwuZ3WPx03Ce6X5mb+nxavo7vWQO
jsXAcsVLjmz/nFi03vhzVYsdDzcWH7b2ujxBdv7HYuNNXPVgecSxyOo6SK0+
mvU/FpwvKwW+7PpQFIu6kE9mC+NZ/2Nx78ceG5dE1v9Y3N9+esB7dr2oiMXe
Ni3zt6wfNbHwGRu60pVdL2pjEX4mYu4adr2oj8XdVd13H2XzoVF6vLVN6Y5s
/jRJ630znG+7k/U/FvVOc1ZJ2Hxti8VyXQ3z6Wy+y8VhbPAX+VnsfFKKQ+6A
V6cOnmL9j8NduT7fUitY/+Ok3x9maFZVs/7HoZ9HbRfcZP2Pw5v+tU3P7rH+
x2FhpMEWyRPW/zj8/Ps21ek1638cTOPLPkxrYf2PQ8iTnhGDv7P+xyH8ifFB
+b+s/9Lj3RdZ1tLVrcOOcdD5YWt9szfZPQ7CsbfbsweSvePwfvSn9LnDycFx
iNrUc9JpLTInDkWhQy901SVz48Dd2etl/6lkXhwae88tuD2TLI7DqPBKlykg
F8Th7/A3AZqm5KI4GCqeC8taSi6JwyzjfadTLcilcRjDSS1QXkWukB6PYNHW
4avJNdLx81+y9ZI9uTYO07g/h3RzJNfH4ZTOh6MNzuTGOHCi7u9a6EJuisMP
7yBNuJFb49DSfk98053cFgeNC21xPzeR5eLRIN6zv8KDrBSPMq7LKo3NZJV4
eCckHejJrBaPuOcTWzazv9eIh7rOgFp9tj+dePxTm+NjxerrxYNvkP367kay
YTz0DZWGXnUiIx6XwjUvLV1PNouH8UGdVVvXkC3i4fLF56+JDdkuHhY3IrfX
rmT9j0fBePkC5WWs//EY9HpX7cdFrP/xWHDuzCr/Baz/8XAXDzPOM2L9j8fV
tB4avtNZ/+MxXSP2Zlc91v94JBYtqXUbx/ofj7TSGOXdo1j/41FlWfaschjr
fzzy9lj8uKzK+h+P0HkxY46z+VkaD7dpG85yu7H+x0Mr+JVoyT92/kv3p9sw
SLGNnf/xCNfP2lPRys5/af0bN8JT3rLzPx5Xpm78ueU5O//j0XWBvsPWR+z8
j8fzvA/tWXXs/I9HyLWn3d9eZ+d/AjZMqO3uy85npQQoOvg8NjrPzv8EXE+Z
29XmNDv/E6Tflz/kVx9n538Cuul/LhKx+6tOAkZUHxx5gd0/9RKw4FvPaybs
+mOYAMmz5W1q7P6IBPhU6GoYsfuhWQIGDnM+U5LLzv8EXFDYuTKCXe/sEqAx
zWTYPnb/c0yA/UHX9hns/ueeAIcZBqKx7P7nnQAjbp7K1gx2/U/AtlNp2V3Y
/ZCTgGX7WjVvs+svNwENumPS7qWw638C4o/ZH1RiFiegeOEpDRd2vyyQ1rc5
eqPz338JsH7FyUxnLknAuJf/LJczlyagbFt5+3DZ9T8BUdUv476w+21NAnqk
uVyrYq5NwODGGgM+c30ChjQ9FqxkbkzA/J3CXnLMTdK8FkXvs9j9pjUBUweO
utmduS0B10yuJCxi93O5RExfYbnZlN2vlBLRb/VMhTZ2P1NJBHe75RMrdn9X
S4Rx2GdFG3Y/1EiEzk3Lv3/Y/VQnERNdff+as39P6yWCr/h1sEkw638iPp49
O/cF+/c4EnGg5TlnnA/rfyJKf+lYDGL/nrdIxIvEUYsPuLP+S/1vxPEPG1j/
E2GSrzjoDfs+4Z6IwNarawvZ9w/vRDz+8ej5VGvW/0RMsPN8uJN9n+Qk4p24
6NsvM9b/RPT5JJ4035j1PxFD9z/+EsC+34oT8dlDP000g/U/Ee0Gh1S367P+
J2LW6iNzUiew/idCe0imuf0Y1v9ErLu1U67vSNb/RGiJ2ncWqrH+J6Jlz7br
6v1Z/6XHs750b0Av1v9ErLeP1yxWZP1PRED8oWln/tDzgybp8V5emL+XPV9o
TUSPRcqDt7DnD23S42np4dqfPZ+Q48L+24HWbY1kJS42F6mvH/iAPQ/hYo/L
HuuwW2Q1Lvg5ZltvXGbPR7hIVmpT6HmBrMPFmVZOoA573qLHxbm9cX20j5AN
ufg7doKcwn72/IQLF/G00xfZ8x0zLvobCPy25rDnKVwcDFtypjd7XmTHxV3u
3+hCLnu+woXc9agVMzhkdy7MrxtOrQliz1u40Jm2I3T1VnIwF54PLGZ+ZM/H
OFzED9mdl8Gep3G5ePrA8+J8G/Y8houHe8/u6sWe34m5UOP4K7ey538FXMTG
Jl/4MIdcxMWRoTw9uenseRUX3Cv3N2iy55mlXERXOUaYs+ejFVzMrHTPiGLP
X2u4iFo/b0Y5ex5cKx2PlTdbu7HnzfVcpH67VebCnl83cvE17mr1E/b8u4mL
RRERRUFt7Hk/F0HJOc0G7Hl7Gxfhf3u1D2HP5+WSME/Xuk3nBVkpCbv5O/Y6
N7D1gCQ81ozNrmLrA2pJEH07c9DqJlsfSILXDovpPS6TdZJw41vN5KYLbL0g
CfeyL5p/LScbJmFmsKGKwUm2fpCEKxd+HvzvMNksCWeUTjz2KmbrCUm4pudq
E7iXbJeE3iKl5ks72fpCEi7ZfBhul092T8Lyq9WWoyVsvSEJBp7FpuoicnAS
7nTdUGjIZ+sPSajhqP/nnU7mJsF11+5V59j6DS8Jv8+F3tFIJIuTkJl7qYIX
y9YnkjDRc0aZEodclIRlnxJ9OOFsvSIJYxaemPCRrReVJsFp3cRnywLY+kUS
CoJ/3BT7kGuk43doPP/mFraekQSNkyv5XzaR65PwetGdnK6ubH0nCd+66h9T
cGb9T0JLEce/aR3rfxI2/U18fWA1638Syl2d4xeuYv1PhqEW/+9BC9b/ZLyK
GVj0dCnrfzLMBjXZ3jVl/U8GdtSv4M5n/U/Gcqcx+S2zWf+Tkexzd87vaaz/
ydDd5eFcMJn1Pxmn0vaPvMPW75AMc1vOmXRN1v9kLB3q3ufeENb/ZIzxnaJy
pB/rfzJae83YMqkH67/075c9cF0lx/qfjCydu090f7D1xmR8Vw4qkN4wOhyc
jEYPbpcPL9j6YzJatia8vPmAzE2GxsTdqevYeicvGctObGoSV5LFyVAfYtWY
eIqtzyZjocNlU/1D5KJkNHw/nS/ZydZrk5E6WvdulYhcmgyjoOP+J9j6bkUy
rrxs1NwUSa6RHt/I9ZKnbD25NhkHLYOmD2fr0fXJuH4kRE/Hjq3vJsM3aEGB
0lJyUzJe9N5ZVcXW71uT8fYZkjax91nakuGe6X/+G3sfRy4FSv3PRHgNJCul
YGP5pZd3u7P14BR4GStPn/TLucNqKXhoPM43tJmskYK28T18z7L3rXRSsMBf
L/5vLVkvBVnTfr+be5FsmAJ11RWRsez9NKRgsfm34zf3ks2k+z/kfk+bvZ9o
kYL9gT69U9n7kXYpGNXlqbF8FNkxBQevWx5M8SG7pwClxavHsfdPvVPgWeSk
+Yi9zxucgrAD/40pWEzmpODa/h11QUZkbgrE+36obphM5qXgscmjIS6jyOIU
qFTNDo0dSC5Iwdn7L0IuKZGLUtDTtf3WlHanDpekILBrVPTtj+TSFHzo8W30
/hfkihT0GHJa/ux9ck0KdFpmlfS7Rq5NQYBb4n9FFeT6FLQ+MN+WcJzcmILR
T5RSDu0nN6VActdlv2YBuTUFieNv3nmcRW6TjsfL5gMNKWS5VARcW9dbNYas
lIojr8Y3BQWTVVLRGLdmzB8vsloq3vi94eW5kDVSMW3c2QJre7JOKoIv/7dw
nBVZLxVyU9SKNZeQDaWf3/g922Q+GalQb5yRLjQkm6Xi2vr3mr31yBapcPhg
HbZzLNkuFXM/hMQYjyQ7pkLJfL3Kk0Fk91SoRFxM2dCH7J0Kgzln/l3tSg5O
hZrKf86D/jh2mJOK9KELBpp+JXNTwbUfc2/9ezJPun/jsh+Oz8niVCS3tEUv
ekAuSIXCSsOpPWrJRanQC+Fq5FWRS1LhOzfE9Vc5uTQVbYNH/zfmKLlCejwb
H90fu49ckworu6vOKtvJtamo3B549KOQXJ+K83W7L99KJjemwoc3Y0MZh9yU
ihK3uumFgeTWVCzop9Ee60luS8XZ8r1jlzuT5dIwyP7WznZbslIaVlWuP5y5
jKySBptR9XcGGZPV0jD13+tMsSFZQ/r5gSUOmpPIOmmA0qv3x0eT9dJgbT7P
yXoI2TAN/nb9bnzvQ0YaLra8tc5WJJulIbTLx21uXx06bJGGloLHldueku3S
YHbmxMSGK2THNIxfMnSB7gmyexr6uu3pmrGD7J2GJRtcT/9KJQenwWOX/dr1
wWROGsomyQ/bt4HMTcOIyJOfbi0n89Lw+cu+Hw9nksVp6P80qeaGFrkgDYHO
rhNO9SUXpeGK9KaZ/2t9h0vSkBo3IzLwFblUOh4V04S6teSKNBjdTl+5t4xc
k4aIYaavbxWSa9MwqU511a50cr10fMZxj44MJjemocvF1QetnMhNaYj9cK3W
fAm5VTpeLs9y+k0lt6XBr0qxX94wslw6hHWPkh8okJXS8fWqhlvJ+3UdVkmH
r836zT3ukNXSoeeo+fP+KbJGOvaNG204vICsk47XrQVRr+LJeulYcDCl+4LN
ZMN0GO/3eDrfgox09PFfpvzBgGyWjsQEhXbjIWSLdKiM5xww/mPfYbt0nKjr
j+ZGsmM6sCttsWkl2T0dT837Ptywl+wtPV670HnrksnB6Sg3++m5dAuZI61/
X7t1gQWZm465F+vOr5xK5qXD0tm9jDOILE7HZtOALfd/ru1wQTrs362rdHhM
LpJ+/qhfi/Z5ckk6sl7L95q9m1yajnuvLPrsTSJXpGPgS5OUrV7kmnQc+uVS
yrci16ajtV+vpcozyfXS8bzW2+nRCHKj9HiuZGl170puSkfvKXfWb3+/psOt
6RjaTY5Tepvclo7JoStVXMrIchn4rPDfrv92kpUyUD/twHBxClklA4rtew4N
DCCrZeBhreF5dQeyRga6vS19vHsxWScDf+Nabx82IOtloGXdQPnFGmTDDFw1
kNscqExGBjy/nOw1/+fqDptlwExY4L/nNdlCejyLb+8U15HtMoAKv7f/LpAd
MyBajMEVh8nu0v2tvBxxtoDsnYEl2bpdX2eQgzNQtdYrc2wUmZOBggleXwO9
yNwMFNnYzqhaR+ZloLhuWHKXZWRxBppb5hzvbUQuyMCmYWsvXh5PLspA8Lao
wQOGkEsyIA642H65G7k0A+U/XQvqvth1uCIDGlfGrBnZSK7JQPqG576Sq+Ta
DMzwfpA5/QS5PgNTEk3dnm0nN0rzcw/2jeOSmzJgMt3ul4I3uTUDB6c//7XQ
htyWgeTfnLFTZpPleLh6RuP+iRFkRR7mPp9VcFmOrMSD3cOCGa7PbDuszMMa
7ZstKRVkFR52Rp1qn5VPVuWBP4SzxzeUrMYDz1bprd4qsjoPv+O6FPlNImvw
sGeT15NZ3chaPDwu298lpcGmwzo8TNuSXu11mKzLg9J/Xc7+iCPr8XDwwdnE
ObZkAx6OnglTtNchG/Jgtq5vV5+2VR024qFl2mkzSTUZPHycfsbqaxbZhAdd
x95rJBvIZjy8zVMet1ePbM5D3rLSM9P/WHfYggfz/FH/3C6TrXkw9v32dV0W
2Y6HyqCcL9I7YIftefA9uXW34USyIw8rzsWt8v9p1eGN0vFe2mf4yCqyOw9G
setDNwjInjwsUfiQtMmJ7M3D6z9jr9jokf150Hv3XHO5HDmYh6aGJw+33rLs
cDgP8t3XOD7YRebwULr5fXVhEDmOh8Yx37c0mZO5PNTdttE4OZqcysOp4wmT
NdtXdpjHQ1K82cTp98hCHrotdUjodoQs5mE459aIwgxyHg+m004Xa24lF/Dg
eDdtcKYFuZAHpxHVRl0MyEU8yDmO54cNIRdL56fv31T5LuQSHhyuJL/KfGfR
4WM81Oef/aZxj1wq3f/9uK57LpLLedi0K/C02lFyBQ9W1Rt3+RaSK3lI7NH0
5GA2uYYHTdN+JRdSydek9SW+VwtjybU8nBtbsm1+OLmOh9ozLQmcQHI9DxN3
7Oy50JfcwMPg3Nhyn63kRun81An3eLeF/JKHhrGXzwmZm3hAvW+krRe5Wdr/
c7of1LzJrdLzK/mD8xm2/688nMjv8lqb1W/jwfPcyDnTQ8ntPIwP0b54LZIs
lwkDkfOp6yyPYiY8/iWZjkgiK2Wi3OGBWWE6WTkTp55PvGsiJKtk4ueiPy4v
csiqmSgce8vFeTtZTbo/1cyvhWx81TPxvE79DW8fWSMTC6KmVPU9RNbKhPu2
TMM+R8g6mZBrNR0Xepysm4l+e/RCUUrWy8QShxczl5aRDTIxaVfR4ujTZMNM
9J+Tdb+a2SgTg34qtSsyIxNLbSfLjTpFNsnElQHzxyifIJtlwkT/Vu3Rw2Tz
TARAVNWzmGyRiVny01fK7yZbSz9fqrUkOY9slwnFqocXMvlke+nx8I7P65FI
dsxE5NB1zq9CyBszUeZ1lq+xmeyeiajiS0/L1pA9M6H2W3tUqRnZOxNWl6+9
V59G9s9ERdiHNe9HkoMzcfNFqJ9mD3J4JhKW3Avzf7aiwxzp9oXPhc4HyXGZ
sDUaa9E7kMzNhJLG1OCY2eTUTFj7VNY1/FneYV4m3FqMh849QxZmSs93q2mX
QsjiTORP2HMzbio5T+rV4jlR75Z1uEB6/NfWDTuQTy7MxJ8pv/v+W0EuysSc
FU90o/6ad7g4E/y7i/uZ7ieXZKJhZnJgghX5WCZ2hJcVx/1a2uHSTLwcM3JE
8nZyeSZiLh8Kub+AXJGJp5u+FOW+XNLhyv/Nh/DlX+PINdL5r1U3rG00+Vom
crvtWlp1fnGHazPxY9uJBsF6cl0mvO78VS75Zdbh+kzMPTbBJ0JEbsjE67LA
qc5TyI2ZCAzwX3HixqIOv8yE47i9305uJjdl4uG/L6dTepCbM7ElZlmTWZFp
h1uleR0eRiibkb9m4m63XuE93y7scJu0395tsVkp5PZMTPk7K2GIHlmOj7PZ
R4Yo3zfpsCIfLbuyrj7gkJX4aO29or5+IlmZD7eHvCrTJ8YdVuHD2sTyngWf
rMqHosnLD5pLyGp8TLdrNm/pSlaX7u9o26vvlxZ0WIOPeWeKHsQkk7X40MoZ
eeK2FVmHj7SCWRNUR5F1+ZD4K6yx/za/w3p8qBvyDA9cJxvw4bJ49/lv+8mG
fNhe2TVTP41sxMcBvcMWq/3J4OOe5GL+FkeyCR9ByrwTbivJZnzEPlVZOXkR
2ZwP7qITwwXzyRZ85P3WurgYZGs+Zm5pPvVzAdmOj8LNpqbGi8n20u2R/XdV
W5Id+ThpP3z3eAfyRj7E39r79fUiu/OxQ3QuSCWK7MmH/PUJRWczyd58LE34
qp+/m+wvzdM9femkMnIwH+djC+Z+ukEO58P/dkS17wsyhw/LF/tHLP5BjpNu
P7Brn0pPGm8uH97zFwtchpFT+Wivv/fo6XgyT3q8Q1Z0G2hIFvIRMOnGvO0L
yGJp/0t0tmsvIefxoXNw1G635eQCPiwmB+lNXUEu5OPoCedlbubkIj6q/z5Z
9HIhuZiP1UkjPsfOJpfwsf/UyTlqE8nH+Ejob2ztO5RcykewelCtlwK5nI/J
hhP1ujRR3go+qgymtxrWkCuleRZXR84pJNfw4Vq732tBOPkaH9GT1viFWJBr
pXmuzNXuoUmu4+PBVck35RZ0uJ6Pv+/qudtOkhv4ONJF60pDBLmRjxvZ43L+
gfySD6Gqa5JFF3ITHy+354yxjpzX4WY+xjUout39NrfDrXx8VbVRv72J/JWP
jYFNpQ0P53S4jQ8b+QILv8Xkdun5g4cl/U4YdVhOAPMlbkuNNcmKAiyx+vV+
f8rsDisJMGz0lX3t32Z1WFmAK64lyR8cySoCTOGnuGhen9lhVQHyM82va8wm
qwkwyN/lqP0Bww6rC3DKZnH8nBFkDQHaLjZdMhDO6LCWAIp3i9Wqe5N1BLA7
dKE4KWV6h3UFKK1UcBjYh6wnQFVbb48fWdM6bCDA/v4NjkWjyYbS44+6PC79
pEGHjQTY3cXsczdLMgT4caMLJ+DL1A6bCHDSY5SRaR7ZTADf/tPim8zJ5gK8
dP915WxXsoUAOpPGH+ldPaXD1gLE9Uoo+sIj2wkw4vjoQV4byPYC9L897+2m
uWRHqWdfPHBPk7xRgMoN+xwO9ya7S/NcE7vIyZM9BSjYPfrB+b/6HfYWQDRq
78m7CrTdXwBu49HhrSrkYAE8Qs6/yR1DDhdggvwP62XzyRwBqt8Htoax44sT
4Ow4hxUnU8hcAb5M3skvPkVOFUCs6nhryAcyTwB5BQnn+BgaD6EA7neC1gza
QBYL4H/vt3dRITlPuv8X29ccf0suECD107O1YfrUj0IBnqcsObcojFwkwPch
F40Tq8jFApS1HlO+1J/6WyLtz5tTt3McyMek88llkl1WMblUgKMLPZ9M+kku
F2Bs28J+l0xo/lQIMMt/2uKD6eRKAXQHremz5B65RoDHI14uGD6M5uM1Ad6P
cwu/Zk+uFSBSP/Wzai65ToDti95ZH79LrhcgfOth7TXKNN8bBFBy6rFAPJfc
KMC/y2ND2jaTXwowU8llt7KQ3CSd/wt6u0SfIDcLYFLfXX30HXKrAF7rXGrr
3pK/SvtT38KP/EVuE+DFwfcx7Yp0PrYLYPR28MjBPchyQjQFqR9I6kZWFGKH
S6Gt6h/6vJIQnr/mBfCaycpC9JHc8fpVR1YRYpjnXbEHOz5VIcouNI+XyySr
CRG8rq7nlY3s/BeiOm6hXpk+O/+FKHoj3rz/Bzv/hdAWls71PsHOfyHK7xyt
/7aFrCuE84A6n6UjyHpCtNzdfn1vNfXLQLp98Letth5kQyGUJogrd3UjGwnx
tz3TpSKP5gOEWNBwYO9lXbKJEBPtjJfcO0HzzUyIY5Vjzg+YTTYX4sIl/pon
p9j5L0TkgyWZ1VPJ1tLxMpEbEb+Pnf9CrPrb1e3mMHb+S8d7j03xvBQ6fx2F
KPj07N28Nr0ObxSix6Jck0EbyO5CXNXfXd5XPLnDnkK424x52dVtUoe9hRDv
SnsWaDCxw/5C/FPzbVklr9vhYCGm3dij/+L2+A6HS/PfSXxgWjSuwxwhPg39
/HVynE6H44T4oFZ3dbfb2A5zhVAVjTBUsdLucKoQE0KfmaaYjukwT4g1Dtm3
li3Q6rBQCPMP8778Nh3dYbEQ7VcMLStXjepwnhD70ucFzvPW7HCBEIcaf90e
JdbocKEQ8vpbD97bNrLDRUJUNFkPWzphRIeLhTi/3LP9zgP1DpcIMdfG1l51
/7AOHxNixLEd1/fkDe1wqXS8ltht4B4Z0uFyISz1X22c8UGtwxXS+dn1xIDI
5eRKIfwX6A7rWT+4wzVCpK9DZdcU8jXpfPGc+vi5G7lWiC6Ch55bvMh1QvS8
790wJJ9cL50PNxdau34nN0i3L21eMyKI6jVKzxfnnj/Xa9DxvRTi6+Ox1as/
k5uEaNi+Ydj3ZsrTLESO1RxxVF/K3yrEucTyJVy74R3+KsTDv5wSpSoarzYh
dNocht4dT+PbLj2/D4gNU+Vp/OWyMFlbcmrYW7JiFsxMi5REj6lfSlnwn1CY
Pewp9VM5C1lr5lWdbqZ+q2RhoeW/MLuuND9Us/B9SayTZCzNH7UsCDKuV/5a
SfNLPQtDVNyHPI6h+aeRhXeSe/kHSml+amVhluKwgvefJnRYJwsndz7WNZ5I
81s3C+7m37y9N9H818vC0Jc+Foa76fwwyMKoTYtP7N9K549hFpQutnYx7EXn
m1EWKtbmtfIKycjCYt7RvV1m0/lpkgU1zVVhj6+TzbLQ/bhbWrw9u/9nQeiw
cInna3b+Z8F+/0DlgZvp+mCdBe++VhdV3pHtspC6btrgX850fbHPQg+cKvK7
S3bMwq5x2YXj5tP1aWMWWgaqfbq7m+yehauVHywWKtD1zjMLxgXPjq9dTfbO
gmr1IZ1BRWT/LKyZvd006SM5OAuHVjvkNUym6224dP/ah11NNpE5WajpP5D3
O5ccJx0/7Jwxr4bMzUJr8mN/8xZyahZ0T/2QOPah+wVPmic2I+60DlmYhT61
f0J2ziGLpfsfvLLeaRk5LwthDq+Mze3IBdLj/+cUdXI9uTAL7f/MtdscyUVZ
qNtTqLTegVycBSv+tMIpa8glWdL7b65j2UrysSzoDK4YbmhKLs2Cy7tZ5Z9m
kMuz0Gz85cbUseSKLGy3saq0VCVXSj//NPlQ0T/KWyMdzxfJpjx2f72WBc6B
7loOt8m10n7Hbk5xKiPXZWFKXa/VD3aQ67NQ+mZHd7kkdv+XjschJb+e3uz+
n4W9f4sddG3Z/T8LI38n6EjYvw+asmBeHa7I1Wb3/yxki3dFj+3L7v9ZODb3
Z1phG/X7axa4HtFRo1+Q27JQ+OO11vkb5Hbp/J6xoXvWabKcCPnXzj89to+s
KIKjztiUGTlkJRFWLZm/YHoyWVkE/91GWtfCySoi1KUX9B/oQ1YVoX1i13Jd
N7KaCPxpC3UnOZDVRXC1HdnTgM1fDRFerstIXr2K3f9FUOoSknLait3/RXC5
9/52sDW7/4twzUVn4mFbdv8XoW/G4R1x68gGIsS1fl+u6ko2FMFoQP9bcez4
jERQcCrsL8chQ4QGW9H8Y5lkExF08o5vurmHbCaC5+UFfUPOkc1F+HRo9tOr
j8gWImRMbTh86zfZWoS862+14kZSf+xECFTyHXzHlGwvwu5TE3j/+ZAdpeNb
eD9yUAF5owg195rlB7H55S5Clame/ZXuND89RWgdcyXbaj7ZW4TYStdBNZFk
fxHEn4vtxlWQg0U49Pi8umNX+r4WLsLstePMFywnc0QocyiJK5CQ40SI3Dop
1PodmSuCV6NJvtkc+j6YKoKi4r/wAAGZJ8Ka05v73m8mC0VIjnn8zGExfZ8U
i1B4+YBqaxE5TwSTNYL51r3o+2iBCLbzeNrLvMmFIhhslz+fd59cJIJhWWBF
v/n0/bZYOv9WDOiRXEwuEUF13YsTb4fQ9+NjIoTd9qrqmUQuFeFzuQv34E9y
uXS+zh6zt3Qafb+uEOH3jeDVzV7kSul8WKL8ckIRuUaEGyVj5Kc+I18TYdLx
0d8vDWHf/0V4v3ix/VH2vKhOhIrnQ57Xcsn1IqTrib2+nSU3iLAniDf/6xdy
o/TvKz+czh27oMMvRUjauymndDW5SYTUyZX91dnzsWYR9jrbp+8oJbeKYGlq
wdV7Rf4qwl3dkL2n+tLztjYRhmVzP+kZktul8/PZRC/uerJcNpq7jTpzMIas
mI3Ra+empBSSlbKhtks5sE8lWTkb/o6DkyY8Y8//srEq7MbMV7/Z879s1DTy
1M1V6XmhWjaqzx9B2HiyejZsGz9NEcwla2Sj2ysNzZMWZK1sXJPzmtbbiayT
DXcHn4MVW8m62XC+HVmkEEHWy8aGN+f4fZPIBtkQV307P1pINsyGncsZ7Zh8
spH0eDg2zz2KyMhG8Nt9n9WOkE2ykWrjvObCabJZNtZvbEfeJbJ5NtoOp55r
vEm2yIaN2tbc2w/J1tnYa3NFufw12S4b8mfjRzd9IdtnI+GRT+8ceXr+6pgN
p5hdC//1J2/Mhu7psWenjSG7Z2Onra/qwplkz2wsUihO1l1B9s7GsffjU5td
yf7ZMIucWJjGIQdno4/KxXiNPHJ4NvhXt+icPEXmZOPJqiqPNQ/Icdl4ui+c
3+U3mZuNGzPer+ONoOfLqdmY7nxs6mNjMi8bLVUPj5R7kIXZWPxf38fKArI4
G1uWC4zKysl52cDCY8fK35ALsmGZ5Ti4jyo93y7MxqiFitu3zycXSftzaMRJ
K29ysXS8P6ku+redXJKNnrsODfCtJR/LRvgb8yUxXej5emk22kMeZg2cSi7P
hq/4+abRLuQK6f6vKCuUZJMrs3Fm1ILDF6+Qa7JxZPewmg1/ydekeUVFWplT
2PP/bKS3fNhv7sae/2dj2a6Fsfl55Hrp8a35b1DubXKDtL+LHt5x6kHrCY3Z
SDFasmzgfPLLbCilrZ5XG0JuysbQir0teUfJzdkwGLnzmW8LuTUbOZsrfWaP
p/WMr9loWLHW56EruS0bnnlbKqcXktuzwXufHDbvOVlODLnK7mrNGrR+oijG
h7OHR810JCuJofTO/83oArKyGOsXTv+5t5GsIkbfpgM4p0nrNapiNDt9G79h
A1lNDN2XPQtTd5PVxbBOLPLXbyJriNGzP2fvvAm0PqQlRuNcfbccL7KOGOF3
u01QPULWFSP9dvip8G9kPTEa9kqmbTek9SkDMSJ6LZ9rEUY2FONeS7ya3xmy
kRjaW5vif/4lQ4wltSKDFrZeZiLGng9rP3YHW/8T48YQvwHlDmz9TzpeZw54
fGbrpxZimMdc907extb/xAgJF/91ZOuLdmK4GnwcYFvP1v/EUN1retzmK1v/
E+PMrvPHrPrSevZGMdwfW802G0d2F6MqYKjK5AVkTzEsNq6r+rua7C3G3G5/
vIq8yf5ifL/6wmNoAjlYjFlXnAsWSsjhYrjcqGzWPEjmSPP+XNT/v7PkODG+
7NkW8OkGmStGhbxcYvNjcqp0PhiFjc5/z9b/xXgyseLCnx9s/V+MC3EPZ8sp
0PsCYjEOLopzyVcm54lh4z1W7ZEquUA6/oPv6V4aRi6U9rdda46/JrlIjIEK
B+XktcnFYgytk9OJG0cuEWPQmmtTeuqSj4nxMUbboWAiuVTar0fTWldNIpdL
8/vfHWLMXCFGRtqO28ns7yvFWPVPv8WG7a9GDBMTLmrHk6+J8WeCW5/BrH6t
GNO/n1DGWHKdGPxP49/ajiHXi1ESvcLKk70/0SBGdev0ZhHL1yjtj695l64a
5JdibLT4L+bHCHKTGP4VNr3KmJvF+Hr78HnhSHKrGPm3R70/x/b3VYyzXp8e
rWf126Tz5aw4LZYdf7sYh1TOPJqhT5bLwe5QpcDEmWTFHNz9oDsgwZislIMb
YQVpK1aQlXNwdvjdKPl1ZJUcuN6vSyv1JKvmoOFdnQMnkqyWAy3Lp8/W8snq
OYhcf/7SgiKyRg6K1xUsHltB1sqBY9np2l8PyDo5SLo+eFfJN7JuDn5avnGb
O4Deb9HLgXKm2T/JFLJBDq7tCX5abkU2zIH1lI0vxIFkoxwEvOp+STOXjBw8
iepzd9F5skkOvhefX93WRDaTjo9y/Gb1/vS+jnkOFtp2v5FtxN7/ycEkfsQp
M3f2/k8Opvi9ieghe/8nB+s/bpx77AJ7/ycHJ2I0qsZ+Yu//5EC1t+ucpRr0
ftFG6f5Sr9n1sSC75+Dm4CNaLhyyp3S8XV73mX+Y7C3dX8vs2OTnZP8cZF3e
qj1Cld5/Cs6BzbTE5zcWksNz8Hrr7Eebg8icHKQPanpRXUSOy8HygGth5x6Q
uTn4l/D56aye9H5Wag5M3iwKmzCLzMsBp1ZpesImsjAHUekR2XPEZHEOXnhW
R82tIuflQK9eeMD7C7lA2u+ULlPKRtL7ZoU5iNs25LzCUnKR9HhTeZNmB5CL
pXl/7FGwyieX5EDz2VzreVXkYzl49do16VMzuTQHV76NNF3Vn96/K89B6Q9j
DYvp5IocWD4MOlppR66UzofC71+yQ8g1OfA6bO16Qky+Jj0fxus/GXSCXJsD
/q2Z5aduketyIJwo9t79nlyfg4fq2lOeK9D7jg05KBu44UXgUHJjDqYVY5r7
ZPJL6f50lt48tYDclIOEwlnLvK3JzTlo725yhr+Rvd+Zg6HOo7+P9yN/zYHS
Pu2+Cznsfc8cjK5wfNbC3udsl87vnD3rDEXs/U8Jjs42OmywnawogdX3Nv3f
e9j7oNLtfdzO7zlIVpbgqofjQquj7P1QCTaUq60bWkpWlWBa5P7V/crZ+6IS
dLF71m/JObK6BON/da28d569PyrB/vTNiTcvkrUkcBW8CrC5xN4nlcAi7Hl2
dhVZV4L0rhkhF6vZ+6US2Pgm+HS7TDaQQAGP7nKusPdNJTD4F/vR+BrZSIKJ
vJIm6xvs/VMJTh4t63uslmwiwa6Mtncb75DNJLj/H1/P7x7ZXIIA3rAunx+Q
LaT7rwrK+/aYbC2BkaLa/eTnZDsJGvtfbip5Q7aXYNKU17/tPpAdJfjW7DnY
8wt5owR95pSo3v1JdpdAdP3R2mQ5er/XUwK1x/++87uTvSXIa+LnK/Yl+0sQ
8tHz4+9B5GAJZj1c28AfSQ6XoOir1Y0HOmSOBIZbhly5O4UcJ0HuseyusXPI
XAl+/33t9MCMnCpBz5f1w2qtyTxpv1yH+Do4kYUSrBiX+ZHD3mcWS7D+hd8Y
vXByngR/79bqbklm709Lx+uGVRpyyIUS6Prqm54tYu9TSyDg23bveopcLB3P
LkE9DK+w96slGNWcKRfQQD4mQWbzoIgrH9n71hL8eugcN1WR3t8ul+D67V8n
JEPIFRIsUb3CfzGZXClBLTQCv5mSa6R5z08xvLiefE2CT7NHlS0NItdK8LX6
yFIBj1wnPZ572w7k7CfXS+D4fLGf5SVygwQPhq1yLGTvrzdKsGBGaBfvdvJL
CY73z9eXqNH7700SbB1Umao6jdwswalvvXOerCS3SuDxKb32jxf5qwRrdt+/
vDWV3CaBfZc/W4bvJ7dLcCHFoOZuNVkuFy4et55ZviIr5kJQ+D7cVJ79HiAX
Jvd0nm4aQVbORWHbhckpM8kquVjjWRkksCKr5mJ8+4xtMZ5ktVz8+2LadUMc
WT0Xy8fNvDIrl6yRi1FvAyO7HCZr5cJV7LM3/xJZJxcNefm3WuvJurkQu/64
9eAdWS8Xn4+PGLD0N9kgFz0XPNtl3pN+j2GYi9TTtkd/DyYb5SJKo8fYaPb7
DeRCd9PW54p6ZJNc3P11NHrXLLJZLkRD9s/zMCGb54LT1TV89TL2+5Rc6J8f
9nrzKrJ1LrQLNo3Ybs9+r5KL3PMD0n45k+1zEeq+7kOmO/v9Si7MP8XKxW4h
b8zFK8uxLz76sN+z5OL1ckFRWwDZMxdVkzjFJ0LY71uk/dnoJTc7guyfi6zr
noN4HPZ7l1y0vlDYeyaWHC516mKV6wns9y+5GOQ81f1aEjkuFzdy8s1ust/L
cKX9nbwh5UMGOVU6X4r7D5kvYL+PyUX5gddjXorIwlw47tHY3yphv5fJRcuy
tU8528l5ufi/ou49Lqfs/Rt4ktAQEpKkmpxDkyhq8hGapHFMSEgaUkk1JUJO
IUpCkboP+3AjOSWnNCGEhoaGJAlpkiiVc5I8+3n91rW/f75fau+1rrWutXLX
Wpd1ddCZUxo6P5MGA9MNxikZzJo0aDW0tJ11ms7TpMF8vm7Bx2zm42lo/7Pa
K+4qc2Ya3mW//dX0DvPZNChKrIMzHzJnp6Gbd/rZCS+Yc6X+z97Qvfwtc14a
bvf9emDTN+Z8afyVrzP6taPzWGloPhNR3qUzc2EaTm6L+LyvB53PkuIxKmdx
hilzsdReLeOQ3wfReS0pvqM3jY+wYS5Pw722cf8a/0rnt6R4R9c/GOvKXJUG
W5M1hSWz6DyXFJ8ZP0V+WMRcJ8X7z3jtZDrP1ZiGow5uX3PWMH9Mg9PlT58W
bKfzXml4tnT29JBk5pY06Kz+d+ULkc5/KdAzUstWyGLWUSB6a75b+lU6D6aA
xde3yfV0vq2TApml7bqHVdD5MAXmd89VWjUyGyrg6lDt1FWLzgsqoOve70C7
rswmCiyq1l9bT+f3zBSY+VvN12MjmC0VGD4+IK7/ODpPKD3vD2+/qVOZrRQ4
Itz3GLCAzhcq0BL6JeBcILOtArbPLkMnis4bKlCQOPWMYSyzowJ7nLqHPaPz
kJDas9ONny4yT1Rgo/OUcXMy6TyiAtdUM8Ne5DK7K3Cl7Mw/LwvofKICt7W7
3vUtZvZQYPMnl2vzn9N5RQX23ro9rPg1s7cCE/t0n1/4gc4vKuC8afZLfGf2
k+J1I7fXMF3f/7O/Ai5ttGcn6DMHKdB6KX/M0p7MIQokuC7Ty+nLHK5AanBE
5m5L5tUK5C1b2OPNEOZ1UrzWRRvfsmbeqIDPvQFbzUYzxyiALX23NoxljlVg
gbvWD+txzPEKmJUcmlTjzJyoQA0nnjN1YU5S4OqScV4VrswpClR9fhtqN4VZ
ocCTCUPdBv/OzEnj0/F2n/NTmTUKjF1+5+mTaczpUjzOzApMnc58XIGukbMO
fyZnKqB6GnmnmXxWmj/fnl85Q85WYIZh7X9W5FwFRpt3vRtEz8+T5vPAqefC
6f35CnS5cvCWM7WvQIHI5HzLEmp/oQKN8/v72rgxFylgVPZD7UP9LZbyZ5Zq
xQqKR6mUX8mvd/tNZC5XwLS2g8nvFL8KqT1HaxwHgblKgeUHO2378CtzjQIm
sTo1JxyY6xR4Z73lh/cY5kYFik0Ta7vYMX9UIHzZjoSntsxNCmS/6OT9zIa5
RYGHHWcesPyFWUuJhPf7fr5A5511lHBbcPzcnuHMHZToMyFnScYw5k7Sv+OO
QbMVc1clmnf1aNpCNlTCvI9T6FyykRKnNy8cu4dsosSCv27+4UrPM1PizfDy
Qwn0PkslYvvxWktpfg5SotW6xu86td9KiffKpvLkUczWShjfPr7/nj2zrRIv
RumEBdF5bnslmqaf/xZG8XVUoujFpsUNNB5Qos2BPkNr6Tz4RCXO9+y9fCnN
D1cl/qmfZeRJ9aPclfDKNZ+VTvWXpithmTr13hRfZg8l8o/1yBlN9YzmKrE5
43HkcqpP5K1E3om+12ojmX2U2LKoYf0NOs/up8Qduyd9vmxn9pf6f0vvZEQi
c5AS16pqsqwOMococfv+qj90BOZwJaLsnzm/pvo0q5WYdfa5/b9nmNcpkTT1
X6fcXOaNSvgnGrhnUv2WGCW4S31rsu4yxypxj9t37/oj5nglngjqdU8qmBOV
GDRioHn9a+YkJRSRe+3fvWdOUeJxv4KUim/MCiU6HZ7+W54O3Z+gxNX0y21T
OzNrlAhoOXo8kuqRpCuR4xM4aQHVFzmuBEbWrJ0k1wORxgNNJhZUj+OsEpMP
rXrznOohZCsxJoJ/FejMnKuE55ir1Rfc6P4FJaw/r7qeO5M5Xwn9T5lla7zo
PgYlXm1P2/6e6gMUKhHfJWnAUKoHUKREereHrQNCmIuVOD7KX/VqFd3XoITe
Dt5lxXrmciW0B1YdvLCF7m9QorG985cbO5irlAhM57cf2E33OShhOsc2bGgy
c52Uf+OHcJtS6X4HJVx/Dm1IUzN/VGLO5FvdNmjovgclxm1famJzlLlFiS/z
Xk7NpXoAWirsTO52zDyLWUeF2t+3vFt0nu6DUKHb6eTrK3KYO6lge7WqyvEy
3Q+hwuU/2067cpXZUIWI7ANb39J9GUYqvF9vcuTOLWYTFVK7n04IuE31BVSo
66h75L9CZksVxOzfzk+n+zcGqaB2G+Jz/V9mKxVWn69eiWKqR6BC6cv6irwS
ZlsVarZNybSj+zzsVTCoHhFz8AmzowqFU3SOVT6l+gUqOPYbyRtVME9UYcCa
blYulcyuKpyOtvz7zypmdxXe5a9w4aqp3oEK9y+JMy/VMHuoIMwZk3ea6h/M
VcFsRK9EnzpmbxV6nHzy8jTdR+KjgqfNCfPUemY/FS6VXyno08Dsr8LcuUN/
mkAOUgHJ676bkENUCFy0T+8UfX+4CvPnZnx5L993osKXb8tdHtP716kwaUbn
xOm1dP+JCg8e2zlMfc0co8KpE78tK6b+xapQvTtu3Hu6LyVeBV/v7+cvU7wS
Vcgr9No7neKZpMKhoxPLL1D8U6T5MuOvo98eMitU+PWUU7DJfcp/FQa72Fw3
ukv5r0LzBNtT7/6m/FchwTFn9vEblP8qlOXYlU+n+ZYpjefmXkY1uZT/KpwJ
Sh4WlU35r4L2fes5Xc5S/qsQMnLFb1mnKP+l8e9dNiLsGOW/CvrDWn19j1D+
q3DtUf7L/SLlvwruGOvej6P8V2FXfNYBbSXlvwr+Y7qsd6L8LFVhWtsQzW2q
11GugvW/8WNVlM8VKpgkzC49u4/yX4VtQ6P1u+6l/FfB44xw/izV/6hT4fxX
24xDtD40qjDn9Xm75wmU/yr0v/g2wpPcJMWzp0/E912U/ypMmNkz9jZZSw2D
gfcrLpN11Pj7wwyuhtxBjbcB3WYvpOd1UuNKqJX3KHp/VzV8v1YciqT2GaqR
uqj/t77UfiM1HNM9V3VLovxXw8yhw/CRdB+OmRof1jxasTSF8l+Na7kvxxyk
+A1SY5rCsPiWgvJfjanLNndppnon1mr8aH/3uwNP+a9GvmrU5WQaL3s1rCfe
DNA9TPmvxroZzzvHpFP+qzF6tf6VHxmU/9LX52RMCaT10VWNoKjGE5dovrir
ka53aM/H05T/atS3Rp0woPnlocakS7rOJrR+zlVj7VCxpDvNR2814sM/3Wui
+4N8pOf7hJsX/EX5r8ZPJ1vMoqkei78aI43sDI2uUP6r4TP07YqkPMp/NW7H
b9nzjvIhXI2o0wmvhl6n/JfaW6ezx5HW43Vq/Dv8Ul5vyqeNaqQk/FqTTY5R
w3/LqS/dqP5LrBoOcYopFuR4qX1D9XLf0tcnqqFXqH6xjpykxps50d0fy/cl
qVHcL6dnB7JCjc55Yx51pPZxagx6NiHwMbVfo0aZjfOTEOpfuuRUh2v/0H5z
XI3Pk9ev/Ej5nqmGrlXIkwban86qse/WoBl35fxXo6dP0ToFjUeuND8X5scs
pvHKU8O5rHSMKe1/+Wq8Ch3E3aPxLlDjxYBFDn/SfChU49bJJxl6tF4UqdHY
oSJJQfOpWIpfp5E+NjTfStV4/U/ST8U0H8vVKIkSEmNovlaocfCXP5pB+3eV
GpWNqx/J60mNGt1PW5TnUz7USfFM27hgO+VLoxoKJ5fZMymfPqoR2rC3aCTl
W5Maln23bHSgfGxRI8FuGxdB+arFoebh4mOvKL+1OSy7GItEeT3gcLZzzfPl
8cy6HOoWzLgVHEfrA4dfJ7hUptF9VnochF/0Vryjn2c6cfCb7T4mlKzPQddn
xuU+5K4cJpYsEd/GMhtw2NgcpfOcbMgh4Vr6oSpyTw53Fp2Y/J5sxMH9hXVD
C9mYw36r5c3fyCYctvTy1X9NNuXQVs/L8grZjIOW46rSNWQLDlWZxqd6kC05
+P+w9NuznXkAB8MB6l0N22h94hBXd2S1HXkIh4VhMSvCt9J6xeE/nUfzz1B9
p+EcmnIXP/pBP/9ZS/FcbHhxMdmGw9Aqs2Xlm2k946A/4nTDSvJoDoePRzn3
Idtz6JDc4vtsE/NYDmZNQ5L+IjtyeLNzvPkFshOHcQVD+5eQweHk48sWfel5
zhyW2lUN3U2eyEEVefXxMGqfC4fHMSMKv5JdOVjcNDX7QP1zk9o3wiy4N8XD
nZPWN4/fAyl+U6X+1v9y6SXFdzqHyITcj1to/szkUBnRrWQczTcPDna+vZ8Y
0Pz05LDn+f42X2j/mcthu5Gx/as9zF4cCvo5Gz6n/dSbQ2rOuPZltN8u5NA6
cHfqfdqPfTg0Ttzpcu0gsy+HXs/iBghptB5L4xH7aHYQ5eNSDiGFQ+f3pXz1
l97X7uirs/TzQAAHl0iDZaPo/rcgDl7buaUC5X8wh8kjDwW30s/nIRyad7vZ
T6b1Ikyyz62v0fTzRziHgE2DW1JofVnF4YPnxf676ef51Rw8//UvmUf7VxSH
Cb37L/9AXschZnHDo7m0XkVzWLXrxLwd5I0c7l9IGLeVvFmKf+uPdHdyjNT+
H0vSn9HztnFo6FM4YAw5lkP8uAGB86g9OzmYbm946kjtjZfG90hFygvqXwKH
899nbneh+mSJ0vOHDrcKpPjs5bCNL1gwjdbHJCneo1OmfKD9fj+HJLVR3Rz6
eSCFw2YDtbiBxi+VQ3undnnBtB4qOCz65UbQUJoPKg63mi/qXKL5w0njdb1P
yxCabwIH17M37q+l+anhUFrbFHmW5vdhDs9uV00t3Uj7E4dsc9uc1+uYMzjc
tRle+WY17VdSvFqKFj0LZz4prR96T/fdov8vZnKI2q5SZgQxZ0nr3YEzHeP9
aT/jcHp9ok+IH/N5DqM0i3Pn+9D+xiGv5+cdM7yZc6T11aJivwfdD5jLwfKw
7s5lVB/vsrQ+mVcW7ppO+5/0/ROqcwup3t41DvX7jl+1onp8+Rwyi4/mXqT6
fTel+XXGzXMz/X+6gEN+XkPb/eOYb0vtC5xtrU33DxZy0Jl7MPIe1R+8K+Wf
VbSBllyvkEPi8coBiVTP8r60fhyYXxlJ9S+LpfnaNXjtSaqPWSKN15SY/6zI
pVL+b7g/ooHqaZZJ+0+P+bM/kss5PF02e5Mjff0zDp2Nd/x3k1wh5e+fE5p2
0/sqOQx48m/vPdSeKmn8p3SLvEr1Nas5iLVuFb2oPzUcRr/JTYyneopvOPB3
EscbU//rpP2oJNTmMtVPrJf2t0+b7SKpfmKjlO8VOjYTKZ7vpfb/12uPxUTa
zzlYme8L6ezC/JmD0/j+iu9UP7GJQ9jTnh5vaLyapf0lrkPYbboPsoXD6pc3
dib/ztwq5edAp1sTp9H+z8N5ySTXBzQftHkYHHil5USfh+jwSFqU3HPLLNr/
edhPjm7laD514PGhb+ih5Nm0//O4qiirWeBJ+z+P/i0Juz6R9XksrNfkzaH6
jF153B3noreRbMBjm/uq8ECyIY9rzwfF9Sb35PFLZZvH8fQ8Ix7inw2a2/R+
Yx7R3fo0Pqb2mfCYYzTp41VqvymPQW12J8ZS/8x4GP3H9fmF6kla8PA6f67x
L4qPJY/5xx/fGUD1JwfwmPls/NUVlC+DeDw1frA8nj5PGsKj9Pr10mhX2v95
TO25p4czjd9wHtwSu57FVB/TmsdS3yehI6l+pg2Pvd29LBbRfLHl0ao5pPak
+TWax/57TSuNaT7a8wiZ9173BM33sTyMZ7YmdafPwxx5/Fmxebon1b914jF6
fVnZBqqfCx6X7/c9nkb1d515OHVaW3qG6vdO5PEpPOv5Xar36yK1f17fefVU
H9iVh59roFEX+rzOjccu0fH1EAPa/3k8//ApzEGf9n8eO90XBf2qR/u/1P/v
R7qPpPrGM3nE//W13pLqH3vwcAxTTjZr9f0/e0rzT1maO5LuI53Lw8x1YKdA
qrfsxSN4/xTDQvr80ZtHi/VWE88G5oU8tg+bltuW7i/14VFZEhJwt4bZl4fm
+dkhWS+Z/XjoBY3PP1XJvFSaD0k9AgufM/vzqG3s+ED/KXMAj7Ktr+ujypiD
eCgmrA/Qp3rVwTz0qzTKK1TPOoRH3qVVWzc8YA6T5uec8d2d/mUO5/EodOSC
Bvo8dhWPI52/le4uZF4tjd8x7Vv9qb52FI+zCWNvX77FvI5Hv1+rQgPo891o
HvW9+zrYXmfeyOOzi2Nlv6vMm6X4xZ1ZM/gKcwyP2F+L81ypHvg2Hvcfza+M
oHrhsTy+ZFeGn6B64jul8VEfM3hP9cbjeejcc2xyO8+cwGPsuwu786heeaKU
P2LJi7n0+fReHlrNIXd7UH3zJB5pqaMufqJ66Pt5VJifevXpFHOKlA891n43
JKfycDWy7+NB9dQVPEzbf2g9R/XWVTwW75xxyZHM8TAxfpP8iuqzCzzaHfpt
QRZZwyNloe2P/eTDPM6/27Q0kZzOY92Y8dOV5Awe7gcWh14lH5fybUmPd23p
fSel9YbX2hdIzuSRtU87qJmcxePNEyHiGLX/LI8OaftH/0n9O8/DInvFe2eK
RzaPkS0jSjpRffgcHmged/QWOVda3x31ykMonpel9WuLdtdOFO88Htrhg7+r
ydd49Gxc2d6Gxiefx3Cj9gXXyDel9dmts93vdH9vAY+mvE2bCsi3eUQpnTyH
0ngX8qj2H2K1knxXmn//HBm3l1wkjadbRNgB8n0eVSZ3DWLIxTwss8+d8yaX
8KixnVpjQS7l4RJ34mUxvb+Mx1p1pc1KcjkPz3a7tRuo/c+k/tvs6uBBruAR
eMGhiKP+V0r9a8NFPKZ4VfGI0Z+d0IZcLY1/3ew0Y4pvDY/lp9p0t6TxeMOj
wHKsYV8arzoemYk//tal8aznEdo8sEs1zY9GqT3BRtbXjzG/l/Kr6zvuCP3+
5qM0fz48OJt6lPmzNF5vhvdWpzM38QgrqFiTRfcnN/NoE+oVee8wc4s0H56v
fd54iLmVh3q63n5DspaAmG43ih01zNoCenV9NGilyKwjwLBCT3NaYNYV4Nbm
3Pn25A4C8KjeL4Rn1hMQpsk9U80xdxJQ2H774yVkfQEf1HG1L9TMXQUouuz4
ZwHZQMCMq0lZj1TMhlJ7Utb2nUnuKWDa7oq6e0pmIwHCzdVrZpKNpfZMti0o
VTCbCCh2cbTyIZsKyA0KefIyjdlMQID402Z/soWA44O//qih+6ctBWw/Uvxx
OXmAgHUv33vU0+/fBknxmXT/SiR5iAD/6Og17chWkpf125uUwjxcQPWltf3M
ydYC5o2OrzpygNlGwArPqkMDybYCXPv2OszvZx4tIGSG1YDeZHsBA1d9Gbw3
mXmsgE3Ly7p0JTsKqBv5RpWUxOwkoNK9oa4fGQJan0bont7H7Cwg+NXuShfy
RAEnnYYZv9jL7CIgNWtEz41kV+n7TWuvWJLdBJxW22kV7WF2F/AwWdtvM3mq
gG/6JYaO5OkCjhRF9PxOv9+cKWDQzbKEG2QPqf2Xg8qTyZ4Czk1v9Q0mzxWw
cqXdwGlkL2k+cw7BdmRvAe9NKlL6kxcKGCa6e/Ui+wgY0LcOemRfAe+OXfdu
2c3sJ2Bw5aaLdeSlAoas3L/mCdlfwE9t2ib/TQ4Q0NLm0rJscpCAR2+fORwl
BwtIsPj7hYIcIj1/hJPnPnKYgJQvRWvjyOECHtzv3bqZvEqaTz+po1eRVwsI
D1tu5kuOEuB10mqZM3mdgM9Z4aN6kKMFRNTOTypLYN4o4LDbp6ok8mYBTjUj
RrmSYwT8NaMsr2kX8zYBnWrR7yg5VurP0Svv55J3SvPVavbfOuR4abzHOUw6
Qve3JwgwOLVH34GcKGBMfUlxbhzzXgFae/qcsCInST57Z0TCTub9AppNTnV8
tYM5RWp/ekmoIzlVgN7vdpcSY5kV0vgvWzuvkn6frhIQ1zf6qBWZExCds8Mh
YBuzIKBj93duB7Yya6T2LjaOPhPDfFhAhVNIn2tbmNMF3PvycFvBZuYMAUFu
qy7c2cR8XEDfvTO//rOR+aQAkwMnLO7S7/szpfmX025bQTRzlmQ/rt3F9cxn
BSz2+jxOuY75vDQ+3rkPItYyZwvIbHGwcIlizpHyY3tctsEa5lwBu5odZz6n
vze4LM0vw0TxxCrmPAF7P+2PWx/BfE1AUcR2/6nhzPkCRjd+PWL2J/NNAXn8
tJTPdN9+wf+Pz4n6B/T3DbcFZJ+wtc9dyVwoYFvu6X6ng5nvCqg9M33v6RXM
RQI8E82RE8R8X0DG/GXDbgUyFwtwf30s7mEAc4nUnqk/NVfR31eUCrA20Nvx
xZ+5THpe8MTwruRyaT3oGDnZZhnzMwEbI/VSFyxlrhAwpcePxsQ/mCsF7Hv+
7e3fVD+gSsDdNjdu65KrpfXBT3f1b0uYawTcfjjk4i5f5jcCch7EGJUvZq4T
MHWu7khbcr2AhcVF85N9mBuleP+8JrRlEfN7AUsrL/7wI38UUBN6tOedhcyf
BYzy5nSHkZuk+Z4/1zl+AXOztB8ef1ZR583cIsX7ccmtWeRWARffxnnl09+v
aInocLnNRyeytgi/9f+9z/Ni1hGR98x8kAtZV8TjUy4Vt+cxdxBhe3jb6d/J
eiIO9lo2p2gucycRn0Y6m88h60vP19Hu/WoOc1cRHqk3S7aQDUTM3HjHZjjZ
UET0PfeFVVS/oaeI7PN1WiLZSITxqE0pS8nGImp+GrXHimwiwquaK/tAf79j
KuKrTvl/uWQzEdfu3Oy0g2whwi644ME8sqUIrUInS2vyABEXEka270QeJOL+
+DcX6jyYh4jS/w80n4vIViJmjH0YcoE8XESXORozNdlaRMurrITtZBsRHXsn
1YSQbUU4VRVVzyePFhHs9ve2yWR7EYN6xaePJY8V8WBhm5MjyI4iDi/ZiEFk
JxE/77vu9TMZIhLa6yn6kZ1F2Ec73epDnijiyk3Y9yK7iAiavKa3AdlVGv+M
r792JruJSAuNO96R7C7CYdS9Th3IU6X5lvbBXvZ0EcfCmobIXz9TxMkn7zxl
e4gI21Yxqz3ZU4p3ZGu8NnmuiPjBFw5/m8XsJWJncbb3R7K3iGQrqxf15IUi
bnb9r+Nbso8U/45H0hvIviJOvOiPz2Q/EU/Hzer1g7xUer7px0Nye/xFTLy7
YI7c/wARfz2JitQnB4n4UPzXCz1ysAglX9FJhxwiIsbQe3kLPT9MROL4N4Hy
+8NFZJiuvvCBvEqED9/vhNy/1VL8pvUNayJHiSi9sWned/I6EZYffGPb0Pui
RYx7vuhgW/JGEf9mJbeVvVlE1aOn5lrkGBFnR32vkOO7TcTzk/HOX8ixIlLS
7Rrfk3eKyC87pSvHM15ESVoH01pyggj9Z+23VJMTRWz4wyOxgrxXhBA1ucNj
cpKUnyf+QBF5vwjPIf+0uUVOEXHj/Qrby+RUEQHcH1vPkxXSetP6zTKTrJLa
m3tJyCBz0np1YnizhiyIGBEb9kpJ1ogwMnganEQ+LMJ/hPmMWHK6iB61rSOj
yBnS+pP7Y30g+bi0frYXviwgnxSx6mqA/SxypjTfWhK13MlZIsZkupT9Rj4r
rX+T/vSYRD4vwtDTJ9eZnC1C/dSm3ImcI8WjqXDeGHKuCOt7+idtyJdFrO7x
d/lQcp6Ic2VzOw4gXxNRsfqnNhbkfBHunc+87Ue+KcWn47CFsgtEmMbbHJR9
W8THLPsW2YUiRkds+8WMfFeE64cRo2QXSfOrwMxB9n0pX96kb5ddLGKfi62r
OblERKN4JUpuX6mI/Q1j3/5MLhMxuGTHjP7kchFm/2R4yf17Jq13RUWPZFeI
MOk39IbsShFjs2rdZVeJGLr4nwvy86pF3NVZNFN2jbS+PvGfLvuNiJXfJmfL
rpPit1JcID+vXkSd5YZ62Y0iovp0NhhIfi+itvrmXvnfP0r7V7B+jPy8z9J6
U1/qZkluElEepFkj979ZGn+vkF2yW6T+79iYJX99q7Se+i7LlJ+vpcFfBc3f
B5G1NWjuPKZ2CFlHAz5000N5vuhqYD9rwWLZHTRYGnXz6GCyngZ7979zlfvT
SYPBpjeHyO3X16Cgqa2d3J6uGgROUX+WbaABvuyaJ3+/oQapmafOye3pqUFS
+01thpONNDg5N2CkNdlYAwuUqWWbaKAZHDZ6BNlUA621a+KtyGYacOaaDLn9
FhqUdy4V5PdbatDn4ahesgdokL9qxVfZgzSInpN6Qv7+IRp8nTctWI6PldTf
+c84+X3DNeiMxw2yrTVYpZ8xWbaNBpO2Tvxf/G01KDxQ+4f8/NEaFE0JXimP
l70G48KaNsgeq4FfO6dY+esdpf6t/aYtt8dJg1nX0qbJ74MGpbXjdIeRnTWw
3hbTVfZEDXLM3ybLX+8ixfuTe6X8PFcNnti2nSbbTYNrzQ4Wst01OL0jIkD2
VGm866o+yJ6uQa7906Xy82dqYDIrYY1sDw26DR5vINtTGk/tq1Pk75+rwfVQ
dz85Xl4aHA+5I8j999Zge2dxrOyFGtg+qh4j20eDkWYv4mX7amAT+rCb/Dw/
DT4drUuXvVSDmqibtvL7/aX2xO/aLztAg7C7DudkB0nvi1sRLztYiu/wYGvZ
IRr8Pv6PPPn5YRrsTPnNQ3a4BkvWbPgst2+VBo/Vfv/Lt9UaZPxStEJ2lDT+
vnkTZa+TnhdqPFx29P/8/wAmajFH
       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 2623.}, {0, 187.34769697028042`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.867483843691392*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"fe9c158f-09ea-43c7-ae85-140323652875"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.86748384370336*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"0024a86c-8f81-4b19-921e-c95e62745586"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV13k4VdsbB3CiQpOktqmDM+xzDkIcbgP5pklSGlCJukhEpvAjJJSIBkmI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        "]]},
      Annotation[#, "Charting`Private`Tag$4097392#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7JkM89demyvvABVwOPAiRNpbWw7K53A46Jfz
5/JNGShfwMEuLDxGZJU0lC/iILdl4dllc6SgfAmHDK+I5I5NklC+jEOQ4dMU
87cSUL6CQwXrNuE6PxhfyaHESUea64Y4lK/i0BfrcIS1G8ZXc3DKMb77KB3G
13BgnHwrJzcPxtdy4LpecEdyHoyv45Bz3jUk7RuMr+fA5f0mSq4cZp+Bw64k
rp9xCjD3GTp8uat+PPITjG/kcGd+svS3NzD/GDvMDLadUc8P87+Jw/72PV4d
EbJQvqnDrX8NGziOyTkAACHmTug=
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 8.694553166296716}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674838438041515`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"272ef2bb-0deb-45ec-a8c1-d5072bad29ef"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "0.774887931524387`"}], "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", -0.774887931524387, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.867483843814064*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"d96792c6-1bdb-4c8e-a754-11a81b580120"],

Cell[BoxData[
 StyleBox["\<\"Coupling constants\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.867483843818115*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"86e8b1fc-8505-4759-aabb-4c13c27e4d66"]
}, Open  ]],

Cell[BoxData[
 TagBox[GridBox[{
    {"5.3842256842107075`"},
    {"48.74763411226208`"},
    {"2.1242904736905124`"},
    {
     RowBox[{"-", "0.06334718652116751`"}]},
    {"28.025403680282682`"},
    {
     RowBox[{"-", "0.774887931524387`"}]}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.854100465341464*^9, 3.8674752622096004`*^9, 
  3.867475734912259*^9, 3.867483162928974*^9, 3.8674838438221054`*^9},
 CellLabel->
  "Out[202]//TableForm=",ExpressionUUID->"74302186-abfe-4111-a78a-\
c0c28c834484"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Time used = \"\>", "\[InvisibleSpace]", 
   "332.6891171`9.97358358799052", "\[InvisibleSpace]", "\<\"seconds\"\>"}],
  SequenceForm["Time used = ", 332.6891171`9.97358358799052, "seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.854100071270564*^9, 3.867474827646149*^9, 
  3.867475322312959*^9, 3.8674828061062193`*^9, 3.8674838438310814`*^9},
 CellLabel->
  "During evaluation of \
In[185]:=",ExpressionUUID->"5105682c-4cb3-4c92-bfce-8b06604e0162"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1278, 1348},
WindowMargins->{{-7, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"12.0 for Microsoft Windows (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 538, 10, 69, "Subsubsection",ExpressionUUID->"e0dd5b4c-3a91-4051-9a25-a39ac98e766a"],
Cell[1121, 34, 1338, 28, 320, "Text",ExpressionUUID->"c61c22a2-f7f7-4bd3-b074-cb3183ff65e0"],
Cell[CellGroupData[{
Cell[2484, 66, 29888, 709, 1929, "Input",ExpressionUUID->"83ce1c8d-1a22-4fa3-84c9-6c6be868c2d5"],
Cell[CellGroupData[{
Cell[32397, 779, 701, 18, 29, "Print",ExpressionUUID->"547f5675-0e26-4afd-a7ce-051c01557c40"],
Cell[33101, 799, 316, 5, 22, "Print",ExpressionUUID->"b208e14c-7028-4edf-8a19-9f96457a0889"],
Cell[33420, 806, 475, 12, 22, "Print",ExpressionUUID->"415d8572-859b-4172-b1f3-3ebfe97aa327"],
Cell[33898, 820, 336, 7, 33, "Print",ExpressionUUID->"4c69ff9e-0ce3-4a98-a9d3-f8f44c4efaef"],
Cell[34237, 829, 20198, 349, 235, "Print",ExpressionUUID->"9abd0f1a-6f6e-4ba8-b3fa-d39629795fe1"],
Cell[54438, 1180, 372, 8, 33, "Print",ExpressionUUID->"e9da16a1-2474-408c-9e08-869236f624ce"],
Cell[54813, 1190, 18936, 327, 230, "Print",ExpressionUUID->"a352f2ea-f21e-4b0e-a5f4-2ca0cea56737"],
Cell[73752, 1519, 406, 8, 33, "Print",ExpressionUUID->"bd31e611-ff65-4166-9db8-88f469f5901b"],
Cell[74161, 1529, 8229, 154, 247, "Print",ExpressionUUID->"c926965d-67df-445e-926b-1c8b422a0576"],
Cell[82393, 1685, 567, 13, 22, "Print",ExpressionUUID->"b80e8da1-ddf2-43b5-a8ab-1edb13a9cc11"],
Cell[82963, 1700, 701, 18, 29, "Print",ExpressionUUID->"22129811-4356-49fd-b1d4-5d9f36c619ed"],
Cell[83667, 1720, 316, 5, 22, "Print",ExpressionUUID->"61a9a99c-7626-4209-af3c-53b81cb74ce0"],
Cell[83986, 1727, 477, 12, 22, "Print",ExpressionUUID->"3a3f31f8-cb6b-4d31-be85-c4a4adc9f756"],
Cell[84466, 1741, 336, 7, 33, "Print",ExpressionUUID->"eb67ba2c-e4d4-4824-af40-d82843f7300b"],
Cell[84805, 1750, 61925, 1033, 228, "Print",ExpressionUUID->"17e53593-dba9-4d7f-85cc-208a18799106"],
Cell[146733, 2785, 372, 8, 33, "Print",ExpressionUUID->"2c36d894-17fe-4c14-ab92-d8e329f0e1cc"],
Cell[147108, 2795, 54070, 903, 230, "Print",ExpressionUUID->"923b5769-bd81-466d-b3dd-4f0ac81b8546"],
Cell[201181, 3700, 406, 8, 33, "Print",ExpressionUUID->"408dfdc0-60a6-47bc-b7a7-44ce6ae987de"],
Cell[201590, 3710, 8171, 154, 247, "Print",ExpressionUUID->"dceeed0b-f052-4e08-ba0f-6c4aeca1a009"],
Cell[209764, 3866, 566, 13, 22, "Print",ExpressionUUID->"26f28fd4-f57b-485e-b1fe-1977d94b7d83"],
Cell[210333, 3881, 703, 18, 29, "Print",ExpressionUUID->"1b02a878-5e45-4dab-86c5-b7123ad099a7"],
Cell[211039, 3901, 316, 5, 22, "Print",ExpressionUUID->"0c2ee018-bba4-4b5d-8eec-6e0559d9f560"],
Cell[211358, 3908, 476, 12, 22, "Print",ExpressionUUID->"f94a11d3-edc0-42ba-a1ad-646a84ac6143"],
Cell[211837, 3922, 336, 7, 33, "Print",ExpressionUUID->"bf409200-f7a6-4373-8a50-bc4a6bde87b7"],
Cell[212176, 3931, 25826, 442, 236, "Print",ExpressionUUID->"1b666216-f749-47e7-a38c-68739c4e152d"],
Cell[238005, 4375, 374, 8, 33, "Print",ExpressionUUID->"fadd77f3-68a0-4a9a-b013-45e1b22d6ee6"],
Cell[238382, 4385, 24420, 417, 234, "Print",ExpressionUUID->"75078197-9f60-4e2f-99e9-9254bf5ff5cf"],
Cell[262805, 4804, 404, 8, 33, "Print",ExpressionUUID->"7b3724b1-5999-4fc8-900a-8ebcc5691bea"],
Cell[263212, 4814, 8097, 152, 247, "Print",ExpressionUUID->"9aa51359-1930-4557-9708-96dd42f901b6"],
Cell[271312, 4968, 569, 13, 22, "Print",ExpressionUUID->"ba55854f-027c-40ca-8406-295ec80612e9"],
Cell[271884, 4983, 703, 18, 29, "Print",ExpressionUUID->"499444eb-ea10-48f0-8642-4d1238e446a1"],
Cell[272590, 5003, 314, 5, 22, "Print",ExpressionUUID->"714492a3-1063-4618-8139-d47dfeff2280"],
Cell[272907, 5010, 480, 12, 22, "Print",ExpressionUUID->"fdd0caad-6996-4d3c-8dc6-4ea855b37e01"],
Cell[273390, 5024, 334, 7, 33, "Print",ExpressionUUID->"703afbf3-73c4-4e9d-94d6-9b50f3e35faa"],
Cell[273727, 5033, 22077, 380, 236, "Print",ExpressionUUID->"ed0c0b0d-05fc-47e0-9e2d-cbe170fba44a"],
Cell[295807, 5415, 372, 8, 33, "Print",ExpressionUUID->"03471da8-c3f3-46a4-b717-cdeb2a0696dc"],
Cell[296182, 5425, 21108, 363, 234, "Print",ExpressionUUID->"103136f2-cfa7-4c75-bff8-483ab1e8fa9c"],
Cell[317293, 5790, 404, 8, 33, "Print",ExpressionUUID->"e0476248-9959-44e0-aff4-d580b22d085a"],
Cell[317700, 5800, 8203, 154, 247, "Print",ExpressionUUID->"250dadad-5e28-4ff5-8179-e4fc2f6c4ded"],
Cell[325906, 5956, 586, 13, 22, "Print",ExpressionUUID->"eee4673b-f3fc-42c5-8a04-1e77152a0707"],
Cell[326495, 5971, 703, 18, 29, "Print",ExpressionUUID->"ff9a9a3e-9b26-4bc8-9341-d6432e89f97b"],
Cell[327201, 5991, 316, 5, 22, "Print",ExpressionUUID->"db0d11f5-b219-41d4-a9b6-0bfe49da0339"],
Cell[327520, 5998, 476, 12, 22, "Print",ExpressionUUID->"cdee925a-dd82-4c7a-9362-b80438e7c005"],
Cell[327999, 6012, 336, 7, 33, "Print",ExpressionUUID->"f0159633-00eb-431b-9f84-2ab583161fcb"],
Cell[328338, 6021, 68217, 1136, 227, "Print",ExpressionUUID->"2a55708e-4fa3-47b1-b608-82097a274ba1"],
Cell[396558, 7159, 372, 8, 33, "Print",ExpressionUUID->"744d543d-5a6d-4fef-8ae3-85ff6ca0f908"],
Cell[396933, 7169, 61278, 1021, 238, "Print",ExpressionUUID->"4be56be8-c6db-489f-98b6-7db7e1a555e3"],
Cell[458214, 8192, 404, 8, 33, "Print",ExpressionUUID->"82e25108-e87b-4b93-ac0a-57ee4ff8ca48"],
Cell[458621, 8202, 8091, 152, 247, "Print",ExpressionUUID->"ac3b5002-851a-4fbe-b66b-fc18a4e89fa3"],
Cell[466715, 8356, 566, 13, 22, "Print",ExpressionUUID->"7863c4ae-63af-4bea-abc6-789be5d0a912"],
Cell[467284, 8371, 700, 18, 29, "Print",ExpressionUUID->"0cf10cbe-d095-42cc-90b1-eebfef45eab2"],
Cell[467987, 8391, 316, 5, 22, "Print",ExpressionUUID->"8bb3d0bf-01b9-401e-898f-bf49676a751e"],
Cell[468306, 8398, 480, 12, 22, "Print",ExpressionUUID->"3ae718f4-621e-44b7-b501-6258ced6ee25"],
Cell[468789, 8412, 336, 7, 33, "Print",ExpressionUUID->"6ab69e16-41f4-4f0a-83db-32a97db1c395"],
Cell[469128, 8421, 38370, 647, 228, "Print",ExpressionUUID->"a06906e3-c296-4528-a50a-d598f2141324"],
Cell[507501, 9070, 372, 8, 33, "Print",ExpressionUUID->"6c5ef827-bc96-4cac-9511-9af0abcfe800"],
Cell[507876, 9080, 35632, 601, 234, "Print",ExpressionUUID->"fe9c158f-09ea-43c7-ae85-140323652875"],
Cell[543511, 9683, 403, 8, 33, "Print",ExpressionUUID->"0024a86c-8f81-4b19-921e-c95e62745586"],
Cell[543917, 9693, 8018, 151, 247, "Print",ExpressionUUID->"272ef2bb-0deb-45ec-a8c1-d5072bad29ef"],
Cell[551938, 9846, 580, 13, 22, "Print",ExpressionUUID->"d96792c6-1bdb-4c8e-a754-11a81b580120"],
Cell[552521, 9861, 342, 7, 33, "Print",ExpressionUUID->"86e8b1fc-8505-4759-aabb-4c13c27e4d66"]
}, Open  ]],
Cell[552878, 9871, 849, 25, 130, "Output",ExpressionUUID->"74302186-abfe-4111-a78a-c0c28c834484"],
Cell[553730, 9898, 512, 10, 22, "Print",ExpressionUUID->"5105682c-4cb3-4c92-bfce-8b06604e0162"]
}, Open  ]]
}, Open  ]]
}
]
*)

