(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    681040,      12168]
NotebookOptionsPosition[    672192,      12061]
NotebookOutlinePosition[    672589,      12078]
CellTagsIndexPosition[    672546,      12075]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Determination of the signs and magnitudes of all heteronuclear coupling using \
IPAP-MODO-FESTA data.
Automatically determine optimum ratio when combining IP and AP data, \
adjusting ratio and number of points to shift until rms difference is minimum\
\>", "Subsubsection",
 CellChangeTimes->{{3.835342719267295*^9, 3.8353427673607473`*^9}, {
   3.835342957217922*^9, 3.8353429845994587`*^9}, {3.853579885840021*^9, 
   3.853579910287277*^9}, 
   3.8535799927992496`*^9},ExpressionUUID->"e0dd5b4c-3a91-4051-9a25-\
a39ac98e766a"],

Cell["\<\
Automatically determines the optimum ratio when combining the IP and AP data, \
adjusts the ratio and numbers of points required to shift until the RMS \
difference is at its minimum.
Information required:
shifts={chemical shift in ppm}; (each chemical shift to be separated by a \
comma)
widths={width of multiplet in ppm}; (each width to be separated by a comma)
nreps=1; (number of repetitions of that data - typically 1)
filestart=12; (EXPNO in file)
filenamebase=\[CloseCurlyDoubleQuote]data/folder/nmr/filename/\
\[CloseCurlyDoubleQuote]; (filepath of data)
procnoIP=\[CloseCurlyDoubleQuote]1001\[CloseCurlyDoubleQuote];  (PROCNO of IP \
data)
procnoAP=\[CloseCurlyDoubleQuote]1002\[CloseCurlyDoubleQuote]; (PROCNO of AP \
data - ensure IP and AP are processed with identical parameters)

Sample details: 681 mM Fluorohydrin in DMSO-d6
H excited: 4.23 ppm (cis)
F excited: -186.415 ppm 
\
\>", "Text",
 CellChangeTimes->{{3.835344344114542*^9, 3.835344495255948*^9}, {
  3.835345752399667*^9, 3.83534578817225*^9}, {3.835416894520056*^9, 
  3.8354170090033817`*^9}, {3.8535743479833965`*^9, 3.8535743941759214`*^9}, {
  3.8535744245888777`*^9, 3.853574427182979*^9}, {3.8535799150722027`*^9, 
  3.8535802318062067`*^9}, {3.853584046988967*^9, 3.8535840819842186`*^9}, {
  3.8535889262966967`*^9, 3.8535889273155904`*^9}, {3.854020898558416*^9, 
  3.854020899546094*^9}},ExpressionUUID->"c61c22a2-f7f7-4bd3-b074-\
cb3183ff65e0"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"Context", "[", "]"}], " ", "<>", " ", "\"\<*\>\""}], "]"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"vardiff", "[", 
     RowBox[{"tspip_", ",", "tspap_", ",", 
      RowBox[{"ratio_", "?", "NumericQ"}], ",", 
      RowBox[{"diff_", "?", "NumericQ"}]}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"zspm", ",", "len"}], "}"}], ",", 
      RowBox[{
       RowBox[{"len", "=", 
        RowBox[{"Length", "[", "tspip", "]"}]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"zspm", "=", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "len"}], "}"}]}], "]"}], ",", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"tspip", "-", 
             RowBox[{"ratio", " ", "tspap"}]}], ",", 
            RowBox[{"Table", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "len"}], "}"}]}], "]"}]}], "]"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"Total", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"tspip", "+", 
           RowBox[{"ratio", " ", "tspap"}], "-", 
           RowBox[{"Take", "[", 
            RowBox[{
             RowBox[{"RotateRight", "[", 
              RowBox[{"zspm", ",", "diff"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"len", "+", "1"}], ",", 
               RowBox[{"2", " ", "len"}]}], "}"}]}], "]"}]}], ")"}], "^", 
         "2"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Calculate", " ", "variance", " ", "between", " ", "shifted", " ", 
    "spectra", " ", "obtained", " ", "by", " ", "IPAP", " ", "processing"}], 
   " ", "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"getpars", "[", 
    RowBox[{"filenamebase_", ",", "procno_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "filename", "}"}], ",", 
     RowBox[{
      RowBox[{"filename", "=", 
       RowBox[{
       "filenamebase", "<>", "\"\</pdata/\>\"", "<>", "procno", "<>", 
        "\"\</procs\>\""}]}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"stream", "=", 
       RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"offset", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<OFFSET= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"si", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<SI= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"filename", "=", 
       RowBox[{"filenamebase", "<>", "\"\</acqus\>\""}]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"stream", "=", 
       RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"sfo1", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<SFO1= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"swp", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<SW= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"offset", ",", "si", ",", "sfo1", ",", "swp"}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"process", "[", 
     RowBox[{
     "filenamebaseIP_", ",", "filenamebaseAP_", ",", "shift_", ",", "width_", 
      ",", "swp_", ",", "offset_", ",", "si_", ",", "sfo1_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "diff", ",", "dip", ",", "start", ",", "end", ",", "hzpp", ",", 
        "ncproc", ",", "spip", ",", "spap"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseIP", "<>", "\"\</procs\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"stream", "=", 
        RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ncproc", "=", 
        RowBox[{
         RowBox[{"Read", "[", 
          RowBox[{
           RowBox[{"StringToStream", "[", 
            RowBox[{"Find", "[", 
             RowBox[{"stream", ",", "\"\<NC_proc= \>\""}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Need", " ", "to", " ", "correct", " ", "for", " ", "any", " ", 
         "difference", " ", "in", " ", "scaling", " ", "during", " ", "FT", 
         " ", 
         RowBox[{"etc", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseIP", "<>", "\"\</1r\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"spip", "=", 
        RowBox[{
         RowBox[{"2.", "^", "ncproc"}], " ", 
         RowBox[{
          RowBox[{"Import", "[", 
           RowBox[{"filename", ",", "\"\<Integer32\>\""}], "]"}], "/", 
          RowBox[{"10", "^", "6"}]}]}]}], ";", " ", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseAP", "<>", "\"\</procs\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"stream", "=", 
        RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ncproc", "=", 
        RowBox[{
         RowBox[{"Read", "[", 
          RowBox[{
           RowBox[{"StringToStream", "[", 
            RowBox[{"Find", "[", 
             RowBox[{"stream", ",", "\"\<NC_proc= \>\""}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Need", " ", "to", " ", "correct", " ", "for", " ", "any", " ", 
         "difference", " ", "in", " ", "scaling", " ", "during", " ", "FT", 
         " ", 
         RowBox[{"etc", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseAP", "<>", "\"\</1r\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"spap", "=", 
        RowBox[{
         RowBox[{"2.", "^", "ncproc"}], " ", 
         RowBox[{
          RowBox[{"Import", "[", 
           RowBox[{"filename", ",", "\"\<Integer32\>\""}], "]"}], "/", 
          RowBox[{"10", "^", "6"}]}]}]}], ";", " ", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"hzpp", "=", 
        RowBox[{"swp", " ", 
         RowBox[{"sfo1", "/", 
          RowBox[{"(", 
           RowBox[{"si", "-", "1"}], ")"}]}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"start", "=", 
        RowBox[{"Round", "[", 
         RowBox[{"sfo1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"offset", "-", "shift", "-", 
             RowBox[{"width", "/", "2"}]}], ")"}], "/", "hzpp"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"end", "=", 
        RowBox[{"Round", "[", 
         RowBox[{"sfo1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"offset", "-", "shift", "+", 
             RowBox[{"width", "/", "2"}]}], ")"}], "/", "hzpp"}]}], " ", 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tspip", "=", 
        RowBox[{"Take", "[", 
         RowBox[{"spip", ",", 
          RowBox[{"{", 
           RowBox[{"start", ",", "end"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"len", "=", 
        RowBox[{"Length", "[", "tspip", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tspap", "=", 
        RowBox[{"Take", "[", 
         RowBox[{"spap", ",", 
          RowBox[{"{", 
           RowBox[{"start", ",", "end"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<Chemical shift = \>\"", ",", "\"\<Subsection\>\""}], 
          "]"}], ",", 
         RowBox[{"Style", "[", 
          RowBox[{"shift", ",", "\"\<Subsection\>\""}], "]"}], ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\< ppm\>\"", ",", "\"\<Subsection\>\""}], "]"}]}], "]"}],
        ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{
         "Do", " ", "optimistion", " ", "in", " ", "two", " ", "stages"}], 
         ",", " ", 
         RowBox[{
         "otherwise", " ", "fails", " ", "to", " ", "find", " ", "global", 
          " ", "minimum"}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"res1", "=", 
        RowBox[{"NMinimize", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"vardiff", "[", 
             RowBox[{"tspip", ",", "tspap", ",", "fratio", ",", 
              RowBox[{"5", " ", "fdiff"}]}], "]"}], ",", 
            RowBox[{"fdiff", ">", 
             RowBox[{
              RowBox[{"-", "len"}], "/", "5"}]}], ",", 
            RowBox[{"fdiff", "<", 
             RowBox[{"len", "/", "5"}]}], ",", 
            RowBox[{"fratio", ">", "0.8"}], ",", 
            RowBox[{"fratio", "<", "1.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"fdiff", "\[Element]", " ", "Integers"}], ",", "fratio"}],
            "}"}], ",", 
          RowBox[{"MaxIterations", "\[Rule]", "100"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"res2", "=", 
        RowBox[{"NMinimize", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"vardiff", "[", 
             RowBox[{
             "tspip", ",", "tspap", ",", "fratio", ",", " ", "fdiff"}], "]"}],
             ",", 
            RowBox[{"fratio", ">", "0.8"}], ",", 
            RowBox[{"fratio", "<", "1.2"}], ",", 
            RowBox[{"fdiff", ">", 
             RowBox[{
              RowBox[{"Round", "[", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"5", " ", "fdiff"}], "/.", 
                 RowBox[{"res1", "[", 
                  RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "]"}], "-", 
              RowBox[{"len", "/", "10"}]}]}], ",", 
            RowBox[{"fdiff", "<", 
             RowBox[{"Round", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"len", "/", "10"}], "+", 
                RowBox[{"5", " ", "fdiff"}]}], "/.", 
               RowBox[{"res1", "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"fdiff", "\[Element]", " ", "Integers"}], ",", "fratio"}],
            "}"}], ",", 
          RowBox[{"MaxIterations", "\[Rule]", "1000"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
       "Print", "[", "\"\<Variance and optimised shift and ratio:\>\"", "]"}],
        ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "res2", "]"}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{"ratio", "=", 
        RowBox[{"fratio", "/.", 
         RowBox[{"res2", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"spp", "=", 
        RowBox[{"tspip", "+", 
         RowBox[{"ratio", " ", "tspap"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"spm", "=", 
        RowBox[{"tspip", "-", 
         RowBox[{"ratio", " ", "tspap"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<Input data\>\"", ",", "\"\<Subsection\>\""}], "]"}], 
        "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"ListPlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"spp", ",", "spm"}], "}"}], ",", 
          RowBox[{"Joined", "\[Rule]", "True"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"len", "=", 
        RowBox[{"Length", "[", "spp", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"zspm", "=", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "len"}], "}"}]}], "]"}], ",", 
          RowBox[{"Join", "[", 
           RowBox[{"spm", ",", 
            RowBox[{"Table", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "len"}], "}"}]}], "]"}]}], "]"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"diff", "=", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{
             RowBox[{"2", " ", "len"}], "+", "1"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "\[LessEqual]", 
          RowBox[{"Length", "[", "diff", "]"}]}], ",", 
         RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"diff", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "=", 
           RowBox[{"Total", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"spp", "-", 
               RowBox[{"Take", "[", 
                RowBox[{
                 RowBox[{"RotateRight", "[", 
                  RowBox[{"zspm", ",", 
                   RowBox[{"len", "-", "i"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"len", "+", "1"}], ",", 
                   RowBox[{"2", " ", "len"}]}], "}"}]}], "]"}]}], ")"}], "^", 
             "2"}], "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\n", 
       RowBox[{"Print", "[", 
        RowBox[{"Style", "[", 
         RowBox[{
         "\"\<RMS difference vs displacement in data points\>\"", ",", 
          "\"\<Subsection\>\""}], "]"}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"ListPlot", "[", 
         RowBox[{"diff", ",", 
          RowBox[{"Joined", "\[Rule]", "True"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"min", "=", 
        RowBox[{"Min", "[", "diff", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "\[LessEqual]", 
          RowBox[{"Length", "[", "diff", "]"}]}], ",", 
         RowBox[{"i", "++"}], ",", " ", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"diff", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "\[Equal]", "min"}], ",", 
            RowBox[{"minpoint", "=", "i"}]}], "]"}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"Style", "[", 
         RowBox[{
         "\"\<Expansion of RMS difference vs displacement in data points, \
with parabolic fit\>\"", ",", "\"\<Subsection\>\""}], "]"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"dip", "=", 
        RowBox[{"Take", "[", 
         RowBox[{"diff", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"minpoint", "-", "10"}], ",", 
            RowBox[{"minpoint", "+", "10"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"dipfit", "=", 
        RowBox[{"NonlinearModelFit", "[", 
         RowBox[{"dip", ",", 
          RowBox[{"a", "+", 
           RowBox[{"b", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"x", "-", "x0"}], ")"}], "^", "2"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"a", ",", "b", ",", "x0"}], "}"}], ",", "x"}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"Show", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Plot", "[", 
            RowBox[{
             RowBox[{"dipfit", "[", "x", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", "1", ",", 
               RowBox[{"Length", "[", "dip", "]"}]}], "}"}], ",", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"All", ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", 
                  RowBox[{"1.1", " ", 
                   RowBox[{"Max", "[", "dip", "]"}]}]}], "}"}]}], "}"}]}]}], 
            "]"}], ",", 
           RowBox[{"ListPlot", "[", 
            RowBox[{"dip", ",", 
             RowBox[{"Joined", "\[Rule]", "False"}], ",", 
             RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "}"}], "]"}],
         "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<Interpolated frequency shift with best match is \>\"", ",", 
         RowBox[{
          RowBox[{"-", "hzpp"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"x0", "/.", 
              RowBox[{"dipfit", "[", "\"\<BestFitParameters\>\"", "]"}]}], 
             ")"}], "+", "minpoint", "-", "11", "-", "len"}], ")"}]}], ",", 
         " ", "\"\< Hz\>\""}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"-", "hzpp"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"x0", "/.", 
            RowBox[{"dipfit", "[", "\"\<BestFitParameters\>\"", "]"}]}], 
           ")"}], "+", "minpoint", "-", "11", "-", "len"}], ")"}]}]}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"shifts", "=", 
   RowBox[{"{", 
    RowBox[{
    "4.8956", ",", "4.4494", ",", "3.7426", ",", "3.3741", ",", "1.9039", ",",
      "1.7623", ",", "1.6337", ",", "1.4927"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"widths", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.045", ",", "0.15", ",", "0.06", ",", "0.06", ",", "0.13", ",", "0.11", 
     ",", "0.08", ",", "0.09"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"njs", "=", 
   RowBox[{"Length", "[", "shifts", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nreps", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"filestart", "=", "13"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"js", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", "njs", ",", "nreps"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "filenamebase", "=", 
   "\"\<V:/dropbox/Coral/_Projects/_Publications/IPAP FESTA/Fluorohydrin \
data/data/GDP_fluorohydrinDMSO_thais/GDP_fluoridrina_thais/nmr/\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"procnoIP", "=", "\"\<1001\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"procnoAP", "=", "\"\<1002\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"getpars", "[", 
   RowBox[{
    RowBox[{"filenamebase", "<>", 
     RowBox[{"ToString", "[", "filestart", "]"}]}], ",", "procnoIP"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"starttime", "=", 
   RowBox[{"AbsoluteTime", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"jnumber", "=", "1"}], ",", 
    RowBox[{"jnumber", "\[LessEqual]", 
     RowBox[{"Length", "[", "shifts", "]"}]}], ",", 
    RowBox[{"jnumber", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"rep", "=", "1"}], ",", 
       RowBox[{"rep", "\[LessEqual]", "nreps"}], ",", 
       RowBox[{"rep", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"filename", "=", 
         RowBox[{"filenamebase", "<>", 
          RowBox[{"ToString", "[", 
           RowBox[{"filestart", "+", "rep", "-", "1"}], "]"}], "<>", 
          "\"\</pdata/\>\""}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"js", "[", 
          RowBox[{"[", 
           RowBox[{"jnumber", ",", "rep"}], "]"}], "]"}], "=", 
         RowBox[{"process", "[", 
          RowBox[{
           RowBox[{"filename", "<>", "procnoIP"}], ",", 
           RowBox[{"filename", "<>", "procnoAP"}], ",", 
           RowBox[{"shifts", "[", 
            RowBox[{"[", "jnumber", "]"}], "]"}], ",", 
           RowBox[{"widths", "[", 
            RowBox[{"[", "jnumber", "]"}], "]"}], ",", "swp", ",", "offset", 
           ",", "si", ",", "sfo1"}], "]"}]}], ";"}]}], "\[IndentingNewLine]", 
      "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"Style", "[", 
    RowBox[{"\"\<Coupling constants\>\"", ",", "\"\<Subsection\>\""}], "]"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"TableForm", "[", "js", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"jslb1", "=", "js"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"timeused", "=", 
   RowBox[{
    RowBox[{"AbsoluteTime", "[", "]"}], "-", "starttime"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<Time used = \>\"", ",", "timeused", ",", "\"\<seconds\>\""}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"meansdandsdmean", "[", "x_", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Mean", "[", "x", "]"}], ",", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"Variance", "[", "x", "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Length", "[", "x", "]"}], "-", "1"}], ")"}], ")"}]}], 
      "]"}], ",", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"Variance", "[", "x", "]"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Length", "[", "x", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Length", "[", "x", "]"}], "-", "1"}], ")"}]}], ")"}]}], 
      "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"nreps", ">", "1"}], ",", 
    RowBox[{
     RowBox[{"reslb1", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"Length", "[", "shifts", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"reslb1", "=", 
      RowBox[{"Prepend", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"shifts", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"meansdandsdmean", "[", 
              RowBox[{"jslb1", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Length", "[", "shifts", "]"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Shift / ppm\>\"", ",", "\"\<JHF / Hz\>\"", ",", 
          "\"\<std dev / Hz\>\"", ",", "\"\<sd of mean of J / Hz\>\""}], 
         "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"TableForm", "[", "reslb1", "]"}], "]"}], ";"}]}], "]"}], 
  "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.833448292510956*^9, 3.833448473320225*^9}, {
   3.833448567630739*^9, 3.833448597926832*^9}, {3.833448726706624*^9, 
   3.8334488386106873`*^9}, {3.833448894130322*^9, 3.83344899381962*^9}, {
   3.8334490263559*^9, 3.833449034371501*^9}, {3.833449208176523*^9, 
   3.83344924369489*^9}, {3.8334515420085583`*^9, 3.833451676813837*^9}, {
   3.8335325651614*^9, 3.833532637209276*^9}, {3.833532759034121*^9, 
   3.8335330239765873`*^9}, {3.8335330927635307`*^9, 
   3.8335331455943604`*^9}, {3.833533397697961*^9, 3.8335334255106373`*^9}, {
   3.8335334594455547`*^9, 3.833533507765386*^9}, {3.833533539339788*^9, 
   3.833533659575992*^9}, {3.833533697198904*^9, 3.8335337340891523`*^9}, {
   3.833533780205265*^9, 3.833533893496993*^9}, 3.833533985781467*^9, {
   3.8335340192182083`*^9, 3.833534070521394*^9}, {3.833534125296022*^9, 
   3.833534125914562*^9}, 3.833534226165428*^9, {3.833534380477125*^9, 
   3.833534380818433*^9}, {3.8335344656134453`*^9, 3.833534519575261*^9}, {
   3.8335346317293777`*^9, 3.83353463272573*^9}, 3.8335347268726482`*^9, {
   3.8335347781741343`*^9, 3.83353485994346*^9}, {3.833534904539554*^9, 
   3.83353494839614*^9}, {3.833534999551011*^9, 3.833534999698493*^9}, {
   3.833535037301165*^9, 3.833535103927022*^9}, {3.8335351368517733`*^9, 
   3.833535139414091*^9}, {3.8335352378369083`*^9, 3.833535337311174*^9}, {
   3.833535394550235*^9, 3.833535454170685*^9}, {3.8335361679797087`*^9, 
   3.8335362375090513`*^9}, {3.833536274111115*^9, 3.833536278469448*^9}, 
   3.833536449477241*^9, {3.8335364826240788`*^9, 3.8335365448917313`*^9}, {
   3.833538035225528*^9, 3.833538077529106*^9}, {3.8337034631307096`*^9, 
   3.833703463865309*^9}, {3.833703506926898*^9, 3.833703553753542*^9}, {
   3.833703617125688*^9, 3.833703688345792*^9}, {3.833703718670663*^9, 
   3.8337037764894876`*^9}, {3.8337038223632317`*^9, 
   3.8337039123907833`*^9}, {3.83370394998801*^9, 3.833704007351994*^9}, {
   3.833704056375489*^9, 3.833704136756112*^9}, {3.833704176289364*^9, 
   3.833704289758876*^9}, {3.833704391066206*^9, 3.833704429891245*^9}, {
   3.833704972721045*^9, 3.8337049956209497`*^9}, {3.8337050367076*^9, 
   3.833705038457287*^9}, {3.8337053194184847`*^9, 3.833705411458173*^9}, {
   3.8337070792528667`*^9, 3.833707127605337*^9}, {3.835337695095479*^9, 
   3.835337749538929*^9}, {3.835338577798208*^9, 3.835338620041452*^9}, {
   3.835338653990897*^9, 3.835338823765335*^9}, {3.835338865410541*^9, 
   3.835338962622757*^9}, {3.83533899622244*^9, 3.8353390024553337`*^9}, {
   3.835339165977964*^9, 3.835339170838904*^9}, {3.835339226586821*^9, 
   3.835339252159419*^9}, {3.8353394292671547`*^9, 3.835339457784766*^9}, {
   3.835339500275881*^9, 3.8353395120074873`*^9}, 3.8353400097312202`*^9, {
   3.835340043255178*^9, 3.835340049105363*^9}, {3.835340320155546*^9, 
   3.8353403214856653`*^9}, {3.8353429884303017`*^9, 3.835343088575757*^9}, {
   3.835343169936596*^9, 3.83534322437465*^9}, {3.835343746121127*^9, 
   3.8353437642293177`*^9}, {3.8353445222541227`*^9, 3.835344552148288*^9}, {
   3.835344620203895*^9, 3.835344716850436*^9}, {3.835344824168634*^9, 
   3.835344832897682*^9}, {3.835344894608045*^9, 3.835344999609126*^9}, {
   3.8353450692229977`*^9, 3.835345143285017*^9}, {3.835345243601369*^9, 
   3.835345244855967*^9}, 3.8353452928938713`*^9, {3.835345339394802*^9, 
   3.835345341993548*^9}, {3.835345390387436*^9, 3.835345394595192*^9}, 
   3.835345505879159*^9, {3.835345633336461*^9, 3.835345726337473*^9}, {
   3.8353458377226467`*^9, 3.835345843828887*^9}, {3.835372061030136*^9, 
   3.835372071264954*^9}, {3.835372109388467*^9, 3.83537218434414*^9}, 
   3.835372522290762*^9, {3.8354170700934362`*^9, 3.835417083829755*^9}, {
   3.835417167922065*^9, 3.835417196326001*^9}, {3.835418223179352*^9, 
   3.835418229883106*^9}, {3.835418393819128*^9, 3.835418488516716*^9}, {
   3.835418519132303*^9, 3.835418537842663*^9}, {3.83542543494832*^9, 
   3.835425472964828*^9}, 3.8354255498612223`*^9, {3.835425690259713*^9, 
   3.83542571399114*^9}, {3.835431541550761*^9, 3.835431541640277*^9}, {
   3.852979611453643*^9, 3.852979691319852*^9}, {3.8529797654116774`*^9, 
   3.852979781170024*^9}, {3.852979821986277*^9, 3.8529798368790913`*^9}, 
   3.852982940810091*^9, {3.8535786610591493`*^9, 3.853578743107206*^9}, {
   3.8535791499440546`*^9, 3.853579151302937*^9}, 3.8535799422709336`*^9, {
   3.8535838939871745`*^9, 3.8535838969618187`*^9}, {3.8535840894390697`*^9, 
   3.853584130737338*^9}, {3.853584364500019*^9, 3.853584414180328*^9}, {
   3.853584583050776*^9, 3.8535845835084496`*^9}, {3.8535893677640505`*^9, 
   3.853589368218996*^9}, {3.8540210545617766`*^9, 3.854021054731043*^9}, {
   3.8540210878247185`*^9, 3.854021137632004*^9}, {3.854021176932391*^9, 
   3.854021205049368*^9}, {3.854021424118428*^9, 3.854021435280898*^9}, {
   3.85410090918059*^9, 3.8541009136872745`*^9}, 3.867477688425621*^9, {
   3.867484182799741*^9, 3.867484194580062*^9}},
 CellLabel->
  "In[208]:=",ExpressionUUID->"83ce1c8d-1a22-4fa3-84c9-6c6be868c2d5"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["4.8956`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[4.8956, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484232019315*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"6950d68f-8f34-41c3-9323-68f22669f5c5"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674842552694054`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"ee7c6538-d223-4b8d-9d8a-97c3573c0fca"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.1515940072234285`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", "199"}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.9844294193697442`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484255275389*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"783eb339-984c-44de-bf26-0315e9cfd726"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674842552783804`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"dee9a0a6-6a19-4e95-8953-e6794165f212"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9mHlcjN37x4dE8mCIyvoMkexjiWT7SCoRU7SgMlEpbdM+7fcMkoipRIoa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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9mHlcTdv//49CkeGUyFhHkjKk4iLjy1giUtGcU9I8nOZBap+4ilwOmTOc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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 591.}, {-0.088233169894646, 3.541907440186754}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674842553501883`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"69101572-58f4-4b90-bd10-fbb437459a06"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484255659478*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"8ae74ebd-bc5b-408d-bc20-a3b64cbb51bc"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxF3HdYE9vWB+DYUZETLIgdOzZEsSAWfjbAhoiiIEUERETA0DuEUJJQE2zY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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1183.}, {0, 2974.175364554888}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674842557175007`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"dda4dbda-4a81-4bfa-a7a1-b95e35cc79ab"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484255722644*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"74baf4e9-011e-43d1-82e8-087505c1eaec"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVlnk8VP8XxidU1iiyRLaZubMgMwyh8jm0oKQUlSVFWSJEKkkIhVQkIZVU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        "]]},
      Annotation[#, "Charting`Private`Tag$4168470#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7LW80nYw3zNxgAo4JLB/6bUNNITyORy2L/NZ
7G+rA+ULODz9+vnPt1Y1KF/EoYzhtF11pSKUL+Ew62qVZ4eJFJQv42DV8/Jz
6j0hKF/B4VaTrW4BMxeUr+QglyexVjOCEcpXcXgezblxatt3ewhfzUFqa8m1
tzmfoHwNB0n9lI316p+hfC0Hv+ptzisqfkL5Og4CbOV9U+YxQc3Tc4go+2B0
24YbyjdwWHW+z7g3VBjKN3SYIFmRWt4Ec6+Rw4JZFv6fpsP8Y+xwrmzT1fPr
Yf41cbiwxWpNZwssPEwdCr6udg9vN3QAADIoVKk=
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 22.953968694181807`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484255812402*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"a540bf6b-0ee5-4c74-bb38-dd3edbd645b7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", "7.573319576608222`", 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", 7.573319576608222, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484255822375*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"da1d46e4-881e-492e-853a-6c31c6d158bc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["4.4494`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[4.4494, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674842564677124`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"82e9f9a2-671d-435c-935b-a976de9a04c7"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674843196187825`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"e88cdd7f-303b-4101-8487-580e298df583"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"27.443092476730712`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", "1277"}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.9359921514554316`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484319624761*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"ff0c5677-6125-4920-88c2-bbd745545a18"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674843196277523`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"fa1f63ca-55f4-4efc-a754-360de6b475d1"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw0XHlczN33H4QQBknWZ1AJIUQhvBGyJbIU0VAqhFFJ2kz7VFNNs88IgxDC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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw0XHlcjN/bHiQhhCS+IXvWJkKIrrKFkERRMiWpVEb73rRP+1TTqjIIlSIJ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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1967.}, {-0.6062497681452811, 5.13115790091927}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674843197215023`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"8d52e2a8-b22f-453d-bc79-b5f2d09a3d9e"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484323108977*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"4c0c3d35-070b-410c-b09b-307f26f48e24"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxEm3lcjN37x0MIIQlJSJKQhBBZPlIJIUkqISoqlfZNZdr3mmlmaqZCEkII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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 3935.}, {0, 8433.130943079996}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484323204525*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"ae62b28b-e23c-4f4e-a7c8-0f5f32817561"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.86748432320951*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"fa76739c-5454-45c7-a8f6-640de207f961"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVlnk4lG8Xx5WSUCnSooSZZ8YW0jRtyjc9M3YN2VIR2SWUSqKfKHsaEpIs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        "]]},
      Annotation[#, "Charting`Private`Tag$4239483#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7DceFDrfKTvBASrgIKt4Z37Jyi4on8Nh01zu
y5+rWqF8AYcHLF+2WhxogPJFHNpSeecVC1VC+RIOHxrbma+fLITyZRwcPOda
dTWnQ/kKDmWrVdSj3GOgfCWHnObmhRMy/aB8FQcf04h15bwOUL6aQ81Kg6a8
QmsoX8MhT2NpgnWpO5Sv5SC6d+bTjd1hUL6Ow5RtbeasE5KhfD2HCbYnZ5XN
yIPyDRx2LFl+nV2yDMo3dOB/VOr6X7gOyjdyyMrk53nV3wzlGzvwmElt7Ovr
gPJNHHbN3L2k9GsvlG/qoMkYLH/m5kQHAEcyVFk=
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 1256.694272066727}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674843233250546`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"a5fcf837-4b5d-44e7-b37e-f34e2cf69719"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", "48.725041724217135`", 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", 48.725041724217135`, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484323332038*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"b7451008-35b4-4cd5-a642-e424a63305b6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["3.7426`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[3.7426, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674843239003305`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"9729f968-9fa1-4310-9294-2dd29209602b"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.86748435466308*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"088a3daa-f2eb-4cae-92fe-ce0d72a37171"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.2196550582881243`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", 
      RowBox[{"-", "3"}]}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.9290875878955083`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484354668067*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"dc6df369-7b49-4893-a7c9-860da7afaf8f"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674843546710606`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"c13f32a0-dfb1-45b9-9dfc-2c4396b9168b"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1mnlcjPsXx6eylCVxy5JiELInVBR9SkpRopAsTfte077X7DO6lm5C9rlZ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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9mnlczN/3x4si9ElUSlnGvieSIvRClFJGUkkybVq0TPu0zzRLEQpJQoa0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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 787.}, {-0.025045892292145315`, 2.867588506238092}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674843547575707`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"b18f7f1e-8969-4870-b232-0ba44846a07b"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674843553025284`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"0398dd62-8433-4b26-9dc4-d5b084da3ef7"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxFnXlczcv/x0PcJGQPIZVUkhBCeEkIISQhaS9J+76e9tN+zulsiJKQPQlJ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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1575.}, {0, 1991.3242509096585`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674843553762355`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"0d7b965f-0ec6-47b7-9861-d84b87ae4469"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674843553842134`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"c1f05455-4688-4468-915b-a03dca14c77f"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVV3k41N8bZWbskqIU0myfmSEhTbIUJ0lEi0qkVMYYytai8hWRRNGiUkSS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        "]]},
      Annotation[#, "Charting`Private`Tag$4310855#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7K0My6y6DqU4QAUc3iRZ7vb7lgDlczgciddb
suNfFJQv4LCpa3JqxYkQKF/EIe6zs6bgKj8oX8Lhh9rmVY3RrlC+jMOBSb0z
OLKsoXwFh+9tzalrBPShfCWHDhuBhsRlMlC+ioOWYt/bx/+ZoHw1h10/d7Nu
bf5sD+FrOFRfO3509WZeqLyWw74cg8g9K5WhfB2HGdq8AtItxlC+noOnz9f1
nWEOUL6BA2fBcdu5Mz2gfEOHNCWnORNsA6F8I4dtxyRrFn4Jg/KNHRry9k3g
y4iF8k0c1JwP9bm5JUH5pg63Np36ulwrzQEAjY5WSw==
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 195.0663032393316}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484355513945*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"0f459a84-e3e0-4273-93de-b3cea03d4dc0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "0.10774000237952099`"}], "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", -0.10774000237952099`, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674843555229225`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"18ace200-d469-41e8-9078-1a3b9c47208f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["3.3741`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[3.3741, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674843560983887`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"e61b563d-b9d3-49f6-80a9-0194a8b001c3"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674843858969774`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"b1509ce6-399c-43df-a2ee-e76a9cf5ebe3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.8528359803735386`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", "80"}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.9557912127570845`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484385901964*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"a7675a21-106e-4497-9916-8e2547e25c59"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484385904956*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"ebf3f5fa-8d82-4117-8948-e1b40720379f"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1mnlczN0Xx0c86iEZCUkYKkIoa2X72CNLCFFqStLetE/77DMIY0sII1tI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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9mnlczN/3xytUsmWJPvh8TCLJNhFSySuJsk6hRcpItGfap32apmbskSVK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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 788.}, {-0.006427541453172772, 3.298032158446342}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674843859837446`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"3c2b5d42-0d77-4174-96f4-d60f6764924f"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674843866020927`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"4f50371f-2a8f-451b-b0d8-a01b48297649"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxFnXlczc3bx0MokoTuJGQPISRF9JFKQpIkWqRSSdK+L6d9r9PpnNNBlJAQ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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1577.}, {0, 1653.0562172880304`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484386686157*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"f3d05827-1259-4369-8695-26f9493d2a19"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484386693139*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"2733e9b4-12a8-4801-b32b-e4042625b0db"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVVnk4lV8XJfVeY8YSZbz3vveap5tEWCRRfkqFQqaECCWkKJIpISFkTooG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        "]]},
      Annotation[#, "Charting`Private`Tag$4381781#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7Hd5dXb5FCc4QAUcip4n7mpUi4byORxUNokV
n7sbCuULOAS4uv0zFQuE8kUcphVv0jy4yRPKl3A4fjem8kmCE5Qv49BQHP3C
us8CyldwqLOwXvP0tC6Ur+RQUn9vnWqZPJSv4vBr557Q70I8UL6ag9lzj3Dz
pX/tIXwNh4e+K9pMldmh8loO3Yn3WM6kS0H5Og4OLMb6hvc1oXw9hyPzLyZ7
XTWF8g0cFpeIhf2Y5QDlGzpMXreEYXu1O5Rv5PDKqbBrdq0/lG/scERJQvik
ewiUb+KgYFd9eLp/JJRv6vBK66DwmjNxDgBj51Re
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 144.76340274330434`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674843867769156`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"3384d715-427e-4a55-a935-2d030fb6e164"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", "3.045832811380205`", 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", 3.045832811380205, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484386783896*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"0ed5db94-ba66-4b59-a51b-340f159edc08"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["1.9039`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[1.9039, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674843873419437`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"a52f9210-ea4c-4bd0-8716-bdd0f2311390"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674844466043453`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"a83cfb32-a66d-4ff6-bde2-d7df685b4e25"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3.863523177963832`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", "239"}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.9450456436712198`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674844466083336`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"36408843-d4dd-470e-a700-c35130ed1b39"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674844466103277`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"02ced007-93fa-4a13-bb3c-01784ca760f0"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw8XXtYjNvbHueQ5FQhjIQiJCGEG0kRooMQRookSaXzYTpP56mmaSbJSFEJ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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw8XXlcTN3/H54khEoSilJIohBC8kYIIYRKMtFGpX1fTPu0z0zLTEmSIrQh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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1704.}, {-0.09691418734999976, 2.013065205344414}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484446693538*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"e610d8c5-4b4a-428a-a680-c317b850ca28"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.86748444919585*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"4ceaf803-b54c-451e-9c29-486351232df4"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxE3HlcTN//B/AQQlQkIWTPlhCyvxCSECqhqKRC0qq9pn2vaZqmaSbJHkIS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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 3409.}, {0, 1339.227184614938}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674844493245564`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"a597b790-4361-4e89-8754-b30813626dff"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484449330541*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"efdbf6d0-254c-4d9b-9f37-6e23d8c789b9"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVl3k01N8fxi0lSTUzlhAyZj5jLElMEsVjqSiRrZQ2ihZrUSlLviJSSlKW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        "]]},
      Annotation[#, "Charting`Private`Tag$4452909#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7O/8v2PuZhvkABVwaFvht2ChqB+Uz+GQkPdh
rpuLB5Qv4LBJ2rPLgN8ZyhdxKDr+OF7jrw2UL+FQGmXk+MjYFMqXcYgze7vT
cb4ulK/gcC4uwF9xmzKUr+Rw/dpDk+0VklC+igODuY58RYUglK/m0NXFer3u
BR+Ur+EwS9Bq56UMYShfy0FEUNI5w0MWytdxsJ3wP/9+nRqUr+fwa0pU+qPZ
BlC+gQN3mbXp4gRzKN/QIe6s6PuSNnso38iBZWr9lNlNLlC+scPiLv3SrJee
UL6JAw9b9aJ7H/yhfFOHSXsLJr12D3YAAAdPULI=
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 84.83612849341199}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674844494049697`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"eafb8218-fabb-4a28-85c1-6defa511895a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", "9.122802660371008`", 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", 9.122802660371008, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674844494109535`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"a2260e71-0197-4880-942e-4d25ce03a99a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["1.7623`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[1.7623, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674844499356775`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"94c14829-2395-488a-8237-6e2b6f46d7e1"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674844990538473`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"479b4216-1886-4c8f-96db-7c19bb703865"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2.742148820304993`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", "472"}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.9221098344517137`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484499058835*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"071cef7b-eddf-4249-bd08-4970ce5f2ef4"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674844990618258`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"c50a16f9-4f43-4ebd-97b7-811284d43678"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9nHlcTN//xwchSUIIyaAowqAIxSuizTISktQgqRRDRXvTPu2zJqmMPQlJ
CKmxJYQQkm0skT0+luy/+314359/PJ6d9X3ey3mfO+fewSvWua5qz+Fwdnbk
cP73/79/rdMi5grnjbmbW01/QGJpyNshnXYSa2NuyFXj3CF7iPUx6pxxhe73
XcQG8O8x2SR9sIrYEDvOFRtePCcjNoLRNz+/2twwYi4q3t1dcKnFbdo/HoJ6
Yx1l+dP5xCb41MAb7VsaQfWHgdNg/jRls5zYDJeNv0+su8qONwIL2617VDeZ
nZ8FGt0/Wt9JKiIeDe3GUpvV1nuJebiV8eBA0gBWvrFo6Dt3r8P7rcTjEL1a
/GT7e3a88XiT7Gk4/pqU2BKi07XZuV03E1thttHxAwGTthNPgKuZ76X0Gez4
E7EowO60Zs1BYmvsWrhucbvWUuJJSJ9tvLXgC8uTsfDN3rkdLA8RT0GLMkbn
qPd+YhsM7Zt4yO3/+7eF34Y5Rl3asfJNxfuBi8clxbI8DXO3aHe9KGLrA11q
Cu+o+MQi4H1bxZiiY7up3A5mveOydh6m9RXZQc2PiaoZr6Ty6XCUacxdXZKp
fDoUe/f4xAdFUfkMvHsx82b71UlUPgOay14zrEMVVG6PtbHGi85NZvu3h2W5
4sC0nuz4M9ESu3mY7miav2gmRH2WGR9eyOp3Fgxee7QlqEh/oll4GqKqHF/L
2oMDru3tVz08uJDKHTDJ987PfjXEHEes+ex369sWdnxH+NisSBq1ldWfE7rr
PjY1XkQsckK9ocvZdn23UbkzhuSd2FV1ZQuVO+OgwNHieAd2fVzg3jLG9OFy
sn+RC/aOLTjd7w5rP7PRp2ugRYKcWDQbBnv2DLy0LIvK58CyRObwVhpP5XMg
aHQJusBzovK5mN1j8bw5sVH//EU0F4G3UhoqDyeS/8wDd/iEmO83NlH5PDQa
rZ0ZvoD1Pz4y0hRrLJJz/jH4EA47FDmmF7uefMQvW+KzrzvZh5qPs6Ov724c
so/az4csZOXP/d1IP5iPYe1lOaI/bPv5eHH/W8cXQTuo/XxUdVU4zL7F+psr
PNsbXze/z7Z3xTrvSw8MxCXU3hVuz71Tr/LI/tWu8I0vnsl5cIDaL8CI9M8x
L5xofliAwJyvS3imrD4XgD+sLvZmgoTaL4Ag/3Re94VsPHGDaNi2uOHGIdTe
DQJ/SdSsv4nU3g2qDsN3NqWR/tRu0L8Pl8wnrL8vRP1Hn1+L2hFjIThDwx/p
VmVT+4UQ/bDQG3dgE7VnuO6HRVSGO+lnEUSd9f0MDy79x1gEldvDhVFboqn9
InBc+p+7MY/isXoRSpIt3Hr/f3xbDO35T+v1O9D6YDFKK6c86dGxjNovht+B
zSePdCFWLwZ0syXf17DxxB2V73bZHNzPrr87Sh/N074wivUXd6gsC+oqUkke
tTtQbFzVsZz17yVAh++m1hWh1H4J1AMmznnwg7VXpvx3zxkRl9n1XwLJ8478
Q+PZ/cUDvGPPC18YF1B7DwgfZ+5duYwd3wOSqE8brZLzqb0HOIa++UcV5G+c
pUCZwcjsR+z6LwXfsca720XqX8SUv9SNLbxM8VzNsL/BhatrWf/3BOwv7P09
kx3fE5qDQarlJeS/Ik+ozY/wV6hJH2qm/rAWj4YOSaS/ZeBqX3E79TGP9LcM
nBN6G/pM20H+tgzavaUlTvrE6mUQBqqsnG5RfY4XBAOWL4u9lkbtvSBaIi2W
eq6k9l7gKGS6M9rm0vheUCevvt1h6npq7w31zhOrLmgyqL03eL0nXdnpmUPt
vcE1rmy0slXS+Ez9pWm+ny1E1F4ATfqQ3qUbMv71zxWgsazmva+G/BUC6C7V
DB/kX/yPBQIoBhi2nLEiFgnwq/8B5zuXKT6qmP7OLBCpTUQ0XwHq+xRKOukq
/o2nEaAl6YTWluU7afzlaD2x4aNm3O5/zF0OlaL+0IbqbSTPcqjL9vv/dqD1
ETB84ZqdqS75q2g5zDapb03xJPtSLQfWBDseFdB+rV4OyYpxi88EUHzVMP3z
v+/g8qg+ZwVyD4+/t2gg7UfcFXCPfPJ3kJy1hxWwdOpwtZcd5TeCFXjLDXVT
OLP70QpIJi+dFuhJ+5VqBUSBF8pm9GHtdQUEblFTsxIiaXymvHLH9XY/SB7O
SlQmft/k8XILyb8SnIKxvcd+Yu1pJcq/Jf5+K5CR/Csh2K5+4dwzjPS7EjgS
+Nt64BoafyXUdXzNldCNND7T37l9N17VzqHxV0L/1Lv6rOBwGt8HpXoBwy11
yJ65PuDzfw4VB8TQ+D7MeNMWzbmwguT3gXvi/MQH1bQ/iXxQvGOUJuUq+aPK
B1Olt8LSFtH6qX1Q76Onc9GXyjU+sHjvleYhZPe/VXjwJCFcZE75A3cVBF0z
+/1yJ8YqRLl9XarnQPoUrIK91+JYq3A2vq+CyWVJ54NZpA/VKvgarYrbtoL2
D/UqCN/zOkScpP1CswotM2xd53OpnOMLn7H5O16tpP2M64vJy22dFgrZeOgL
v0+dv2eYEAt8MUE/X5PZyOrfF/b2af1232bH98Uus75f18aQPah9YbjTQfko
muar8YX7+uoROzaz+c9qiFb7d046ycq/mom3WVa8MsqXsBpmw8aVGe+heCRY
jYr0j7ETG8keRathb/nn3BkzyhdVq6F5G62t3FJO46+Gz71dWuFDj9H4q/G5
vHktHKic44fclgFrph+k/YDrB3H0oL/fLWn+8ANvb2i8cGIeje8HlTjvR6g3
zV/kB27nn9zkEVSu8oP1OduzK6fR/NR+MLP6mxZ1jtZb44eQXja7gi8dpvH9
Yfbx0YnimUdofH+orPBkeDTtV/BHfccJE8PiaX4Cf/B23it9mMeuvz84R+wK
b/4ke1P5QxSQPfmOUSaNz5TPvuAmuxRI4zP8a1SqV4AL2X8AOC1F47d0WEnj
B0DtvEW7pyCNxmfK96zPCiql/gUMvz4j6NmDzZcDoD9WknLmIs1PFQCkXOjc
/grJpw5AW9ptr9A/pB9NAFT9uh34+ZfiJ2cNWjtcz1zP5r/cNVDLOnYI9o6j
8Rl+PdxbNyyF/H8NBAd9nqje5pL/rwE3iP920Z2Cf6xaA80VXdfbZvkU7xku
t4g60nczxd814NjJ/Cbtl5L8gcx+fe7o8vsUj7iBEJlflfsbU/4Ihp/2HBjv
SfFGEAgmR5jqMtacxmd4wY++S4JiSH6Gw+9u6KPH5guBUKWaWhpkkL1oAqHR
CeR/Ocqep4IgUu+dX2CQQvIHgdPFtDCtxI/GD4Lqcv62wB+0fwiCILhkwpta
z+6vQRBOnW75cXERyR8Enqn6x+qKfSQ/099Lj95dG/eQ/Ez7g2m/vV+qSP61
4PK9DO51oP65a4Hh9blXzeNp/LUQ2dyq1d0RTOOvBWde5p7qQ1QuWgt10xe/
DhLaX1VroTqpP8isH+1v6rXQ7Hk30N1oP42/FkUTR51MH1BK468D/8egWWtn
EXPXAX+XpwzaT/WxDpqobXeLr5C8gnUQdPokauhO+hOtY/TxWrs4U5/GZ9qv
nxo9Buz+y5Sn2/ENT9J+qWHYwvjhz9hoGl8IgeG6R5IjZE/6QnDf2W5eN3EX
zUcISb+d0rlptL48IVoT/4Yu1SaGEPxnb09sdSJ5+ULg+J9BK15RfwKGR/Vy
2O2S+o+FQnCu8NoNKaD9RySE6tabgmWelI9IhOBd7XPQrFlC8jDzM08MLR5D
9l0qhLDml8cBEc1PLUQYVqyMzaP51Auh0f3YZj+pmNabGf+uZ2hVFtlDK9Pf
ELOWT9P3kvzrIVAcF2q+0Pz114Nv3dVg3wvKP7jrwfl57W/+JsqneOshGrzp
aeJU8kcw5Zw9G3u9+DT1n/zrgdz+XgfyKH4L1kN19vm1a1fp/CBcD+6t7aV5
fDpvidZDfWW1VcgT8g8J07/dBukxG/IfFVM/Wyd/4x6KB6XMeHfNc6t+rCb9
Muw4v8Vg4xiSn2Hj2/IjJk4kP8MV9V/C55j8q9/K8NyvAz74zCb/2wCOdtLO
jyfH/2N9hkMl+bLlC0n+DRA5TypJHeBD8jPlX6PvOi1bQPIz/HB5YMbkdf/a
8xnW2d91llkqyc/w8fzrEXdJXuEGqErCfxofpfOzaAMc920ZlDue8k3JBuT2
7TYls5rNJzeAaytx6SSg+Fu6Afrlnyf4PmTzuw3At+vinE103qhnxstdH/o1
l+K7hhkvZIs8824C6Z/hjSWn8zwpn+IEg/PiYURyOeVb+sHQnvdyQcaS7SR/
MPTnbNvpEE32xguGYUG3/LUXKF9FMBp7SzZNX0fl/GAIFkyccCiF4osgGKVm
yvp788h+hMHQaNVHWKvEZP/M+L/Dl15piCD7D4Za+PvGNSfyT1UwROuXSica
U3wuDQbsMgoCTSheqZn+rnfY9VBN8b2eGS/v3EmDVWy+zcyH87Um8SQrPzOe
nUZ3xGUh6T8E3PWPbZutyd70Q5j4oxeZt4zslRsCwaDRbU59Ev4xj6m/L7q+
+V4cyR8C9aUBE3duKyT5Q8B7oetVmkX+JQhBK+/OZ49z5H/CEIheDt3X8xat
lygEmtG7Pq7tT/FTEgLOK9dz72IEpP8QSPRygmex/lMaAlWXuWfFunTeUzPz
c9qxa/1DOr/UM+2PDcSpIDpfa5j5FvZrOFuTTfIzfPzm++NLaH04oVClDYbr
sGTSfyhEC7vc6vCB7IkbCs7tr/bjKml/5oWibf8dryQl5YsIBe9yrO4hMT2P
44dCcCV9bYGc8idBKCR1Wi2NO8lehUx/BR8/xLZGkvyh4Laf8j15/1aSPxRh
122UVdMp3qtCUa9sN7SbkOypNBRQXvu16QWrf4ZNthXk+dLzn3pm/vtNwi3E
FB80zHhBVVV/7tP5o5UpNx9Q2v5rOOl/IzhrLgU4DaDzuz7D2lHml3/Q8xHu
RojyvHYrd9D+zGM4PlBm7k76wEaodnh8l64i/+ZvhMbs9MOxpRTPBEx/f1aI
9sZTPBAyvHG7m9NYD/J/pr/lwlsjisneJQwbWL0dbkv2qmLqH5o/uPJoAMm/
EeoJ3cd1W0jxUM2UT6rUHTKBxqtn2o+b/O5REp3/Ncx81o0bb59L541Wpr5Z
U1Vn10kk/yaI+o4MqLAj+9NnOG7Q7At5tB9wN0HYolXVzpvsmbcJ/KM11YXN
ZL/YBMGjee1Xd6V8i8+0z3/y2DGNPa8yPFM3cWX1RrJ/hr1vn3/ajvIr0Sao
R/ccMaMnnf8kmyAxuZy12ITyFdUm8J6WZfg6HyD5mfENhvp/cDtI+t8EjPQM
nzaJ3f+Y/rwdt3CGUTzTbAKn+mXGVw7F71aG7V87u/Sl/JYTBpHT71lDTpH/
6IeBo9B5teXsfNJ/GLj6T3SaYmh9eGFotdujM3EXzY/ZfSVNQYEN6w6R/GEo
Grr/VdXBwyR/GBwdvGaPSiMWhqG2tKHdvUjKd0RhqF9c0/tYKbWXhCHssnb3
Wg8qVzHjz+i6TXSe2peGwS+ro5+k4xGSPwzijB3PNQ1lJH8Y2l6fG9Den9pr
mPa6B26at5D+Whl53VzHt8nZ5y/hUNt2efZsFcUz/XBwOIPqM3Q6kP4ZPup/
a2D9apI/HKK5Yd0tb2WR/OEQWL+XrjlN+QI/HJo/ttfiDtD6CMLBv7c8ZPwZ
Nv6FQzI8InFEAelLFA7unJd+5dVkT5Jw4PDts1b3yd9VTH+3nDr3G079l4ZD
f5X/QqsF7PMkZj5p4Z/FFaz+mfoGl/XW+bHyh4O3fnzHKb9pvVqZ8e0elURz
jpH8EdCvNO1y7OdRkj8C6sKGj7425SR/BOqz9l+sVtH68yIg9LUa7beU7A9M
/ZcOr8xA+So/AqJ93fblz6P8SxAB3oLLcwLqiIUR0Hicqum6gOqLIqAycpjW
O5PKJRGoGNjh2+9rpC9VBPx4EdPHeZM/lkaAn7VmQtg29nwTAcG7q4KfnSge
1jPjDx8xcoIP6UfDjGd7c2LGm0ySPwKt0/cHPo5h9/9I8GyWtb48TfunfiQE
w/rs2jmd+udGopRTPPGtCe1vvEjwzW/sXVNA5WDKV2w/PHog5bt8pr3nmTfb
3lN+LoiEJuul9XAryheFkRCdcDoavZ7NfyPBObH0Td0zX5Kf4exLrp+fUX6l
YrjJOd596CKSn2l/x7T64jR/kp/hqh03RHqUP9RHgnuYX//tOO1nGoY3ntBR
z6H5tDLz6XqsRJRE8nKigCu8BY5NJI9+FPxCtqxe25fsjxsFiaP/0sZwYl4U
+C7+T21T2OdzTHnoZtvx1pSf86MgHON2Zdpt2s8EUWhtCxlm8oH6F0ah0WWg
1Yxs6k8UBffFB2/xb5F+JVFQzZz/ocSN1X8UxJXbLhz8QP5TGgWzYvWYinNk
L+oo6D9Who2UUnk90//YbY29brHnvSg4vrM4bJxK/bcy5VsN71RfYc9/0RBY
yL32nyD96kdDFB4pzL9KzI2G4/UuiQUJrPzRTD5h+iuCQ/6HaPBUTTn7JrDn
n2i0ht4z0lwmFkTD+mqjnvdxYmE0wn6P+xFoSiyKRktUbKzpROpPwsyn5+Hn
uq9Z/4+GqjDku7Mrzac0GpIVp3r6aVP8UjP1lbNqP1yi+FwfzZyHn+b4m8tJ
/mjGfn6Fzv1C3BoNpOc5bXWm/YYTA3FkfIjZIsp39WPQMtFi5FV2/bhM+e37
twtGkb/yYmBocuStlV8JyR8DR+9vRdqutP58pnzhseTDg9nzagzUx2Z29xlA
9ieMASfFKSUkePG//UXE8MHbG7njaf+RxEDU3uHJ4XDar1UxwLqp6eV9KP8o
Zerr5RfeHjWd5Gfq45LW1FfpJH8MWsd0XPL1N/u8Iwa89u9Xag0j+2tleEdb
UFEtG/9jwe00MaxyG+Xn+rFoNa4+99eO1osbC/4GbvOSAGJeLGAxVZR4j/pH
LDinnSa3m83Gf6a/HecvzGP1LWDKv+1pe2hM9iyMhWr06nHnk2m9RLGQJCys
O+NO6yth6h87PX7LUtrvVbF4uzWguEiH4nlpLGp9/lR77KV4rI6FoWHT2t7t
Kb7XxyLKJT5r/BpiTSzcV+i1b+9D+2MrI1/X9I8hL2m/5YiQ+5jzqSiF5qMt
giDXadKjB+x5WARx9wMJ543JPgwZzssr6Coh/XJFaOwyvqb8EclnJkI9Lo/p
O4r654lQriX8m/ScxrcWQftB1x9HdtL+wmhPESnZN2YmsaMI6j+Oyj+DqD5f
BL4yT3VgG+037iKonmu104lj9xem3PRYpzOjiP2Y8r5BzxYHUX2hCH61TRla
hrQeYSK4Px6rxYs+TuvPyDv/8uo9H0/+YzEjz7ROUh2vStKHCBJb506PQ0/9
41wRzMaN0u92u4L0w9S/OOjt3PO0fxYx82+pKFldReOVMvN5uC71yQviCqZ+
7cGLz3bT/qsWwShq+e4P6dR/rQhnDYptWs6oSZ8iCN9n7x1eeO4fN4rA+XJv
4Mr6C6RfER79jNq9vf/Ff9wiQkv/WaM65BO3ivDp4OwN3mriNhEeSO1WVPSp
Jf3HYde333rpxpdI/3GwNN7fomV8hfQfhzvrebsv6F0j/cfB2Dswv/OtetJ/
HKJ6NrYeOHGT9B8Hz8/rfwsSG0j/cdgze3XSJ707pP84fAsZEb2Zf5f0H4f0
8mENk5Y0kv7jcK8o+IN45j3SfxwaxTpNgjFNpP84NA/68sB78H3Sfxx+dtLm
f+/5gPQfB1HunaXy98TCONgsPfKurvAh6T8OO+zH+VUYPSL9x+HvgN6N3DBi
cRxuRjZMsblNLIlDhNHytgPej0n/cShJkEyoH6Ah/cchpsVm0sZS4qI4dC8z
iOJ6PSH9x6FH9crryzo/Jf3HoarHRU/XdGJ1HLzeDNs24BZxLSP/Ntcl7R4S
18dB2+e7WqImbozD6fd3hNx9xJo4PJI9P3L/InFLHN7Nl/I/2D0j/cdhjpWi
o9fg56T/OMiC3g+JnttM+o9H0t/y5aOVL0j/8XA4kDUrv/wl6T8ePn80+0eH
tJD+49GnezBv0jFibjw0R8/7xcURm8VDOVZa1OEPtefFo63bsp4DfYmt45Hq
fXfzto80Hpjx9TMkW84SO8Yj6uu+6XebiPnx4Nu6D9s/kNq7x+NAW9Cx057E
gngs3js4KiyA2C8era/Kr1ePIBbGIzlhmFPNVuovLB5HD8zhuTSQ/KJ4XFy1
U/61jdZHHI+SmprM5lHEknjsnVRxKzaN1jM3HqvP7+7dy4BYFQ9Oe22zJax+
ipj+jqsrpdHEpfEYczu188UprP7jcT7l9Z+2T2Qf6nj4Rxpd+bOTuDYeQ1qG
+l9wI66PR/Hk0JhqHeJGpv7aipp7NWRvmnisqfwyWyuJuCUeZZoxyUOnEbfG
o+9Zc5HsKdlvWzwc22rWPbIm5iRA/+B/WhfSyd61ExCuPeW0/kvyF/0EWPS1
fdRjLrFhAnbpvbHxPkr+xU3Azn3zuN21iM0ScME/9nuBEfknLwG9R9yQ7XtF
/mydAB+zjxvi/cjfkYDBzXc6x5RQfHBMQNnPjOqAexQ/+AnQsrh/srrvLdI/
039QzxkfU26Q/hOg6uU9x3MyxSO/BIjadX5vuYzilTABQXnB9yVldaT/BPjZ
Dt5z2J3imygBd3/NX/Z08mXSfwJG3Q3rOXUexUMJw5EITZFSvMxNwFP980KD
nxRPVQn4KP/dKyaGuCgB9ZuGVcbrEJcy7T+8sp8iqyH9J+BIkPbZywbE6gRM
iYxut72Q4nltAmrdLkz2m05cn4Bjhyv/Lu1G3Mish8lxvvjPedJ/An4HrJqU
25nKWxKw5rXrnjBD4tYEGP0MW/R3DHFbAuwz3nTmrSbmJGLZ36Z2n94Rayfi
88ShZn2/0fz0E7Hi1eh1c7aS/IaJOBK70XXLGVovbiL4R6yk7wZcJf0nwjnb
MnzO1Ouk/0R4hP4Rf/ch/Vgnok+/ZWm4SoxEcP+MOFrzgdgxEV3e9qu40oX0
y2f6X7Xygo0fsXsiTh2d3OW9I+03gkRk2Ukb9NVkH36JcOPt6DHu4G3SfyJG
O207MbmO9puwRHxU1Lwwu0T2KGLku+3/9Hsg2as4EWsXnewcfJjsWZKImOdj
J+VfIPvPZeY/aqyj/g/yF1UiRuRUjXeex8b/RBhf2KTzax0b/xPR9XzFxeQm
1v8T8fNdhfmy9RRf1IlM/vt4pa8OxafaRIT33hI3QETxqz4RQav4y85VU3xt
TET7q7bONddekf6Z+Ti3hE278Jr0n4h9gVfvX1S/If0noi5/5cazt9+S/pn2
zgOdLnd8T/pPglVo5y8zp30g/ScB9/uM+zCulfSfhBGNTQW3DxEbJkHn6Ua/
JP2PpP8k9Pr87Wz7JcRmSTAafC5mq5KYlwSXX+t7t7tDbJ0Eu2j9NbOHfyL9
J+GO28fX0dnEjkmQRezgTtL9j/SfhM0p0rHfFcTuSbjpubZXzKDPpP8kDAnp
8nvZLmK/JMwU3V10YfAX0n8SqiSqsYKtxGFJ2OvVbkxZ36+k/yR4N81ZOj6f
WJyEwIfl3C/m30j/STDp39nYppI4Nwmz9cMacpzaSP9JGD/3Yve3NcRFSXB/
rfXQcuR30n8Sjkdaqz03EFcw6xekXjq0kFidhNdjx03dV05cm4R3/Z2Np5wm
rk9C91l/vVWVxI1JGFc17VJAGbEmCcO2pqdvyCVuScLPzhZ5zT7ErUnwCNDq
s1SPuC0JfRx2nRVLaL6cZOjWmd6+/YHk006G+46ZXWdMJtZPxrn3nb5+SaT1
MUxGaN+dVc0vaD25yXBKXxXrsoHYLBmzOtRnDBhDzEuGzwu5505DYutklBna
aPkOIkYydm+N+3ZxNLFjMlz/63clx5KYn4xjZZm384YTuyfjsWGQjlyHWJCM
KY/FfvavWf0n467wRd+Jd4mFyTjo1tle8pA4LBnPu8ZM9PtDLEpGu+PVbzNH
UX/iZIzyDX740Y1Ykgz1HFvzHE/i3GRs6TTT7PF4YlUyGt7P1/NspP6KkiFz
3XWt42Li0mT0f8Y/PPEi2W9FMlpCJo/ysCNWM/J4vF825jbZf20y7E1tr/5K
IK5Pxn21T+wkO+LGZGQdXu4m/U7+pElGv1StrLEFxC3JsJmVuKLSjLg1GYuE
hjuOF5H/tjH6GVKevt+KmJMC43a6qqYG1v9ToNeBvy/pMLF+CiZ3tXof0I71
/xQoIvSfmy8g5qZgx5qmsOWHic1S8F8fsY/7X2JeCuy/jJxkPZL1/xRIbxYW
vB9PjBRYGx7ZHDmc2DEFJ6NdE470J+anwFytKthoTOyeAlnefsvQicSCFAzU
OXXC3pPYLwVlx308QyKIhSkQT4yb/ymWOCwFm8tTvnf1IRal4PxrQeMWdn7i
FFi5P9u86AXNX5KC/j/MH13YQ5ybgj7var+rw4hVKdiuZ34laClxUQr6jbUp
OGFHXJqCQ7nlu2z7EVekYF7kPdOMIlpfdQoy+zb3tnxO8bg2BfveXF10rj1x
fQpevhl+Lm3CO9J/CnwkU8Lyyiiea1Jg2fye30FJ3JICoy1B1t73iFuZ+VbN
ku1bQu3bUvDp0Ko9XR4Sc8R4NTObN3A0jactBnfpKx+XMcT6YsRf7TTzxXOq
byjGpnzfKNl6Yq4YPYyCfzl1JjYTA8d/xh68RePzxODn3HiR/oHYWozmcb0T
pi6m+hCj/4VD/Ix3xI5ibBhqYRCYTOPzxf97Xvrq0WdidzEcLZJVnfrS+gnE
OK5feTPoIZX7iZF2eIPOldnEQjEsh3+/NS2S+g8T41zF7DMH0mg+IjG+9mkx
i99O+6VYjJMWjlvbntJ+KhGj8IrY9c5q4lwxgoMnL+40iVglRokwb3/tHOIi
Rp4E81XlWcSlYvQWck19HxJXiPHlyUiri8Y0nlqMX0mFw5fYE9eKYf8i2PIG
n7hejKENj/60LCRuFOPp78E1vQOJNWLMPSKJle4lbhFD527etnXdWf2LoWrb
17cgj93/xVjcvqjTj/Gs/lOR+GD5/pBzxNqpaFlx1r5uIqv/VAzTPh8bk0Fs
mIriO8NnBVwi5qbCw/p5v3u/iM1S0X7+8QXO40k/vFS47x24dPJ6YutUbBw6
2/E6G1+QijHzjvctfE3smIqYTYJy7S7kL/xU1AxMk63oSeyeCv82qytRvYgF
qSh9pT50WZ/YLxXGjV/CPPSIhalYU1v9StKNOCwVJn9S1ql1iUWpMBNdc/qs
TSxOxZ7iZz4d2HgnSUVJ+I+La1ppfrmpyLkZ1e3aO2JVKoJL565JZtsXpUI8
50nLgYms/6ei35LnYZw01v9TcV5r1rjDv4nVqbi+0NXhTirFn9pUqPqYLPUf
zMb/VAx99zVo/3E2/qfCYNKAmYb2tH9oUjFPFn90+XnillS8G3qloGkK7T+t
qbCPOt18o5S4LRX3U0zvcc1p/+Kkwetok4vbXmLtNCb/f3l6tTnt9/ppSAmZ
4TV7H7v/p8Hl0/viWmPKD7hpeHvDasaTOGKzNEy8c9//dx0xj2m/yaXD1D/E
1mno9Nj2akNfyj+Qhg81Y78KBxE7pmHnYIdT7QcS89MgbfTqNqYfsXsaHB4+
0bo9gFiQBuddw8ZxRhL7paGL6qF/gjOxMA1zjX6tnBpFHJaGIssyrTo1sSgN
DY2Py0cYUn4kToNgRk7D1zhiSRpWzwvd0es3cW4a5k/oO42T8oP0n4bnYsdI
rwE/Sf/M0eb+RxeLcuLSNGifSTnY4PyL9J+G168bbpbdI1Yz44VtC7Bd9pv0
n4bFE0w39G0grk+DMjc397LtH9J/GhadPL/oZC6xJg0TyprsojXELWmonbCJ
d6PbX9J/Go70WuK835C4LQ071v49ePon1eeko1WvT/Wl48Ta6Wj7EXTlphux
fjqONSmPd9PQfAzT8e6l8tA3X2JuOvjnO3ze8pHkMUvHyO8rD9XGEPPS0ffc
h96btYit09FhyphPfqG0PkjHlt12N85cpPV0TMeupSYT3dj15qdjSfdrPc6a
Erun4/3wR4UWS1n9p8O5ztll/QmyL790nPhkmB+3gFiYDo8Zw4+vHkkclo6m
pEWiQh6xKB1uzzVxZ2cSi9PRo6vMSujC5v/p8LUafece2z43HY7dzi50eEr+
oEpHrYdw7KZI4qJ0rMxLLGvWIy5NR0+dA3/bjpB/VaSjMC5z9O5NxOp0vBL5
9zm8iLg2Hfe9Dep3TyWuT0eMowBFBsSN6RC4949DNfmzJh3t5a8zpo0hbmHk
8Xp88bAPxYPWdIz+kDFCsZbiR1s6WqrOdfi2iuINJwOhs4wcc30pHmln4EKM
v8cTPTb/y8DSecduK4rZ/T8D7Qc/E0/dTvsJNwN5YZOP93pE+49ZBuaXOZjE
TyPmZUD/RPGgmp20/1lnwMexQ3XeFzq/IgMcrv6NdlbEjhkocP06uCSMzrv8
DNjNsfwV8YJ9/peBqtQYo9Jd7PO/DFgbwbekln3+lwHNhf5nezpTeyFTzntp
u4FD/YdlYLzW44PfDhCLMlC0+knoRAOanzgDKzQ9/k7qyu7/GXjvVTRLR0r1
czOgU2jHX3+Z+ldl4Ff/Hzd3/kfjF2XAqGSoz7NZxKUZUM9MWK/7nM73FRl4
NHHcbLPzxOoMoPU/na9V7Pk/A30qOltzVcT1Gdjnmv9t/nTixgw8z4uNnLmT
nl9qMvB0z9uqlhf0PKElA/xP6z/lORC3ZqBslfPNgh/0vLItAw9lrTPP9KZy
TiY67b7W2CuBWDsTY51VS35qU//6mZg7fJh3zEpiw0wojF315rLMzcQd60t8
Wy1is0z41YwwOSik/niZqNi+s2pGK41vnQnba7kVxZeIkYn6XK2KbqZU3zET
Q9Zejhz3i5ifCYlRhNYxY5LfPRPX5jVr73Bg9Z+JRKV4VefJpA+/TFi+Mom/
fJfVfyZElnavp5mz+mfqB7a/uHMBq39G/kL34nGJxOJMRDzYPd+siViSCb02
E99VS9j8LxPGY7epS16z+V8m/gzYYfV6Ndl7USa2TJ/j/+IAcWkmfq3tJ3DY
T1yRiak7Jk//4cvmf5nQevH7i+IX9VebiZNfe5vmSInrM1EQ4tlc5UjcmImY
Vz0uhlgTazIxMzL2YpMv+/wnE6eD1aPkV4hbM6F7fJxgDJs/tmVi8cIVWlc+
EHOycOdGY66GzYe1syDilRTPH0j+rp8Fvdkl96buZf0/C/Z8f2HMWDb/y0Jf
S3M7+WU2/8vCtTE7L66KY/O/LDS4KXT8xlB8sc7CSafzM9vY50nIQoVvfvPF
Sez5Lwu5RfFzB1ax578sxDj1i0keSfHLPQtFyoC1BRuIBVmYfvK5KC2N2C8L
Bmeett8XTCzMQje9VUv8JhKHZcFuf7vuOc3s+S8LnqNcUodL2PNfFnqWKbZ+
nkUsycLTNR590g2Ic7Ogvlpqu/UXe/7LwvHhLxye/WTzvyykGqV52Xeh+qVZ
mGuWfvFqX+KKLGhW3jl/uh+xOguHa0z2eGux+V8WDg48+m54A/VXn4UWTaej
J7OJG7NgpNqWz3Mk1mShzUy2X9ibuCULjjcXznrJ5r+tWehVM6Gpcjp7/s9C
rf3XP+3Z9edko9te87+WoPG1s7HeLqv3FvZ5nX42ogaPLjSeT+tnmI3omdW9
lFuIudmwtGp6+6WE2Cwb3EMDHS9sJeZlY25mwYiWOGLrbHQZkrjUMZx9/peN
/i43Bjpnss//mP78jNK1jxLzs1Eqq2taeJfVfzZ+2n670nyH1X82Ls9MP/JX
xeo/G7wIy/m7WX0Ls5F6IkRqWMae/7Ox1PtEoS37/EHE9B/fzXV+E5v/Z2O0
9olMt6Ns/p+NOyKrIw9Psef/bNyKebXtM6sfVTZMV5huH9rM6p/p312Wf/Qh
m/9no853f9bCC2z+n41hJnOrVrP9q7PxdfWLXdpXiWuzUfRs67vmQTS/+myc
ty0YG7WPuDEb6DvaMcCF5NNkQ3WGnzu/kbglG59P3nfaOYzd/7Nx1xDxJ4YQ
t2UjZOOhRUfY9eRIsGxj+unjAcRaEpj16H5BpkOsLUG66+fNuvdpfF0JfBb4
5Luy/qMvwcqh04x8Dai+gQTW/zlMa53K2osEX5s+R5+bRGwkwfyhdUGS1+zz
Ywmc45oL5a7EJhI0rf9mw8lknydJMMsubYNLEsUTCwlC9vQ/ozeO4g1PgvLM
pRdWO1F8spRgQeTiDkMusc8bJGho9twRkUVsI4HhbJeJt4OIIYG+zqDfV5yJ
7SXY4jzARMuU2FECrREvrXINiGdLUHamV7PTJGK+BK/FXeof7CZ2k8Dj5/ih
41xpPu4SzN3jbnK2P83XU4LL65I8xlwlFkhwMbFh0bopJJ+PBB3f2o5cPJvY
T4LBLVYf7NsTB0qgfaB8wb1Q9vmGBMbN5ztF1NJ4IRLYe3a3udqbfd4hwYpP
N+16rqH5RTHrXTsiRHGR4r9IgvCtjtczTIgTJWi0i9MzimXzIQl2PvllKXhE
+2GGBD0Xy+eYu7L7I7N+42w89d7QfquQoMX4zH/epcS5EqR5jw64soU4X4LK
CwV7z0vY/EmCo2emRzwMJ94lwfXnM1Z3nE5cJMEx8Y2/bq9ovy+RIF4/eVBV
EptfSTDga/Yd0RTicgnG9jUY1nE0cYUEe45HqRLXEVcy9lR2RffNV2I1oy83
l07/qWi88xI0J28aUWZD8tUy9vw4eMH2QuI6CSzLreK0y4jrJTi4tb9L7zji
BgnuDZksVY8hbpRAZ6B+dCC7Pg8k2OH85LrtHWINYz+lXQNcvxE/l6Dbppit
nInUvkWCgHPhpp39id9K8Hf93WwXAXErow/etEOLOxB/lmDGqXa5s92pvzYJ
fmUld70WT/L+kiDi23DprXLKpzhS/JhmsmhpP2ItKeyu+gbfOkv5nLYU8kGp
2x13E+tK0f6j16orhWx+KMVcgyUu5anEBlKMdnwmrp7H5otSbJxnrz7ymfI5
IyluRh/uLpcTc6XIL7PN6McnNpGiWmdzhok9sZkUMY2r9udsILaQomZWZYJ3
DZtfStG/vuOt9wNpPEspNizd6X7Lk9haCtG828N+hRPbSLG3aoBZfTwxpDg7
ry1+hpTYXopt5jVHzE8SO0ph2OnpxOjfxLOluPFMuuaIHXs/QYrBA9fE5i8j
dpPCb8Q8UYYFm69KURxq8blkB7X3lMKiKfuG7A7NXyBFp/VTtXlsfu4jxdqs
4Gc5M4n9GP00JSUmsPdBAqXI4lxaP+8ssVCKeS1R96zriUOkqL0vN910gzhM
iiF7umYUbiGOkuKIa7+yV0bEIqZ8/4xrVZvo98pEKcqvB+9e+5R+zxRL0fS+
XeTnHOIMKc57zymLPEoskcJ32m9zAytqr5Ci7tbZ3p9fEudKmfxW6+RXCY2X
z7Sfc7Yy7y+xSoontytD6kxI3l1S5JkudzvWh7hICklCpWtse+ISKfrY6iXc
6UVcKsXUkermR17E5VJkLrD7bX+XuEKKfv+ZLhrsTutdKYXuzCU39x5nf3+V
InF59bQf94nPS9GzfuCUTNa+apn+x6Ye7iElrmP0m3mEV+hFXC/FZEWJ/mEn
4gYpHKsWjMxnx2uUYvqgPd3PRxM/kKL52cElXjuINYx931705EY58XMpjo/5
GxZZxp7nGLYZVvJ8L/Fbpv8TpYmuRez5Top99/R9k88Sf5aCF+BUV/Odve8j
hdhuXCcbB7K/X4y92BTzHVh75MggOhHWUYv9/VlLhl6NIa5zU9n7QDI8eTdp
5t+xFD90ZajXN3mc14Pii74M4Rl1U/sNo/hjIMPN8t97OnjQ/mEog295js3M
dNpfjGT4PnBXr2db2OcHMhTo9LK/t5H2KxMZqsIfVW0fwZ4nZFh594lh/+vE
FjKMXtJDsCGWPV/IcMXmTPOioZQvWMpwecCzNc7p7HlDBv1Jj0asZH/PsZHh
r8+XnG+D2d+fZODf90nlWhLbyzB0RFvAT7bcUQbuyjOVLn+o/WwZWnxbjV9o
2OfTMqgm3UhfcJ/YTYZOj36evNnKPq+WwaSd3c8Jfag/Txk2bVjZ6w173hHI
UJx5YPe1ecQ+MnQYf6vS2YP9PUsG19M5vSevIQ6UoeTgoJfKrezvWzKsebe8
4/ffxCEy3C8/+XaEnD3vMPqd7dGe50D5X5QMkX2OxHT5TiySoU5d5axMpedH
iTIsK3xz9/0rYrEMyTnz+uexv6dnyGA2/XDnJkf291EZpv+3rvpGOLFChvHC
uGnmavb3UhkqU53n9dGn52H5MqwaWRVv6Mw+P5OhT9z38UNZ3iXDSH5l4tkf
1L5IBq85guOOK4hLZChKiPQ4sYP9fVWGcTE7tpx6Q/KUy7DD16tjt1Xs761M
++4+w9oZEVfKoGVT+UPwm9ZHLcP5L186/X5EfF6Gyc9ebYxUsL/HyrCh4vFv
l47EdTIYBgz60oPVXz1jH0XODlI30neDDNkx4yfs6kH22SjD0W1Gwee/k30/
YOzBbWfGn3BijQwPfh6JeBxE/FwGjvGr171TiVtk8MjsrmiOIn7L6L/6i2lR
f+JWGQrPfVp1cQX502cZ8jSznm+NYM/7jL927DfkroT88Rdj3/vSWrepyV85
csgm8Vt6s/mDlhyhe8S3xk4g/9aWY9/8Rb4vx7P+L4falB+16w27/8sx1jHZ
dPk6ijcGcph3HHWm9C3Fd0M5fk0qX56spP3ASI5Hg2duDGbvq3Hl4D9Y036Z
D91HM5Fj2pgWPWcN3bcxk8OmbfQ5S/Z+p4UcC36OT19URvd3eHJkiJMWT66h
+2OWTP0rH4vu7qD7QNZyrJAJRnW9SPeLbOTw6XUjwGwG3VeCHFuK87ptrKb7
TPZypDWXcSxO0P0vRzmgk2bnu454NiP/lPcqHV1ivhyr00wWOnem+1Fuclxr
S1Cv8KT7U+7M+Oo/4Z/C6b6WpxzRhWted/p1lvxfjk/Djfc+W0zsI4dLj7fN
x3cR+8lxyiDxpvkWuv8bKMfH1oqC6uPUn1AOv9hn6owMur8VIkeRxuHI7HvE
YXK07TNxy9xKHCUH1zhq7M9Wai+So//S8ucHPlL/iXKc6Tt786R8Gl8sx/un
O7vffEL3kTPkMDZ/uGyw8jT5vxzLjKVNv3knyP/lcB423o2TT/ehc+WYNNy4
ZGUfut+dL4fI50630VupXCVH8g3+DI2A7l/vksPJ+ltN6HUar0gOvYXd82se
0XxL5Li548EL6/W03qVMeY/3mgnXSX/lcoz0r8t9fJzu91XI0WH5+5lSIXEl
U556pndZIdVXyzHu9vmVlhzi83K4TVCu2G9CXMus13nvgx/tqX2dHE8chick
ziT7qZfjbdshh65NdN+tQY5IrcpOI5bQfbVGOZ7fHmW1uo7uqz2QI6b+sbf/
FLrfqJHjYPE5ncfb6b7acznqviz6dPIb2XOLHD9v1NTttKD7km/lsNie+txg
FNl/qxwdzQTdn7wj/szY53R8XrCR7ku3Mf6t3JKy7QnxLzmadA3POiyk+24c
BUbcfJV4upVYS4ExA+snSKrI37QVeFRUO6bfIfJHXQVMe4s6bt9G99/0FUx8
dL4XF0D+a6DA7FNtX/ltxIYKhIlG5/4wIX83UiB9a3F8/RTW/xUwqhy6ddIC
YhMFtPenLVgdTWymwKJuUwVdLhJbKLBtYU5iMZtv8hSw9k+d3PMSsaUCTROe
pmSw92+tFagy3bOlZTblgzYKeC/guQay93uhwNqh1R4vu7P5vwI2oYP9Rj9m
838F+LmP3W7FUz40m+EuqY8Mm9n8X4FL/JpvP7+z+b8C7ytERp3Z5/vuCuyI
Wv4UbsSeClzn7G05eJ76FzD9Hfi8PWoMsY8CgSfXLo3YQ/PzU8Bw8RmXuNHE
gQoEb/01w19N8giZ9Re6ziqaSxyiQJ/eczafrGPzfwW+ebTv086Kzf8VmHSw
YNS7NFovkQLP5oydOPserW+iAv02HU2aMJrN/xU46564NH4U6TNDwey3fxZ+
nsjej1dgUF1lXJ8Esg+FAkmdZkx8osPel1TAvtFh+WA12VM+I0/T1rvjUolV
CoSURDtG2hPvUmDY2YBtZtfIHosUUIw6Nd2pC3GJAjEeB383s/eJSxXof7rm
wpNI8o9yxj7zvW6mPyX/qWD08frb1DXzyL8qFTj8qY+F+hPtD2oFcm/m2ce/
If88z9hjZpcWX1viWgVu8/0u9blB/lynwMgPNfucYojrGftcFBQ3egBxgwKq
L4uqEtJov2lU4FNfk12Pkyg+PFDAzlvbKG0rxQ+NAivmfQipjKH48lyB5I7f
Btgupf2lRYG2L6cGVM2n+8RvFTi2XvgpeQN7v5fR78Mp+uuqKX5/Zuzrc9zg
IzyK320KTB3weu33CoqnvxTQupFzr52kivxfieZNvfNt8+n9Ey0lJjR+83uU
SO+3aCvR4e+4j90WUrzWVWLB6SLtSlt6P0dfiQ/BywzF/eh9HwMl7gQvfxg7
kN5nMlRiTvsbzeZX6P1UIyW+Nk1zfn+T3hfiKnHzDc6VLSQ2UeJ9yb1njVPo
/TMzpn7dzeDgs/Q+koUSL76W1m79j9634ilxNWFs3vMb9D6WpRItvC66w9jv
O1grMe372wuLgohtlPDoevOGoIHe14QSW68Xb/hxgt5vslcibffkqeHPaXxH
JcK79Ru8xYfej5rN1Hf4ck9URPPlK3ExbWiFwzdq76bEn4V/n9Z3offx3JWQ
PLcRVDnR92I8lSgpVl/+nUvfYxQoIfPV/ZBYQO+L+yihxy/Tq0mk99X8lDhR
XPvf91CaT6ASG02qXrtLaX2FShT0rCweYkccomT89ZRpWTl9nyKMkUc95OYk
Lr2PGaVE9bKAmcn5NJ5IiTcud02r/en7K4lKcD6svnm4D71PJ2bWL7ji9Pgc
el8wQ4korcTPxTHs+4pKdMlXe+Tb0fvLCiXudol5dmMFvb+Yq0Te97H39nDp
ey75Srg97Pz7wzL6nphKiVULFV09dej9v12MPa4adWbBFXo/vUgJUWCHhxM7
TvvHJUr0aF817sgt0mepEu1r3l5pPUfrX65EyAXXB+0f03wqmPX3jk9YMJ7K
K5UoPtVbP2svzUetROmKhAePcoL+9X9eib8/fa/te0bvH9YqEX9xy9h15vR9
gTol+puXqAIX0fch65XIf720o7Qbfb+gQYnDR/Q7Rh4l+2pU4kHGoUdHG2j8
B0pgk2Ltj0JaP40SrbovJqQ/ofc7nyvxaMScqbc19D5zixKdFvRrOp5L7w+/
VUJH4Pnx8QH6HlMrU27SsvCZaRD5vxLq6P2Dxb28yP+VsDjddKfZw/3ffH8x
/uux/vqXzvQ9Q04OHl0/MD0oPP0fa+VggORtxdifJL92Dhx6a0UfCSTWzYFZ
zwyuwojex9TPgW5ii3GRmL6fZZCDmL0VFyrY+RnmwGvgndGnPej7ckY52Lez
jserJX/g5iDslNX5UC/6voMJ03583+mhEzb8688sB2VFiimXZtL3dCxyUCLe
dizXi74nwcvBHnufb+kzqNwyB9ZHbg6YkUzft7DOQUtwiOc07qp/bJMD4a+W
0KmnaD2Qg1y7iXU1SWv/sX0Oqh7ekFZvpe9LOObA+9PxwbZR9L272TnI7re5
xx8D9nsXOTCoaczup6Hv/bnlwKp469khZ+j7Ne6MfNFV6mlX6Htonow8er+u
O3RmvyeXg11ZzceMqol9crD5h9cOTSJ939MvBxELLobtLqfvpQbmwP7+AJ1v
BfQ9EmEOfqfK74L9XmdIDlwbna7vyaTysBxI7maP761H3yOJykHx8Ftz5taw
32/MgV77Epk4kr5HnMiwwDZB9Zi+1yZm9GvbfaEpaP4ZOXhfuHffn2/J1f8H
FmKClg==
       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1nHlcjF8XwEeSEEKIwlCSPRWS5KQkKUIoomlRqdS07zXt0z4tM5LSUBGK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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1443.}, {-0.08647877086045735, 1.9435227302758278`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674844991406145`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"46a201ea-c779-4653-9b19-35f10bfd4406"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674845010255785`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"789421f0-d9c4-44cf-b556-afe14f82b086"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxE3HlcTO/7P/AQehOFEJLs2UOShBdCSNKO0KoiNe17TTXt2zTN1gjZkxBC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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 2887.}, {0, 1260.2901253492805`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.86748450111434*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"80a02ac4-e028-4192-91ac-d82813de05b0"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484501120324*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"ad09ed31-166e-434b-8e5c-699c6432c4a6"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVlnk4VW0Xxom093HMUqJwhn2OqdBxQoM7KSWJRkXKEIoMUakoKZGQkLGI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        "]]},
      Annotation[#, "Charting`Private`Tag$4523884#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7DeGXL97qsjCASrg4PFhe0TpJxMon8Nh+Z91
1VdXGEL5Ag7L2BWNv9npQvkiDnV7Hjb83a0O5Us4yP3dUfrvihKUL+PAPUk5
/py2LJSv4FAjzyM7T0oMyldyuNN/VrRrtgCUr+Iw8aSgzs0NnFC+msOyM/U7
Xr9nhfI1HALuzjsYockG5Ws57DuR8aYthwvK13Ew8log7e8vCOXrObgEm1gb
OYhD+QYO3uaL3+69JwflGzokND3KfPpfGco3cth9Qrjcx14Tyjd2sGbdVZAu
rw/lmzg8q5E3dDxlBOWbOvSw/+JX9DRzAAAXmlL8
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 26.89324879796801}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484501230609*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"55169f43-94af-4ff0-9db5-544ce4106e61"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", "17.993179827785735`", 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", 17.993179827785735`, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674845012385883`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"4575c609-f6b1-4166-ad80-d33bfd51fe9c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["1.6337`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[1.6337, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674845017436237`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"4bb434c8-70a6-4345-8c66-ce6accf471ac"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674845411913633`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"3661b0c1-9524-4760-93fe-0deddd8eda9a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.6805101014043056`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", "77"}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.9081381442788585`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.86748454119635*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"3014d857-f45f-4c9c-816b-7edd18dbcdaf"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484541199342*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"23912705-4a51-4602-88a9-b8fd8aa3cfc7"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9m3lczN/3xwchS4Q+ylJClGxZS8SL0IIkaaE07aXStO81TVMzzdQ09mSL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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1m3lcjN37x0dE9qQoazwkW7KH0idSkaiQJEx7Wqd9r2maapaWISVEIyGP
LxUhRIWUPVvKkkEIPSRbsv3m93Id/3i9O3POdc65tvu+7nPGuAbae6hwOByd
HhzO////91+76bdh60ymIdGU/oCnU6Sig+4CYjU8WNjS8+7DIGJ1WChqdK8d
5FX+ZU187jr77so9KbE2/j3wiKOXn008Ai8DpbIDtbnEuuCMnrh3ilMO8Vj4
9L/y8ZRWBvE4rC77vLVbn1BiPcy3VhzLdggh+foIe9R/a7hHKvEk1BcVLJ7n
KiWegm/bz4z2KhUSGyBF/6ehSN+T2BBRC0wqNFZF0/jTEbDHN9irK414BmYU
L5vg8HAL8Uz0152jsOCmE8/C5atd2Z7vQ4hnQ1c9W+f5I7Z/c6Aavyb88KUc
4rnY7rR62nNJPrERbhotDylfx3geWpfoVSwfk008HxoXFU7Gd/2IF+C8/VDj
ltVsf4yR10v83ubILmITVPR48Ov1DcYL0eVzbaKPQkJsisyAlxM2e4hoPODx
jF1zawoL/zIfKAoYYjmxVwm1m6G8ZdWxlwbHqN0Mxu/Kiqb0Ye2L8GJBn4dO
t1n/RRj8T8eB4U0Sal+Mb5f/XXH8k/CvfP5ijHSaPuaf5Uzf5jh5xKzFPTqL
2s1REjDqREVSGLUvgbvmk9nhHDGNvwQW4+/7Hv2wg8a3wI1hO0dKQ3dTuwW+
q2BMgyPbb0t0mRgbJjTxqd0S7UMCXfR3R9L4Vpj8e5v/usJMkm8FU2REzW9i
+l6KBt9NJdMaxNS+FIUNi7OCjgdS+zIInwTJe+yNoPGX4fuDrp+DVmaQfGtE
7khYN8sml9qtEfs7PTwodi+1L0dZdFX9XM0ial+OnnsvZtVvLqZ2G7geT1//
voPtvw2c9jdrnbxURu0roNPzypBxicT8Fei3oIpjt5R+z1kJo0Wn7kQtOUrt
K2FV9PDUT7ND1G6LRxru4arJJB+2iKi/+PblziP0e1s0TzsRvOzn8b9cZYsh
MfunT9t3hvrbYZNp87X7u6uovx1yvKW/Zi+9SP3tINMxcr47pob626FHv+zg
x56Xqb89VP7Ii67vqqX+9hCWcn41LbxC/e1xz2pX22bRNeqvbC9KX7jS/ib1
X4XKpwOll7fXU/9VqKtdPcHizm3qvwol5vEpMSV3qP8qPE7+4bBi2l3qvxq7
D4/xO+NHjNU4/Ev8QiWbmL8a2j0z3924Tly1Gl8dc/5p/+ce9V8DzRdD76/L
IcYauPYy1Pww9D71XwOHr73fjy8grlqD2z7mszG/gfo7oOe2j72824jhgGPR
tYEOlQ+ovwPKvti5fixqpP4OSE7/58UFaRP1X4uvnb5nzpk+pP5r4SMcNPnZ
XmL+WriuLrUZVkBctRbrXTu3nLIk5jjCqTn83pJ/aTw4wnte6VSXFySP74iW
RxE677ox+Y4wHj7pVasqzY+zDlv5veruv6L1YR0Czgsf1uTTfvDX4bzb0KXm
89j+rcPDkIZqr6ukH44TYipH3JrDY/pzQt70Mh2LRNIv3wlqEYErxILr1N8J
7Zkpi7xuXaX+63Hwba13lAXZC9ZjeeHV9G53yZ7462HR6bpLHk32VrUevMUp
Pp9Wkz1ynDG7utvFP7xL1N8ZqXf2NF48zezXGbWLtCTn3l+g/s7Yds70suvZ
auq/AbjQb8Tja5XUfwP+98jEUqeL/IO/AXWjq7fPv3WC+m+Aq1dgunFaKfXf
iLeyAarmJ8k/sRHRa6x1Q33J//kbcahigtuG/uTPVRvh49Pzt8M75v+bMKJ7
WJOZ6CT134Swle87VXeSPP4m1HA/N9Z+IXlVm3C5+eZOJzfm/1z0nnS4d9PJ
PX9Zl4v1+7f2SHi0lcbjonZOQ/Xjk8RcLsak6v9q5uXR+FysdV4y1v4lxX85
F2ruJ/fs3kvjV3Ehctbuv7ODWMFFkFub54h3+0m+CyYLBxqcmywn+S4w5lZl
N+tTfIcLXCvO/yyVkTyuC16cXxsU/Jv6813gOMqmTHaW8pHcBbOfdzPYbkj7
UeWCY2bNq+vHnib5Lrj0rehmyNJyku8Kg9I3RaPeUHzTdcXUH6m6fWMOk3xX
HOv45T0nkebHdcXnJI3X3L2UX/iuKMovXXR8Cc1P7or9MVqNR1wonla5YsCu
c/F5e2l8hSu2Te7zXbDzLMl3w6yJwwfVOZA96bpB3lhmrTOS2aMb3tuomp2Y
TfbLdYOTy8Lm1DZm3274HbX06+BUsn+5G6ZNydvbaySLl26oEOZXJuWS/yjc
4L1o/+G6BzdIvjv6zvwhsX1A/qbrjr2JHVzLulsk3x0V/cdemCog/+S6w/VO
CAKCWXx1R0hOicu3KxRf5e6ov5SzdmgU+X+VOxZ1f9/380qKbwp3WOtrmTzX
oHjC8cCV5QmRA7ZR/NH1wOPhy2oia1g888DryVYfcs48IvkeMP5u7lGw4zHJ
98CHRe26rcInJN8Duu82FWiKmkm+BzpMHplVbn1K8j2Q4vlquI6ZguR7okLR
5WK+k1jXEz2/HNwQcIMYnvDv7VZ4SEHM9cS7/MDX1S3EfE/sn6073PU/Yrkn
xvZtWblO7RnJ90Si6u7vjkbECk8oJIp+aWHEHC+kvbwU4HOcWNcLt2ePij3a
Sgwv2H5/8TtC6znJ98IQU3/HI+bEfC9EPGo2+5hKLPfCleqTZ958IK7ywmO7
rE4d4QuS74VhNcNajpq0kHxvZSrqbOH1eknyvRF980HS+IvE8MYsbY/95+xf
kXxvaBxT87ErIOZ7Y+xF/qnkYmK5NxaNXHM8X0pcpRzvf180ddcSK7zxXGw5
tHkuMWcz9CZahu5dTqy7Gav7iWQhbHxsxqjKsSP/N+01yd+MLzrLbL40EPOV
/VX53ruDWkn+ZnS+Fn3NfkJctRkB5jlXa3q/Ifmb4dt4g1/2g9o5PlC5Y753
/HViXR+IooTfunYRwwc+2lvN+6YQc31gMnXXim9ZxHxle6No+YkzTL4PRly/
s01DweT7oG5k/2T3V8QKH+wSFxu0lTP5vhhRP1W8bhWTr+QDNp82VdP64Ivl
xSbXDIey9fuiummUe3cvtv++2P991suuctKX3BdWvvkbTXoTV/niZd6RB+eX
k74Vvtji/07SHEX2wPGD29Nbe/VlZC+6fii5+WjAjF3M/vwQuTy2YGwxs38/
tDwJSPWqJn/i+6FwcsHOcVHkb3I/qCXPz9jI/LHKD9pbti2IqSN/Vfih65TW
+toRxBx/lG3fceiZE/m3rj8GpFsEW/gz//eH09rKlmoHig9cf1z6/Pvg0Ons
+cQfW30E/Lxx9Dwi98emwP/aVjtTvKnyR1enyjS9Lno+Ufijsnrbo4z+7Pkr
AI3HfoTYZxDrBqBNrLlax5nGQwCO3XlT8WYxyeMG4O6LxkulfWk+/AA8PJKX
Zykglgdg8NagIacyiasC0KulQHbNlFgRgOhKjRczqln8C8TVhQ19hq8l1g3E
MLcosyYQIxCWqryrfDmTH4hl9svWcn2Z/EAsUD2i5+ZH+yUPRPq/feN/O9J+
VinHfzO3/Gg7sSIQHR5TNZfrsP3nYYaOid+Dt9SuzkNhsLWFaSHTBw/9DUVe
U9OJDXnwM5J8WnSHGDzk5vZu2+lH49nyML3fwYAvuqR/Lg87Ru7yWJ5LzOPh
at1k1/xUYj4Peq8UDfr3qb+Mh+s/fM0PHaLx5Up5daqqqh60vhIezn9szZ0d
zfaXh6rIHhNPmRHX88D/+KxZpYHtNw8xaf8MWN+bxmvn4cZN0dppUWz9QVjk
PCms7CTNRz0I3Kxl4pQQsmfdIMgnjjXryic2DEJy8g9D+0BiBCFlRedWAzNi
2yD0GZPi7RJNzA2ClY2T7/oN5C+8IKwS+M66HsnyRxAWf7MIsk8kf5MF4dK6
c1FPdrJ4HoQTap/OL8whfy0JwvnWD9qZq8ifq4Kw88/8D8euE9cH4cPPqS+a
tMj/FUEQcRZfd1xN3B6Eq1GWsw8VE3OCMdv+/vT5iyieqAejXnv3e+lAije6
wfgeuqn/VxWKT4bBmFkaXGv+jcXHYBxapTVF7xLFV9tghAaNgd3yt7T+YEzb
c6xlTCoxLxj9vpxPmyog5gej4GFf+3AnYlkw3D+EYZIhsTwYKpoBPX/qEJcE
46FLvcnskcRVwbiU+unFlqnE9cG4EFeH3bOIFcEYZzzhyWD2+/ZgbFvsaj3p
Cc2XE4JYFbMC4xhi9RBc7T9yd+++xLohcMstFXbbz9Yfgt3JbY6169n6QyBX
k28snEVsq+yvk312tB7LFyE4MzP2we8RxLwQmA1Z0K6pyvJHCLpuFOZdv037
LQtBzJb3H+oFxPIQfJG46Vj/Q1wSgqwVPU4WX2L5NQQjk6VlDyOI60Owbdbq
eoEly7chWJy+qq5jNnF7CPQ1F0ycs5Dl31AU8BcVh7L8rB6KnNqPCaWRLB+H
IrqH+870XcSGodCK/6i/5RzLz6GYY1/wc76C2DYU839qhdqosXwViv2ynbdz
jYl5oTC+rDtovpDl71BsWnNiy4oWtv5Q+FltWZu0geXTUPS88a4P9y1xiXK+
vxxrliaQfqpC8aCfiai0H9N/KLrLTxW2MvtShGJQ99zLBg1M/6Fo2bVsjH23
d7T+MHxrblv2SpVYPQxrV/yPu+Yt/V43DLVeW4P0TxEbhuFMBf/omDBihCHy
4akZn6cQ24ZhhMG1vpxWmh83DGpnNwUHlRDzwpBV/qFkYSYxPwx2vz8Hvk4l
loVh6P7QbXVZxPIwyM3+N1ZLTlwShuV7Q0/33MLWHwZHu8odomXE9WHQFl3M
SDnLnjfCcOyN2oBnr2h/28PQ0u7xAS+Z/sOxRXNL+tsnFA/Uw9EWWXOf853i
iW44TlTO+DDTjtgwHBpXphVveUfxCOGoHmRl5Hua2DYct5eZ7Fmwj5gbjrnZ
Hy6eZ/GLFw6FYXZ7joyYHw6tneNN9POIZeEIMrLnHrlCLA/H8oyxs6fokvyS
cLhkB5sdyWLxLxx7T3kMWdCT5l8fDrvLHwcFsHinCEe7ylhxgReLf+GQTNl8
Z7g5i38RGNqv52B5H7b+CLh6Ph09+x1bfwReJ61MEA2gdsMIROphxR8+ez6O
QFH2kFmrJjH7j8AbV8tLpxrY83IEtKI/tBfbMPuPQGeAbs8MX2b/EQgqPJ/1
3ZDZfwQczu35WFPFnqcjUKVx/5evDXFJBPZ8H1Lz9A97vovAak+tYxdb2Poj
MO5mk77rG7b+CMjcm46CcXsEUqQOfnMvsfVHIiVweVsGj60/Eln5lwZN+MPW
H4k1ZlkmJZlM/5E4N+agiroxMSJxV+/hGe1exLaRUH2sv+tZI9N/JE7MnN5g
LWX6j0R1vmHEf3/Y+0skxh2o5HFmEssiMWrBVp11oHwoj0Rz3NgbemspX5ZE
oufKITO1LSifVkUiI2Nd9tkAyrf1kTjv+WJimTqxIhI/uzWrpbRRfm+PROrD
R5aHaok5UVh4ssBaJ5vl/yicNz4183ECsW4Uuk9xvX7wJrFhFEzOu1RpFLP8
H4VD2md2yrvT/GyjEFefGWF1kj0vR2Gkt73RofG0Hl4Uqk84Tx+hTcyPwnph
1xrHVPq9LArudnoFPs60PnkUhr1riB36H8kvicLl43YTA3ew5+so1HeW6bs0
sfVHYU8jvp2upvEUUVht3Fyi7kP72x6Fg30Lc/40s+f/aPzM6y8oLSb9qUdj
7Jd+T2cdZ/qPxozKYcvLdZj+o/HQtPzfvNXM/6MxR26t0aqg8W2j0bfoYdeX
/kz/0djcf9my6kdM/9EIu9xxeCyH7I0fjbunzjr/GED2LYvGkfoQf8cSZv/R
GGruHLn1CrP/aIhTauzVUlj+i8att9+vapiw/BcNz6+1y8zNWf6LhoX6qHL1
yyz/RSNzy4pcu1LyN04Mev5ZlDS1juKlegzSYv2j1rPnGd0Y6Ef8Z704lsX/
GIx/+znC5guL/zE42WO5yiMnyh+2MYjn/BueqiDmxuDdPKezi/a20fpjcHaE
vLYx/T9afwxaIlvCfELf0/pjkPdVTewx4gOtPwYGVyeNX+1FXBIDzifuYyd3
4qoYFEfv85dYE9fHIG6H/6oJbsSKGBwetD3r38fE7TF4IRUMP7mhndYfC78t
2780tBKrx8LZ2PyZzOcjrT8WPZqWJehVERvG4lHbmAt6jcSIxWHfwP155cS2
sai4bRlmH03MjYXVuEdD1xgT82Ixw8Xnj8kQYn4sgpqlY/IGEsticaht3vCs
0cTyWKyvfPI4dCZxSSzyN16Y1teIuCoWJRpFus26xPWxGDjUzv7GW1qPIhZb
5r15YL2TuD0W4RFr9x2ay9Yfh6cW9/nqubQ/6nHoXVL/dUkV6UM3DlYXf+j4
dJK+DOOg5XVRq3oFMeLQ+D+TfFwj/drGoce+62kdm4m5yvY7yWW9tJn+45AT
0fik+BTZBz8OBl1e79ZPJpYpf194zXGCO3v+jUOfQC+tNl+W/+PwapffOV93
Vl+Ig8Rmw8tR0WTP9XF4veTjoMH1zP7jYCfc96g5gNl/HM5Yj1w7Eiz/xyND
L+H6Qx32/BeP0Lf9NBvvsXpQPAxqtm6Z5MryXzyOezQNWn6Pxf94DDlotaJh
DYv/8Ri5pPnMu0HE3HioO89cHD2MmBcPnvr0BaFOxPx4TOAecfDMI5bFw7ph
W6HhPmJ5PPKd1rmWWbH8Hw9T//ZXwVspnlTFw2Ri7L2KEoo/9fGoa3Xs+ec1
q7fFQ8PtVYd1IHF7PFoj8icvWsPqbwm4quUwLCWKWD0BN4I65fw9rB6XgFlb
l/dwkxAbJgC3n5200GP1kQTUZsWld5ey+J+AUTdPdxO/ofjNTUBMf2HINEv2
/peA0gM6O7KDWf0kAXrHxBdj9Vj8T8CkmnG9B5SyemIC+lgVe35XJ3klCbAe
9uklR4vVFxMQ6ftqbnwF/b4+AXZd8vtT5rH4nwDbtAd+P4pJXnsC7BuS3s8+
TczhY4/7uiUVLvR7NT7+Ue+jKbdh+8FHbU3MzbRNtL/ayt/fqUk7voL2X5eP
ZRsOeOx4S6zPx9VX6vo2U1m+4EN7rF9T2VxiIz50/kyvLFvA7IePM7PzDl/l
ElvxMf5lRWt2KbMnPt5N9A7vP5zsz5GPFp2hPZbEEnP5mPZjbemnCmJvPiod
NrS+Y8+zPD4G2E6wlncRR/JhcDpr+4IFrH7Gx8a7Pe9oVRKL+HDflJanI2XP
Y3xMej2avzCZ/C2Xj88hX4oM2fuHnI/8J13B0cvIX4v4+Df/7GaN6+x9lY/B
PReE6/Qk/y7nY7jPpUIVTeIqPu59ufhh+gjiOj52XJYKbi0kruej/nrYxk9i
4kY+jmwZ/KD0G7GCj7u+3XXmh1F8aeVD003UR/09cbvy9zd29N60huJVJx82
muVTkw4RcxKh1XvF+eyPxGqJqC3943l3LsU/9URM1MtW2yEk1k7EsPE2Bc6P
WXxMhG9zrcf/QPFTPxHHnh3S9jlGbJiI0Q/iPXfqULw1SsSdqMJDaa7ESER/
p0OZ28uIrRJRfV/j6jKWD2wTscjvXIVXELFjIsYtiXPb3sTySyI++Ukff7Xo
IP0nYoPpD/Nr5cS8RLg2tnaznvqJ9J8IgwmepiZyYn4iLg+P/rinz2fSfyJ8
Lqd903Unlinnv2SQrcUB4txEcPzPBl+4RSxPhMaETQ9nviIuSsSZrLLnLZ+J
SxLhEec2t1jtC+k/EW0Wa92OTyKuSgQEH7Q9nYnrEvFq+6LfHTnE9Yno59Ln
ut1N4sZEaFt9eh/7lViRiM8rw0YNUftK+k+Efc7j8doqxO2J+NF34AXFa/p9
ZyKWFi46+a2CmCNAjazA1T6RWE0AVcuFw3YYEqsLwKkwPjWrhtajLYDLhNYF
OSbEugIEf9u9YRvbT30B+tnoXHvyi/bfUACDlivFPpuJjQTYX75xYfYn9vwg
wI8649Pb9xJbCdC7f8lhD/b8YStAbsdk9w/zmP4FsPDbOfHsd7IXrgBPv9na
drH87i3A3nvHYu1GEvMEkM3hG/QYRfYYKcBoDQPnA/3IfvkCqOxqarhqQPYv
EuCu6ihRZQ75j0yAJ1xJybr5xLkCPFCbk+rVRf4nF+AAf17t9+PERQIkPI2y
2GtPXCLA989XCxIfUjwoF+CVxRW9QA9WvxIgy7Gj/xtN4joBip21HptyWD1D
gAKP/J8vJxA3CnC9V1esZiirbwiwnuPUPqWSuFUA9fLV82WvWL1DgChuU+jl
JuJOAS7rh17ttZeYkwTtPlHHdjkSqyVhhSKx4+I/xOpJmJlh9T8eq59pJ2GL
05JtDjasPpKEPUnZM7n7ifWTsFtSLY7pRes3TMKL39HePFtioySkXvzn5Wg3
YiTB/tlm+82GxFZJyM7OKetzhtVTkpBlVfzxiTqxYxJc/Sbpt69k9ZUklC4L
EqjlUHz2TsJWjsS78Td7305Cfu2gA0/ziCOToHrTdDPC2Pt3EqaPsp/UHk8s
SkL9pYSkhQdY/E+CVlD0aet7xLlJsDzhPGtMJ6vPJSF0o//+M/1JfpFyfhO5
42NHs3pVElwK2sxKQVyehPfa1uiexJ7fkuB3WJF69h1xXRIMzVq1ggNYPScJ
538v7F7cTtyYhBuHZRvq1jD9J6Gj5+33T9OZ/pXzbbZVL5Ez/Sdh9fpS/syj
TP9JqGs6tL7qBdO/UPl+Ytvz1mbafzUhhOduNQvtyd7Vhfhqb/Ny/BbyD20h
zFd/tcr4zeK/EHZr9Tc6zCJ/0xeiq6StuPEOsaEQDu9cL/+wJf81EiIpdeVl
k1Lm/0IsNN539vIv5v9CrGwo7FMCihe2yvmcvTZFEEfsKMT32etCPYuJuUKc
Mlyq8fY6i/9C2CwZ7DHiFov/SnnbXhxrO0UcKUQPp1/7vmcR84X4GHNiqGs4
sUgIo2uDTjnxiGVC9PPv635QRJwrhAIz9q1n48mFaHl774J5K3GREGVdf8pG
dqd4WCLE4j79/G99ofZyIXbbHUn7eZa4SojQ7T73/bnEdUJsG15y4eM39j4j
xJ7NA39xc4kbhXBu3bFpIttPhRDD+CN488cStwphK1U5cbkXcbsQ0pPC7FVf
SR+dQvhP9fOVvGLvP8mQf577bUIjsVoyOE+eBMy6zd4Hk2H2qZuhYxOxdjI+
qSZ5zP1MrJsMc5f36w1GkTz9ZJx/7rTX1Ya9LyZjNFdH5Wg4038y/AJEn6qy
mP6TsXRxf2vdg0z/ydhm9GPI8bMs/idjn9m4+YqnLP4r5VtF7JGMYvpPhsAi
fMWGKKb/ZEw43iqf/5rpPxnSeca2uWtZ/k/GmNrg0gmnWf5PxkTnli/bOCz/
J4N/bsfoaVNY/k/GrbWeG54uYvk/GZHmNjoTV7L8r1xf8Yk59xxZ/k9Wxq8P
s0K5LP8n46YT5/bvjcTlyUibPiE8dylxVTIuhYmn/TuUuC4ZO+3FXvPqaH71
yThX5lBw3424MRl7fe82D+ii9SmSMeqL03z+LuLWZJRPrfHXWEXcnow5HtbW
sWOIO5Ox8tTVe/2Zv3FSsKjjCz7fJ1ZLgeHh6HNzdhOrp+CV28BXfGti7RTs
zB6p/ryF6T8Fen4ala0RzP9TwCvaftpDm/l/CiJ7XDW+Ukz510jZ3m1F2ME4
YqQg6ebpqXpbia1SkG39JjHvJrFtCvblmKkd7EHjOaYgteRopHgAy/9K3jf5
0epv9HvvFISpJFj0zifmpWCKgdahvjNY/k9BoqBl09cmlv9TsNBh2j5FBbEo
BQbvK3itH1g9JgWe6y0603nUPzcFcS6rvASDSb48BWvdLE062fqLlP0nK9zS
7hGXpKDYf+mi5pG0f+UpEKdXXlrB/LcqBY/3fhidEEBclwKhefVFcRzz/xRo
5VYMnJrI/F85X/95nZ+imP+nAKv+mM7yZP6v1MeJ2NbhS5j/p+CTwaeAOzrE
nSnYdmDhw/Q25v+p0Bo6tRe/jvl/Kpr7vmyedYr5fyoiHf5LijvL/D8VLp4f
XcQ3mf5TMSjcdP5PBdN/KmaXXb/w+ynTfyrMYndfs6tgz/+piH2WMWEFjz3/
p+Kjxo416irs+T8VjqdmZkd1Y/pPRVr0177DflL+cUxF1B+P01MHEHNTIVw6
+7SZKeUr71SceLR7z2Ih5TNeKoIyhnTk1lG+i0zFxV0aw0t/sO8vqbhardq8
bASxKBV9bA/9e3kB5WNZKoqbtwRWRrD8n4r6mIvJz9tYfTIVeBI9aOUh4qJU
VIrbXfvvZ/XKVMy8MFrbhn2vK0/FoambA6Kes/plKnR7/ew98BlxXSp6b/u4
kXec1TNT4VE7dVO8K3FjKh5Wbp56pCer76SiZahffflZer9tTYVhQ07R2yxW
70/FsD/fN16REXem4syJQVHzC1n9XwThQYc2zmliNRF0bmVbjjrPvgeIkLny
TVIU+16sLQJ/2POG89tZfUgE56vmH69IiPVFuDfypA5vF6sXiWA3onSw4Dax
kQgqwqIRmePY90MR8i562e+II7YS4Xzut/ja8+x7iggS/vYx+28QO4owYkrB
7XPseyRXBJ8x7+bEsO8v3iLcEZgcDhCz938R9qRt94iop3pCpAhbTkamJGmz
+pMIf4JConaEUf1CJMKrltMXjn1i3yNEMH5ocCYihzhXBMe7VcsVTuz7vAjj
Ahx9EuYRF4ngduJyy3F94hIRfgaE7iwYRVwuQrzlk1CTwex8lggmTlnhASrE
dSJs5ARN+/of1V/qRRjwwrZ1YDNxowg2k/Hk61NW3xIhMDCgVIv1b1Xu15De
T2tWsHq/CI8CLVUSaok7RVibY+e725XV/8XQ6DCcPbM/7YeaGI/cp/S+U8K+
B4jxvGhhG38B078YvofVml4dYPoXowFJD/73g+lfjA2G9nucV7LvxWJ8ldWo
aLPvxUZi1Gcm/LN3PTvfJEbGssyVHuz7uZUYIzQfD1IzZecJxOj+dvW8pW7s
+V+MbQv3KY7xWX1djIvFozrmRDH/F2NHZ8Oy8vkUH3hiHHCJfvD2InGkGBMO
LV12dyyL/8r17D9+s8KfxX8xStQPvN9/msV/5Xx1Y1T7a7D4L8bE6dZxS8JY
fV6MyXWNTtENxEVicCtDbvbRYPFfDMuuwy3VE4jLxQg7kp8QOZG4SoyF4W9f
c1l9pE6MvN6T9+3sYvV8MayXmvS4eIq4UQxcejK0LITV98UQ/C/m+4LpxK1i
fLrIUdf9j+bfLobD5RrrdXuJO8Xo4Rq4tdGKmCOBaUdb8sVnrP4jQY9snpqR
P7G6BGO3Pxg8+z/aX20J3vm9tnRzJdaVYJVGgyr/GulDXwK7NyVVwyew9z8J
Pq96IL0RTvozkiDL6PzjxmrSLyRoCB4caqxFbCVB470N8xz57DyFBJpbBR1T
BhI7SrA39fG+M5fY+QIJ7BUtfja5xN4SDAjIuuTO4jVPgpvdgi1uWLP3PwlO
zv4yTtqdvf9JcGD+2ne221n9T4JL3wTfXvZj36MkmJexBqdDyb5zJXj8KKHs
4wtWn5YguNxsdLY/cZEEXyYNz7QeyerVEtzu9ryl1xfyt3IJjhsLbVf8x+rX
Eqz5I5Q//EpcJ4HzllEyyU/iegm2lWes2PySuFECL+Gk6hPb2XlOCZa+PiF+
8Iv5v3J/l8/xHN2f+b8EdTYPp7tfp/pupwR9194ZF3SUvhdypJg1oN/PTSfo
fJSaFI9dNWOLtOj8lLoUd3+MXyzTo/Nw2lLMC56mwxnEzstJwW/MnZVZSefr
9KVI9jlosLGF2FCKaG/HOANN+r2RFPOPepsebWP3BaRYbrXmvcccYispfiP7
6KTPdF/AVooMvT+62k50vthRioJrY3sYlbLzyFK45C+bFOhL55e9pTjBHb5Z
/Q+df+ZJsXHHmLT/ftP56Egphq5fNGiGbh3pX4qOux6md0bT+WqRFN7rvB9E
vKPz/zIpRgnHbp9+iM5n50phHPHsza85dN5fLsWI4knP2l/Tee4iKXpM2FJn
70rnzUuksG349Xqq8SnSvxT1jQ49T7bR+f0qKXIHvl+RO4fO99dJ4ehtk+XX
SvcB6qVQHBGe7qVL59EbpTDy894w25hYIUWo2d0ZCjM6/96q/P2k8uJFBnT+
v12KEuP6Zx59aX6dUggP/Dz8+SnNn5MGv31VttL/6P6OWhpiqzvyfAcTq6eh
3PNF4Z8N1F87DZqTOgZaedD4ummwcty55MBRkq+v5Erv+ObNNH9D5fhPK0Ja
Cuj+gVEa+GcXO89Qo/1AGtr9fYaWmJ4j/aehbF/N6e9tJN82DaK5zZPVttL+
O6ZBJUTieMeX2rlpqFDV91sxuYL0r5x/ULf80eY0Pi8N6g8XB25aQfsdmYZc
yZMjDfvZfak0GP+ShRZ70n0AURrqrmndXCQ5T/pPg1NNT/fI03T/IzcNPgnq
Q//cpPsjcuXvR5rPXDCE7KkoDYWKuEmTxWRvJWmQ5w/Stwyj+yrlaZB9vHC5
axk7n5+G+EJtu0t+dD6/Lg2TnOfOFQ0ie65Pw0+X539OjCZ7b0yDKr/25B1f
On+vSEPHBZPtrnfJP1rTgDuzk4ON6Px9exqC35scyI4l/+pU9g+NnPFCyM6/
piO3ey+BE8i/1dKxsOl34dFiYvV01MxWSdV5y/w/HYIPV+aOHcbOq6bjaDii
Q3jE+kpWXZqQok7xwzAdKw4H7f/3D7FROu4GfMgRjmbnR9MxrscSc54Rnce0
SodPH1OeuTqdb7BNx88Rz4N6JBE7pqO6251eU7ew86XpsA44vVvFmdg7HYd7
9DWJGMTOm6bj5q5WneF3aPxI5fgV19aNzmf3B9Ix+ISFCd+JWJQOy2eyP+ea
aH6ydKgeGcpBN+LcdAx42HlhThM775uOXq/FZ05l0vqL0qGekpS51YP2qyQd
7TfXHP3KzheXp2NQAXeotjY7n5yOnJ3jDPIfk37q0nFMZ8oBi+3E9engn9QZ
EqlC3JiO8gt7LQu+U3xUpENsH6S7XsL0n46XXvUJu9vIXtrT4fpQ1Wr7dbKn
znRUjBBKS+zI3jgZuLPKdF0ps0+1DBhME9uWfiR7Vs9AhNtdq/eOdN9EOwMN
5r9Fzk5k/7oZqOhnWra1g/xDPwNnttasvhVC/mmYAY3Bu/1HV5F/GmUALzft
/2VH96OQgaay0/wrbRQvrTKwfoThh8ejKN7YZoDjcW3B8GfU3zEDJvNHJceq
kH9yM1BTt3Rxex7FD+8MJJtceztiI/XnZSDm0+24dRKKB5EZyH3pkP2nht2n
zMCqV64lj3IonooyUBz2v5fZvgWk/wyEHvmnx/YbdB83NwOt2xL7Nx1OIf1n
wGpEU+WbPtGk/wzIHkSq7NSj+6YlGWgv06vD5UzSfwYO6YUvHM3uC1VlIMdU
0vP8O7o/VZeBnj829vXU/pf0n4Fxi3c1jS1i8T8Diz2vDU3bQ/eLFBlQ7bds
0QAh3SdtzcCMwbnQ2CEj/WeAf2ZIZFV3q8q/+s+A+uABCzorRH+ZkwltrZ3T
MwbK/rJaJoxWbZg7lk/3XdUz0X5BI2CcXsRf1s4Ef0lC6tIOC9J/JrgDh137
vt6f9J8J+dETskEhXNJ/JnRzV1ZcafX+298oEyVrTB49ik36y8iEGt9+33x2
/9YqE5o2JWardLf9ZdtMPL7S9c+ZGXRf2DETsvf2r41q6D45Vzn+QO/cLIut
f9k7E7aBOx+pPE7+y7xMcGof931aCNJ/JhTWx6cIj6aT/jOhX7Jm5PVXpA9R
Jgpn+XJ7Guwj/SvlX+6IExwjzs1ErkJ7lPV5ui8nz0RVfGxCYCONV5QJeAgD
Pt1z+Su/RDnfQ+Pnf0ij+/DlyvlVNL20zKH741XK/crclKqyne6P1ynXoxnS
r2Uj2Ve9cr67R4/gRtN9uMZMOE6wL/3gRPIVynbNgfmFxnQfrVU5nw8Xv9Wk
033xdqV+zU7Ns+yk+8ydmQitCuM5u8tJ/zKkPdqlv6SRuIcMuqe+B5YZ0X1s
NRnkqYdtF/wb/ne8fjJwDCc7jGuk++rqMtieDrwiHkD3+zRlKJy6aqXLTrJX
bRnqNmqm3Hp18C+PkKFox8inJ5rYfT8ZqgbkrSk7tO0vj1OONyzDRDqL9lNf
hvpde2MX/CB7nqLsX+w6VpBH96kNZdD+ue5O6hWazywZ5nuqxP+oovGNZMC6
Ra0uGqRfY+X8a+ekNVdvofgjQ/vd8aM9veL+srny9wrz0/H3HSgeKedX7Jwx
7uOGv7xcBu752rjG6hiKTzJ4m3aXvxHTffrVyvlmOcvUw+j+u6Oyf9pKgwUm
NL6zsr//RF5JXjDZrwyynj36H/5F9usuw+A8rfa8PvmV/wfl2GjP
       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1049.}, {-0.0571335112196974, 1.3781489188458038`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484541311043*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"224e6260-1d21-4985-b7f4-2a871f18b215"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484542275468*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"7872f8fa-56d7-4dac-be8e-9c6ff86968ee"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxE3HlcjN/7P/BUkrUQhRCSKIQi2V5SCaESQrRo176phGnfa6ppZpqiwjsh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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 2099.}, {0, 673.0992609362854}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484542371965*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"2986ec1f-448e-4340-a9cb-371f00932be0"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674845423799424`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"bcecb256-8620-4961-9c4c-cbd53cc80855"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVl3k8VO8Xx2eMpZAU0WKduXfGbmhSWjyHJNXkSxFJC1mzpVQSJSmlEhFS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        "]]},
      Annotation[#, "Charting`Private`Tag$4595059#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7AOSTMvjUrUdoAIO3x7Efrv9RA3K53CwvF+/
03+HEpQv4OB+8vDckBeyUL6Ig+jhM67TI8WhfAmH0F2HeG8+EITyZRwepc+7
eZOfG8pXcMiV6md6OIEFyldyOFQs6iKjxQDlqzi0KOa4skz6bQ/hqzl8FEjq
j3v8C8rXcBDjMP5zuvYflK/lYGqksm9iMDNUv47Dihc/dqsf5YTy9Rw8vr85
KeIKc4+Bw/3j9+x+7xKD8g0d0hK+lX5UhPnHyGEZw6+997Rg/jV2WP1ad/19
GVh4mDhwZbn4rYzTgvJNHQysNyieeqPnAABYUFYJ
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 17.008727605856762`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484542474688*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"7210e408-3d04-4710-87e5-4256fb39068a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", "2.952476974095952`", 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", 2.952476974095952, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674845424806724`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"6ef0e694-86da-4231-b0be-445fce1423e0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["1.4927`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[1.4927, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484543112342*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"689b97de-e320-4310-8f2a-31ce0a276d12"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674845861688614`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"4a9a7d9a-ad43-49ea-9b1d-cbb397543401"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5.976509333330347`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", 
      RowBox[{"-", "29"}]}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.9612840811253103`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674845861738477`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"a86196f0-1845-4123-8c8b-498a98598426"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674845861768403`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"74f39b97-4aa5-40e7-a0d7-7e8b60c80aff"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1XHlcjN8XHhRFfEPIPgjJNraE5JGlkIxKstVo12ba95pqqqmmmqkkW0a2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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1XHlczN0XHpVkH4SEGgpJGKmE5EGSJUZCEk17aJn2vaZ92mcSJVH27FlK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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1180.}, {-0.04231303407508171, 2.8724221337686444`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484586265602*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"7e9cc6b3-ec72-4b79-b435-8ee8b8bffb3c"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674845875352077`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"c9c1569c-509f-4cb3-bc7c-f5a8108ddea0"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxEnXlcjOv7x0OSCkkIURRCiJJQ+UgSkiIkSSpt0r6XTPu0T9PUTFMRQggh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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 2361.}, {0, 1267.2520979976548`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674845876289577`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"54a637b2-fddf-4bb4-92bb-ca6dcff6a4de"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484587636936*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"29b1c049-a792-48d2-b902-f64c26ef0534"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVlnk4VP0bxonyZou0vKIxZ2bOmbFknUjC3b5QqRBKsk0iO9VblLQoLVSi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        "]]},
      Annotation[#, "Charting`Private`Tag$4666174#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7H+oTJPb/j/FASrgcC3jsVRXZyKUz+GwRLzy
/baZMVC+gEOP89+l5svCoHwRhwUxarPWeQdC+RIOTaU77p6x9ITyZRwCTqj9
PBXuCOUrOIhxfUpbrmoG5Ss56Bx58+O3ohaUr+IwyXB7vUW7HJSv5sA+iVvg
03NxKF/DQehPjXJSiAKUr+Vw6SST0ZZ4HShfx+EL36wdc76YQ/l6Dqu/ro/e
s9wJyjdwmOXA3LmP2RvKN3QIWL898kFpEJRv5LCzwVWtSyYCyjd2mBZ0rzAp
MQ7KN3FIkHIxOjo9Cco3dUjdfcBf0zLNAQAqX1VN
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 195.56492220313328`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674845877127333`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"b4bd725b-eb7e-4d71-a30c-3f5c99c3f131"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "1.1013147443609683`"}], "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", -1.1013147443609683`, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.867484587718717*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"7ad03db4-e589-4ec7-8a4d-c352d5f607b0"],

Cell[BoxData[
 StyleBox["\<\"Coupling constants\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.8674845877227087`*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"a63c0342-f243-4f10-9589-028ab4afbdee"]
}, Open  ]],

Cell[BoxData[
 TagBox[GridBox[{
    {"7.573319576608222`"},
    {"48.725041724217135`"},
    {
     RowBox[{"-", "0.10774000237952099`"}]},
    {"3.045832811380205`"},
    {"9.122802660371008`"},
    {"17.993179827785735`"},
    {"2.952476974095952`"},
    {
     RowBox[{"-", "1.1013147443609683`"}]}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.854021844132286*^9, 3.854101246023014*^9, 
  3.867478050523447*^9, 3.867484587725701*^9},
 CellLabel->
  "Out[225]//TableForm=",ExpressionUUID->"b16f0e47-435f-4806-af89-\
f5177483490f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Time used = \"\>", "\[InvisibleSpace]", 
   "356.1691475`10.00320129028849", "\[InvisibleSpace]", "\<\"seconds\"\>"}],
  SequenceForm["Time used = ", 356.1691475`10.00320129028849, "seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.854021514488858*^9, 3.8541009160257816`*^9, 
  3.867477692444875*^9, 3.86748458773368*^9},
 CellLabel->
  "During evaluation of \
In[208]:=",ExpressionUUID->"89b15424-f14d-4ac8-83cd-2c3845889fb7"]
}, Open  ]],

Cell[BoxData["\[AliasDelimiter]"], "Input",
 CellChangeTimes->{
  3.854022500632781*^9},ExpressionUUID->"3c1a9fa9-bf44-4c35-8d0d-\
52c2851a5098"]
}, Open  ]]
},
WindowSize->{1278, 1348},
WindowMargins->{{-7, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"12.0 for Microsoft Windows (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 538, 10, 69, "Subsubsection",ExpressionUUID->"e0dd5b4c-3a91-4051-9a25-a39ac98e766a"],
Cell[1121, 34, 1443, 29, 320, "Text",ExpressionUUID->"c61c22a2-f7f7-4bd3-b074-cb3183ff65e0"],
Cell[CellGroupData[{
Cell[2589, 67, 29866, 709, 1872, "Input",ExpressionUUID->"83ce1c8d-1a22-4fa3-84c9-6c6be868c2d5"],
Cell[CellGroupData[{
Cell[32480, 780, 679, 18, 29, "Print",ExpressionUUID->"6950d68f-8f34-41c3-9323-68f22669f5c5"],
Cell[33162, 800, 294, 5, 22, "Print",ExpressionUUID->"ee7c6538-d223-4b8d-9d8a-97c3573c0fca"],
Cell[33459, 807, 454, 12, 22, "Print",ExpressionUUID->"783eb339-984c-44de-bf26-0315e9cfd726"],
Cell[33916, 821, 314, 7, 33, "Print",ExpressionUUID->"dee9a0a6-6a19-4e95-8953-e6794165f212"],
Cell[34233, 830, 18447, 320, 226, "Print",ExpressionUUID->"69101572-58f4-4b90-bd10-fbb437459a06"],
Cell[52683, 1152, 350, 8, 33, "Print",ExpressionUUID->"8ae74ebd-bc5b-408d-bc20-a3b64cbb51bc"],
Cell[53036, 1162, 17135, 298, 225, "Print",ExpressionUUID->"dda4dbda-4a81-4bfa-a7a1-b95e35cc79ab"],
Cell[70174, 1462, 382, 8, 33, "Print",ExpressionUUID->"74baf4e9-011e-43d1-82e8-087505c1eaec"],
Cell[70559, 1472, 8309, 156, 247, "Print",ExpressionUUID->"a540bf6b-0ee5-4c74-bb38-dd3edbd645b7"],
Cell[78871, 1630, 542, 13, 22, "Print",ExpressionUUID->"da1d46e4-881e-492e-853a-6c31c6d158bc"],
Cell[79416, 1645, 681, 18, 29, "Print",ExpressionUUID->"82e9f9a2-671d-435c-935b-a976de9a04c7"],
Cell[80100, 1665, 294, 5, 22, "Print",ExpressionUUID->"e88cdd7f-303b-4101-8487-580e298df583"],
Cell[80397, 1672, 455, 12, 22, "Print",ExpressionUUID->"ff0c5677-6125-4920-88c2-bbd745545a18"],
Cell[80855, 1686, 314, 7, 33, "Print",ExpressionUUID->"fa1f63ca-55f4-4efc-a754-360de6b475d1"],
Cell[81172, 1695, 58241, 973, 224, "Print",ExpressionUUID->"8d52e2a8-b22f-453d-bc79-b5f2d09a3d9e"],
Cell[139416, 2670, 350, 8, 33, "Print",ExpressionUUID->"4c0c3d35-070b-410c-b09b-307f26f48e24"],
Cell[139769, 2680, 51248, 857, 224, "Print",ExpressionUUID->"ae62b28b-e23c-4f4e-a7c8-0f5f32817561"],
Cell[191020, 3539, 381, 8, 33, "Print",ExpressionUUID->"fa76739c-5454-45c7-a8f6-640de207f961"],
Cell[191404, 3549, 8179, 154, 247, "Print",ExpressionUUID->"a5fcf837-4b5d-44e7-b37e-f34e2cf69719"],
Cell[199586, 3705, 545, 13, 22, "Print",ExpressionUUID->"b7451008-35b4-4cd5-a642-e424a63305b6"],
Cell[200134, 3720, 681, 18, 29, "Print",ExpressionUUID->"9729f968-9fa1-4310-9294-2dd29209602b"],
Cell[200818, 3740, 291, 5, 22, "Print",ExpressionUUID->"088a3daa-f2eb-4cae-92fe-ce0d72a37171"],
Cell[201112, 3747, 474, 13, 22, "Print",ExpressionUUID->"dc6df369-7b49-4893-a7c9-860da7afaf8f"],
Cell[201589, 3762, 314, 7, 33, "Print",ExpressionUUID->"c13f32a0-dfb1-45b9-9dfc-2c4396b9168b"],
Cell[201906, 3771, 24454, 419, 228, "Print",ExpressionUUID->"b18f7f1e-8969-4870-b232-0ba44846a07b"],
Cell[226363, 4192, 352, 8, 33, "Print",ExpressionUUID->"0398dd62-8433-4b26-9dc4-d5b084da3ef7"],
Cell[226718, 4202, 22830, 391, 231, "Print",ExpressionUUID->"0d7b965f-0ec6-47b7-9861-d84b87ae4469"],
Cell[249551, 4595, 384, 8, 33, "Print",ExpressionUUID->"c1f05455-4688-4468-915b-a03dca14c77f"],
Cell[249938, 4605, 8144, 153, 247, "Print",ExpressionUUID->"0f459a84-e3e0-4273-93de-b3cea03d4dc0"],
Cell[258085, 4760, 565, 13, 22, "Print",ExpressionUUID->"18ace200-d469-41e8-9078-1a3b9c47208f"],
Cell[258653, 4775, 681, 18, 29, "Print",ExpressionUUID->"e61b563d-b9d3-49f6-80a9-0194a8b001c3"],
Cell[259337, 4795, 294, 5, 22, "Print",ExpressionUUID->"b1509ce6-399c-43df-a2ee-e76a9cf5ebe3"],
Cell[259634, 4802, 453, 12, 22, "Print",ExpressionUUID->"a7675a21-106e-4497-9916-8e2547e25c59"],
Cell[260090, 4816, 312, 7, 33, "Print",ExpressionUUID->"ebf3f5fa-8d82-4117-8948-e1b40720379f"],
Cell[260405, 4825, 24258, 416, 225, "Print",ExpressionUUID->"3c2b5d42-0d77-4174-96f4-d60f6764924f"],
Cell[284666, 5243, 352, 8, 33, "Print",ExpressionUUID->"4f50371f-2a8f-451b-b0d8-a01b48297649"],
Cell[285021, 5253, 22804, 391, 230, "Print",ExpressionUUID->"f3d05827-1259-4369-8695-26f9493d2a19"],
Cell[307828, 5646, 382, 8, 33, "Print",ExpressionUUID->"2733e9b4-12a8-4801-b32b-e4042625b0db"],
Cell[308213, 5656, 8083, 152, 247, "Print",ExpressionUUID->"3384d715-427e-4a55-a935-2d030fb6e164"],
Cell[316299, 5810, 542, 13, 22, "Print",ExpressionUUID->"0ed5db94-ba66-4b59-a51b-340f159edc08"],
Cell[316844, 5825, 681, 18, 29, "Print",ExpressionUUID->"a52f9210-ea4c-4bd0-8716-bdd0f2311390"],
Cell[317528, 5845, 294, 5, 22, "Print",ExpressionUUID->"a83cfb32-a66d-4ff6-bde2-d7df685b4e25"],
Cell[317825, 5852, 455, 12, 22, "Print",ExpressionUUID->"36408843-d4dd-470e-a700-c35130ed1b39"],
Cell[318283, 5866, 314, 7, 33, "Print",ExpressionUUID->"02ced007-93fa-4a13-bb3c-01784ca760f0"],
Cell[318600, 5875, 50774, 850, 225, "Print",ExpressionUUID->"e610d8c5-4b4a-428a-a680-c317b850ca28"],
Cell[369377, 6727, 349, 8, 33, "Print",ExpressionUUID->"4ceaf803-b54c-451e-9c29-486351232df4"],
Cell[369729, 6737, 46228, 775, 235, "Print",ExpressionUUID->"a597b790-4361-4e89-8754-b30813626dff"],
Cell[415960, 7514, 382, 8, 33, "Print",ExpressionUUID->"efdbf6d0-254c-4d9b-9f37-6e23d8c789b9"],
Cell[416345, 7524, 8150, 153, 247, "Print",ExpressionUUID->"eafb8218-fabb-4a28-85c1-6defa511895a"],
Cell[424498, 7679, 544, 13, 22, "Print",ExpressionUUID->"a2260e71-0197-4880-942e-4d25ce03a99a"],
Cell[425045, 7694, 681, 18, 29, "Print",ExpressionUUID->"94c14829-2395-488a-8237-6e2b6f46d7e1"],
Cell[425729, 7714, 294, 5, 22, "Print",ExpressionUUID->"479b4216-1886-4c8f-96db-7c19bb703865"],
Cell[426026, 7721, 453, 12, 22, "Print",ExpressionUUID->"071cef7b-eddf-4249-bd08-4970ce5f2ef4"],
Cell[426482, 7735, 314, 7, 33, "Print",ExpressionUUID->"c50a16f9-4f43-4ebd-97b7-811284d43678"],
Cell[426799, 7744, 42442, 714, 225, "Print",ExpressionUUID->"46a201ea-c779-4653-9b19-35f10bfd4406"],
Cell[469244, 8460, 352, 8, 33, "Print",ExpressionUUID->"789421f0-d9c4-44cf-b556-afe14f82b086"],
Cell[469599, 8470, 39232, 660, 230, "Print",ExpressionUUID->"80a02ac4-e028-4192-91ac-d82813de05b0"],
Cell[508834, 9132, 382, 8, 33, "Print",ExpressionUUID->"ad09ed31-166e-434b-8e5c-699c6432c4a6"],
Cell[509219, 9142, 8291, 156, 247, "Print",ExpressionUUID->"55169f43-94af-4ff0-9db5-544ce4106e61"],
Cell[517513, 9300, 547, 13, 22, "Print",ExpressionUUID->"4575c609-f6b1-4166-ad80-d33bfd51fe9c"],
Cell[518063, 9315, 681, 18, 29, "Print",ExpressionUUID->"4bb434c8-70a6-4345-8c66-ce6accf471ac"],
Cell[518747, 9335, 294, 5, 22, "Print",ExpressionUUID->"3661b0c1-9524-4760-93fe-0deddd8eda9a"],
Cell[519044, 9342, 452, 12, 22, "Print",ExpressionUUID->"3014d857-f45f-4c9c-816b-7edd18dbcdaf"],
Cell[519499, 9356, 312, 7, 33, "Print",ExpressionUUID->"23912705-4a51-4602-88a9-b8fd8aa3cfc7"],
Cell[519814, 9365, 31214, 529, 225, "Print",ExpressionUUID->"224e6260-1d21-4985-b7f4-2a871f18b215"],
Cell[551031, 9896, 350, 8, 33, "Print",ExpressionUUID->"7872f8fa-56d7-4dac-be8e-9c6ff86968ee"],
Cell[551384, 9906, 29305, 498, 237, "Print",ExpressionUUID->"2986ec1f-448e-4340-a9cb-371f00932be0"],
Cell[580692, 10406, 384, 8, 33, "Print",ExpressionUUID->"bcecb256-8620-4961-9c4c-cbd53cc80855"],
Cell[581079, 10416, 8256, 155, 247, "Print",ExpressionUUID->"7210e408-3d04-4710-87e5-4256fb39068a"],
Cell[589338, 10573, 544, 13, 22, "Print",ExpressionUUID->"6ef0e694-86da-4231-b0be-445fce1423e0"],
Cell[589885, 10588, 679, 18, 29, "Print",ExpressionUUID->"689b97de-e320-4310-8f2a-31ce0a276d12"],
Cell[590567, 10608, 294, 5, 22, "Print",ExpressionUUID->"4a9a7d9a-ad43-49ea-9b1d-cbb397543401"],
Cell[590864, 10615, 476, 13, 22, "Print",ExpressionUUID->"a86196f0-1845-4123-8c8b-498a98598426"],
Cell[591343, 10630, 314, 7, 33, "Print",ExpressionUUID->"74f39b97-4aa5-40e7-a0d7-7e8b60c80aff"],
Cell[591660, 10639, 35636, 602, 224, "Print",ExpressionUUID->"7e9cc6b3-ec72-4b79-b435-8ee8b8bffb3c"],
Cell[627299, 11243, 352, 8, 33, "Print",ExpressionUUID->"c9c1569c-509f-4cb3-bc7c-f5a8108ddea0"],
Cell[627654, 11253, 33453, 566, 230, "Print",ExpressionUUID->"54a637b2-fddf-4bb4-92bb-ca6dcff6a4de"],
Cell[661110, 11821, 382, 8, 33, "Print",ExpressionUUID->"29b1c049-a792-48d2-b902-f64c26ef0534"],
Cell[661495, 11831, 8246, 155, 247, "Print",ExpressionUUID->"b4bd725b-eb7e-4d71-a30c-3f5c99c3f131"],
Cell[669744, 11988, 561, 13, 22, "Print",ExpressionUUID->"7ad03db4-e589-4ec7-8a4d-c352d5f607b0"],
Cell[670308, 12003, 322, 7, 33, "Print",ExpressionUUID->"a63c0342-f243-4f10-9589-028ab4afbdee"]
}, Open  ]],
Cell[670645, 12013, 879, 27, 164, "Output",ExpressionUUID->"b16f0e47-435f-4806-af89-f5177483490f"],
Cell[671527, 12042, 489, 10, 22, "Print",ExpressionUUID->"89b15424-f14d-4ac8-83cd-2c3845889fb7"]
}, Open  ]],
Cell[672031, 12055, 145, 3, 28, "Input",ExpressionUUID->"3c1a9fa9-bf44-4c35-8d0d-52c2851a5098"]
}, Open  ]]
}
]
*)

