(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     31907,        773]
NotebookOptionsPosition[     31325,        754]
NotebookOutlinePosition[     31723,        771]
CellTagsIndexPosition[     31680,        768]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Determination of the signs and magnitudes of all heteronuclear coupling using \
IPAP-MODO-FESTA data.
Automatically determine optimum ratio when combining IP and AP data, \
adjusting ratio and number of points to shift until rms difference is minimum\
\>", "Subsubsection",
 CellChangeTimes->{{3.835342719267295*^9, 3.8353427673607473`*^9}, {
   3.835342957217922*^9, 3.8353429845994587`*^9}, {3.853579885840021*^9, 
   3.853579910287277*^9}, 
   3.8535799927992496`*^9},ExpressionUUID->"e0dd5b4c-3a91-4051-9a25-\
a39ac98e766a"],

Cell["\<\
Automatically determines the optimum ratio when combining the IP and AP data, \
adjusts the ratio and numbers of points required to shift until the RMS \
difference is at its minimum.
Information required:
shifts={chemical shift in ppm}; (each chemical shift to be separated by a \
comma)
widths={width of multiplet in ppm}; (each width to be separated by a comma)
nreps=1; (number of repetitions of that data - typically 1)
filestart=12; (EXPNO in file)
filenamebase=\[CloseCurlyDoubleQuote]data/folder/nmr/filename/\
\[CloseCurlyDoubleQuote]; (filepath of data)
procnoIP=\[CloseCurlyDoubleQuote]1001\[CloseCurlyDoubleQuote];  (PROCNO of IP \
data)
procnoAP=\[CloseCurlyDoubleQuote]1002\[CloseCurlyDoubleQuote]; (PROCNO of AP \
data - ensure IP and AP are processed with identical parameters)
\
\>", "Text",
 CellChangeTimes->{{3.835344344114542*^9, 3.835344495255948*^9}, {
  3.835345752399667*^9, 3.83534578817225*^9}, {3.835416894520056*^9, 
  3.8354170090033817`*^9}, {3.8535743479833965`*^9, 3.8535743941759214`*^9}, {
  3.8535744245888777`*^9, 3.853574427182979*^9}, {3.8535799150722027`*^9, 
  3.8535802318062067`*^9}},ExpressionUUID->"c61c22a2-f7f7-4bd3-b074-\
cb3183ff65e0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"Context", "[", "]"}], " ", "<>", " ", "\"\<*\>\""}], "]"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"vardiff", "[", 
     RowBox[{"tspip_", ",", "tspap_", ",", 
      RowBox[{"ratio_", "?", "NumericQ"}], ",", 
      RowBox[{"diff_", "?", "NumericQ"}]}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"zspm", ",", "len"}], "}"}], ",", 
      RowBox[{
       RowBox[{"len", "=", 
        RowBox[{"Length", "[", "tspip", "]"}]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"zspm", "=", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "len"}], "}"}]}], "]"}], ",", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"tspip", "-", 
             RowBox[{"ratio", " ", "tspap"}]}], ",", 
            RowBox[{"Table", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "len"}], "}"}]}], "]"}]}], "]"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"Total", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"tspip", "+", 
           RowBox[{"ratio", " ", "tspap"}], "-", 
           RowBox[{"Take", "[", 
            RowBox[{
             RowBox[{"RotateRight", "[", 
              RowBox[{"zspm", ",", "diff"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"len", "+", "1"}], ",", 
               RowBox[{"2", " ", "len"}]}], "}"}]}], "]"}]}], ")"}], "^", 
         "2"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Calculate", " ", "variance", " ", "between", " ", "shifted", " ", 
    "spectra", " ", "obtained", " ", "by", " ", "IPAP", " ", "processing"}], 
   " ", "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"getpars", "[", 
    RowBox[{"filenamebase_", ",", "procno_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "filename", "}"}], ",", 
     RowBox[{
      RowBox[{"filename", "=", 
       RowBox[{
       "filenamebase", "<>", "\"\</pdata/\>\"", "<>", "procno", "<>", 
        "\"\</procs\>\""}]}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"stream", "=", 
       RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"offset", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<OFFSET= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"si", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<SI= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"filename", "=", 
       RowBox[{"filenamebase", "<>", "\"\</acqus\>\""}]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"stream", "=", 
       RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"sfo1", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<SFO1= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"swp", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<SW= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"offset", ",", "si", ",", "sfo1", ",", "swp"}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"process", "[", 
     RowBox[{
     "filenamebaseIP_", ",", "filenamebaseAP_", ",", "shift_", ",", "width_", 
      ",", "swp_", ",", "offset_", ",", "si_", ",", "sfo1_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "diff", ",", "dip", ",", "start", ",", "end", ",", "hzpp", ",", 
        "ncproc", ",", "spip", ",", "spap"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseIP", "<>", "\"\</procs\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"stream", "=", 
        RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ncproc", "=", 
        RowBox[{
         RowBox[{"Read", "[", 
          RowBox[{
           RowBox[{"StringToStream", "[", 
            RowBox[{"Find", "[", 
             RowBox[{"stream", ",", "\"\<NC_proc= \>\""}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Need", " ", "to", " ", "correct", " ", "for", " ", "any", " ", 
         "difference", " ", "in", " ", "scaling", " ", "during", " ", "FT", 
         " ", 
         RowBox[{"etc", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseIP", "<>", "\"\</1r\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"spip", "=", 
        RowBox[{
         RowBox[{"2.", "^", "ncproc"}], " ", 
         RowBox[{
          RowBox[{"Import", "[", 
           RowBox[{"filename", ",", "\"\<Integer32\>\""}], "]"}], "/", 
          RowBox[{"10", "^", "6"}]}]}]}], ";", " ", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseAP", "<>", "\"\</procs\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"stream", "=", 
        RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ncproc", "=", 
        RowBox[{
         RowBox[{"Read", "[", 
          RowBox[{
           RowBox[{"StringToStream", "[", 
            RowBox[{"Find", "[", 
             RowBox[{"stream", ",", "\"\<NC_proc= \>\""}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Need", " ", "to", " ", "correct", " ", "for", " ", "any", " ", 
         "difference", " ", "in", " ", "scaling", " ", "during", " ", "FT", 
         " ", 
         RowBox[{"etc", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseAP", "<>", "\"\</1r\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"spap", "=", 
        RowBox[{
         RowBox[{"2.", "^", "ncproc"}], " ", 
         RowBox[{
          RowBox[{"Import", "[", 
           RowBox[{"filename", ",", "\"\<Integer32\>\""}], "]"}], "/", 
          RowBox[{"10", "^", "6"}]}]}]}], ";", " ", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"hzpp", "=", 
        RowBox[{"swp", " ", 
         RowBox[{"sfo1", "/", 
          RowBox[{"(", 
           RowBox[{"si", "-", "1"}], ")"}]}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"start", "=", 
        RowBox[{"Round", "[", 
         RowBox[{"sfo1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"offset", "-", "shift", "-", 
             RowBox[{"width", "/", "2"}]}], ")"}], "/", "hzpp"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"end", "=", 
        RowBox[{"Round", "[", 
         RowBox[{"sfo1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"offset", "-", "shift", "+", 
             RowBox[{"width", "/", "2"}]}], ")"}], "/", "hzpp"}]}], " ", 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tspip", "=", 
        RowBox[{"Take", "[", 
         RowBox[{"spip", ",", 
          RowBox[{"{", 
           RowBox[{"start", ",", "end"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"len", "=", 
        RowBox[{"Length", "[", "tspip", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tspap", "=", 
        RowBox[{"Take", "[", 
         RowBox[{"spap", ",", 
          RowBox[{"{", 
           RowBox[{"start", ",", "end"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<Chemical shift = \>\"", ",", "\"\<Subsection\>\""}], 
          "]"}], ",", 
         RowBox[{"Style", "[", 
          RowBox[{"shift", ",", "\"\<Subsection\>\""}], "]"}], ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\< ppm\>\"", ",", "\"\<Subsection\>\""}], "]"}]}], "]"}],
        ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{
         "Do", " ", "optimistion", " ", "in", " ", "two", " ", "stages"}], 
         ",", " ", 
         RowBox[{
         "otherwise", " ", "fails", " ", "to", " ", "find", " ", "global", 
          " ", "minimum"}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"res1", "=", 
        RowBox[{"NMinimize", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"vardiff", "[", 
             RowBox[{"tspip", ",", "tspap", ",", "fratio", ",", 
              RowBox[{"5", " ", "fdiff"}]}], "]"}], ",", 
            RowBox[{"fdiff", ">", 
             RowBox[{
              RowBox[{"-", "len"}], "/", "5"}]}], ",", 
            RowBox[{"fdiff", "<", 
             RowBox[{"len", "/", "5"}]}], ",", 
            RowBox[{"fratio", ">", "0.8"}], ",", 
            RowBox[{"fratio", "<", "1.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"fdiff", "\[Element]", " ", "Integers"}], ",", "fratio"}],
            "}"}], ",", 
          RowBox[{"MaxIterations", "\[Rule]", "100"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"res2", "=", 
        RowBox[{"NMinimize", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"vardiff", "[", 
             RowBox[{
             "tspip", ",", "tspap", ",", "fratio", ",", " ", "fdiff"}], "]"}],
             ",", 
            RowBox[{"fratio", ">", "0.8"}], ",", 
            RowBox[{"fratio", "<", "1.2"}], ",", 
            RowBox[{"fdiff", ">", 
             RowBox[{
              RowBox[{"Round", "[", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"5", " ", "fdiff"}], "/.", 
                 RowBox[{"res1", "[", 
                  RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "]"}], "-", 
              RowBox[{"len", "/", "10"}]}]}], ",", 
            RowBox[{"fdiff", "<", 
             RowBox[{"Round", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"len", "/", "10"}], "+", 
                RowBox[{"5", " ", "fdiff"}]}], "/.", 
               RowBox[{"res1", "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"fdiff", "\[Element]", " ", "Integers"}], ",", "fratio"}],
            "}"}], ",", 
          RowBox[{"MaxIterations", "\[Rule]", "1000"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
       "Print", "[", "\"\<Variance and optimised shift and ratio:\>\"", "]"}],
        ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "res2", "]"}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{"ratio", "=", 
        RowBox[{"fratio", "/.", 
         RowBox[{"res2", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"spp", "=", 
        RowBox[{"tspip", "+", 
         RowBox[{"ratio", " ", "tspap"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"spm", "=", 
        RowBox[{"tspip", "-", 
         RowBox[{"ratio", " ", "tspap"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<Input data\>\"", ",", "\"\<Subsection\>\""}], "]"}], 
        "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"ListPlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"spp", ",", "spm"}], "}"}], ",", 
          RowBox[{"Joined", "\[Rule]", "True"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"len", "=", 
        RowBox[{"Length", "[", "spp", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"zspm", "=", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "len"}], "}"}]}], "]"}], ",", 
          RowBox[{"Join", "[", 
           RowBox[{"spm", ",", 
            RowBox[{"Table", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "len"}], "}"}]}], "]"}]}], "]"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"diff", "=", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{
             RowBox[{"2", " ", "len"}], "+", "1"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "\[LessEqual]", 
          RowBox[{"Length", "[", "diff", "]"}]}], ",", 
         RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"diff", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "=", 
           RowBox[{"Total", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"spp", "-", 
               RowBox[{"Take", "[", 
                RowBox[{
                 RowBox[{"RotateRight", "[", 
                  RowBox[{"zspm", ",", 
                   RowBox[{"len", "-", "i"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"len", "+", "1"}], ",", 
                   RowBox[{"2", " ", "len"}]}], "}"}]}], "]"}]}], ")"}], "^", 
             "2"}], "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\n", 
       RowBox[{"Print", "[", 
        RowBox[{"Style", "[", 
         RowBox[{
         "\"\<RMS difference vs displacement in data points\>\"", ",", 
          "\"\<Subsection\>\""}], "]"}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"ListPlot", "[", 
         RowBox[{"diff", ",", 
          RowBox[{"Joined", "\[Rule]", "True"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"min", "=", 
        RowBox[{"Min", "[", "diff", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "\[LessEqual]", 
          RowBox[{"Length", "[", "diff", "]"}]}], ",", 
         RowBox[{"i", "++"}], ",", " ", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"diff", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "\[Equal]", "min"}], ",", 
            RowBox[{"minpoint", "=", "i"}]}], "]"}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"Style", "[", 
         RowBox[{
         "\"\<Expansion of RMS difference vs displacement in data points, \
with parabolic fit\>\"", ",", "\"\<Subsection\>\""}], "]"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"dip", "=", 
        RowBox[{"Take", "[", 
         RowBox[{"diff", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"minpoint", "-", "10"}], ",", 
            RowBox[{"minpoint", "+", "10"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"dipfit", "=", 
        RowBox[{"NonlinearModelFit", "[", 
         RowBox[{"dip", ",", 
          RowBox[{"a", "+", 
           RowBox[{"b", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"x", "-", "x0"}], ")"}], "^", "2"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"a", ",", "b", ",", "x0"}], "}"}], ",", "x"}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"Show", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Plot", "[", 
            RowBox[{
             RowBox[{"dipfit", "[", "x", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", "1", ",", 
               RowBox[{"Length", "[", "dip", "]"}]}], "}"}], ",", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"All", ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", 
                  RowBox[{"1.1", " ", 
                   RowBox[{"Max", "[", "dip", "]"}]}]}], "}"}]}], "}"}]}]}], 
            "]"}], ",", 
           RowBox[{"ListPlot", "[", 
            RowBox[{"dip", ",", 
             RowBox[{"Joined", "\[Rule]", "False"}], ",", 
             RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "}"}], "]"}],
         "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<Interpolated frequency shift with best match is \>\"", ",", 
         RowBox[{
          RowBox[{"-", "hzpp"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"x0", "/.", 
              RowBox[{"dipfit", "[", "\"\<BestFitParameters\>\"", "]"}]}], 
             ")"}], "+", "minpoint", "-", "11", "-", "len"}], ")"}]}], ",", 
         " ", "\"\< Hz\>\""}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"-", "hzpp"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"x0", "/.", 
            RowBox[{"dipfit", "[", "\"\<BestFitParameters\>\"", "]"}]}], 
           ")"}], "+", "minpoint", "-", "11", "-", "len"}], ")"}]}]}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"shifts", "=", 
   RowBox[{"{", "5.4092", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"widths", "=", 
   RowBox[{"{", "0.3", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"njs", "=", 
   RowBox[{"Length", "[", "shifts", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nreps", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"filestart", "=", "12"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"js", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", "njs", ",", "nreps"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"filenamebase", "=", "\"\<W:/FILEPATH/\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"procnoIP", "=", "\"\<1001\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"procnoAP", "=", "\"\<1002\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"getpars", "[", 
   RowBox[{
    RowBox[{"filenamebase", "<>", 
     RowBox[{"ToString", "[", "filestart", "]"}]}], ",", "procnoIP"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"starttime", "=", 
   RowBox[{"AbsoluteTime", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"jnumber", "=", "1"}], ",", 
    RowBox[{"jnumber", "\[LessEqual]", 
     RowBox[{"Length", "[", "shifts", "]"}]}], ",", 
    RowBox[{"jnumber", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"rep", "=", "1"}], ",", 
       RowBox[{"rep", "\[LessEqual]", "nreps"}], ",", 
       RowBox[{"rep", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"filename", "=", 
         RowBox[{"filenamebase", "<>", 
          RowBox[{"ToString", "[", 
           RowBox[{"filestart", "+", "rep", "-", "1"}], "]"}], "<>", 
          "\"\</pdata/\>\""}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"js", "[", 
          RowBox[{"[", 
           RowBox[{"jnumber", ",", "rep"}], "]"}], "]"}], "=", 
         RowBox[{"process", "[", 
          RowBox[{
           RowBox[{"filename", "<>", "procnoIP"}], ",", 
           RowBox[{"filename", "<>", "procnoAP"}], ",", 
           RowBox[{"shifts", "[", 
            RowBox[{"[", "jnumber", "]"}], "]"}], ",", 
           RowBox[{"widths", "[", 
            RowBox[{"[", "jnumber", "]"}], "]"}], ",", "swp", ",", "offset", 
           ",", "si", ",", "sfo1"}], "]"}]}], ";"}]}], "\[IndentingNewLine]", 
      "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"Style", "[", 
    RowBox[{"\"\<Coupling constants\>\"", ",", "\"\<Subsection\>\""}], "]"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"TableForm", "[", "js", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"jslb1", "=", "js"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"timeused", "=", 
   RowBox[{
    RowBox[{"AbsoluteTime", "[", "]"}], "-", "starttime"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<Time used = \>\"", ",", "timeused", ",", "\"\<seconds\>\""}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"meansdandsdmean", "[", "x_", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Mean", "[", "x", "]"}], ",", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"Variance", "[", "x", "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Length", "[", "x", "]"}], "-", "1"}], ")"}], ")"}]}], 
      "]"}], ",", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"Variance", "[", "x", "]"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Length", "[", "x", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Length", "[", "x", "]"}], "-", "1"}], ")"}]}], ")"}]}], 
      "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"nreps", ">", "1"}], ",", 
    RowBox[{
     RowBox[{"reslb1", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"Length", "[", "shifts", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"reslb1", "=", 
      RowBox[{"Prepend", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"shifts", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"meansdandsdmean", "[", 
              RowBox[{"jslb1", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Length", "[", "shifts", "]"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Shift / ppm\>\"", ",", "\"\<JHF / Hz\>\"", ",", 
          "\"\<std dev / Hz\>\"", ",", "\"\<sd of mean of J / Hz\>\""}], 
         "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"TableForm", "[", "reslb1", "]"}], "]"}], ";"}]}], "]"}], 
  "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.833448292510956*^9, 3.833448473320225*^9}, {
   3.833448567630739*^9, 3.833448597926832*^9}, {3.833448726706624*^9, 
   3.8334488386106873`*^9}, {3.833448894130322*^9, 3.83344899381962*^9}, {
   3.8334490263559*^9, 3.833449034371501*^9}, {3.833449208176523*^9, 
   3.83344924369489*^9}, {3.8334515420085583`*^9, 3.833451676813837*^9}, {
   3.8335325651614*^9, 3.833532637209276*^9}, {3.833532759034121*^9, 
   3.8335330239765873`*^9}, {3.8335330927635307`*^9, 
   3.8335331455943604`*^9}, {3.833533397697961*^9, 3.8335334255106373`*^9}, {
   3.8335334594455547`*^9, 3.833533507765386*^9}, {3.833533539339788*^9, 
   3.833533659575992*^9}, {3.833533697198904*^9, 3.8335337340891523`*^9}, {
   3.833533780205265*^9, 3.833533893496993*^9}, 3.833533985781467*^9, {
   3.8335340192182083`*^9, 3.833534070521394*^9}, {3.833534125296022*^9, 
   3.833534125914562*^9}, 3.833534226165428*^9, {3.833534380477125*^9, 
   3.833534380818433*^9}, {3.8335344656134453`*^9, 3.833534519575261*^9}, {
   3.8335346317293777`*^9, 3.83353463272573*^9}, 3.8335347268726482`*^9, {
   3.8335347781741343`*^9, 3.83353485994346*^9}, {3.833534904539554*^9, 
   3.83353494839614*^9}, {3.833534999551011*^9, 3.833534999698493*^9}, {
   3.833535037301165*^9, 3.833535103927022*^9}, {3.8335351368517733`*^9, 
   3.833535139414091*^9}, {3.8335352378369083`*^9, 3.833535337311174*^9}, {
   3.833535394550235*^9, 3.833535454170685*^9}, {3.8335361679797087`*^9, 
   3.8335362375090513`*^9}, {3.833536274111115*^9, 3.833536278469448*^9}, 
   3.833536449477241*^9, {3.8335364826240788`*^9, 3.8335365448917313`*^9}, {
   3.833538035225528*^9, 3.833538077529106*^9}, {3.8337034631307096`*^9, 
   3.833703463865309*^9}, {3.833703506926898*^9, 3.833703553753542*^9}, {
   3.833703617125688*^9, 3.833703688345792*^9}, {3.833703718670663*^9, 
   3.8337037764894876`*^9}, {3.8337038223632317`*^9, 
   3.8337039123907833`*^9}, {3.83370394998801*^9, 3.833704007351994*^9}, {
   3.833704056375489*^9, 3.833704136756112*^9}, {3.833704176289364*^9, 
   3.833704289758876*^9}, {3.833704391066206*^9, 3.833704429891245*^9}, {
   3.833704972721045*^9, 3.8337049956209497`*^9}, {3.8337050367076*^9, 
   3.833705038457287*^9}, {3.8337053194184847`*^9, 3.833705411458173*^9}, {
   3.8337070792528667`*^9, 3.833707127605337*^9}, {3.835337695095479*^9, 
   3.835337749538929*^9}, {3.835338577798208*^9, 3.835338620041452*^9}, {
   3.835338653990897*^9, 3.835338823765335*^9}, {3.835338865410541*^9, 
   3.835338962622757*^9}, {3.83533899622244*^9, 3.8353390024553337`*^9}, {
   3.835339165977964*^9, 3.835339170838904*^9}, {3.835339226586821*^9, 
   3.835339252159419*^9}, {3.8353394292671547`*^9, 3.835339457784766*^9}, {
   3.835339500275881*^9, 3.8353395120074873`*^9}, 3.8353400097312202`*^9, {
   3.835340043255178*^9, 3.835340049105363*^9}, {3.835340320155546*^9, 
   3.8353403214856653`*^9}, {3.8353429884303017`*^9, 3.835343088575757*^9}, {
   3.835343169936596*^9, 3.83534322437465*^9}, {3.835343746121127*^9, 
   3.8353437642293177`*^9}, {3.8353445222541227`*^9, 3.835344552148288*^9}, {
   3.835344620203895*^9, 3.835344716850436*^9}, {3.835344824168634*^9, 
   3.835344832897682*^9}, {3.835344894608045*^9, 3.835344999609126*^9}, {
   3.8353450692229977`*^9, 3.835345143285017*^9}, {3.835345243601369*^9, 
   3.835345244855967*^9}, 3.8353452928938713`*^9, {3.835345339394802*^9, 
   3.835345341993548*^9}, {3.835345390387436*^9, 3.835345394595192*^9}, 
   3.835345505879159*^9, {3.835345633336461*^9, 3.835345726337473*^9}, {
   3.8353458377226467`*^9, 3.835345843828887*^9}, {3.835372061030136*^9, 
   3.835372071264954*^9}, {3.835372109388467*^9, 3.83537218434414*^9}, 
   3.835372522290762*^9, {3.8354170700934362`*^9, 3.835417083829755*^9}, {
   3.835417167922065*^9, 3.835417196326001*^9}, {3.835418223179352*^9, 
   3.835418229883106*^9}, {3.835418393819128*^9, 3.835418488516716*^9}, {
   3.835418519132303*^9, 3.835418537842663*^9}, {3.83542543494832*^9, 
   3.835425472964828*^9}, 3.8354255498612223`*^9, {3.835425690259713*^9, 
   3.83542571399114*^9}, {3.835431541550761*^9, 3.835431541640277*^9}, {
   3.852979611453643*^9, 3.852979691319852*^9}, {3.8529797654116774`*^9, 
   3.852979781170024*^9}, {3.852979821986277*^9, 3.8529798368790913`*^9}, 
   3.852982940810091*^9, {3.8535786610591493`*^9, 3.853578743107206*^9}, {
   3.8535791499440546`*^9, 3.853579151302937*^9}, 3.8535799422709336`*^9, {
   3.853584626138847*^9, 3.8535846264724474`*^9}, {3.8677419189889865`*^9, 
   3.867741920007409*^9}},ExpressionUUID->"83ce1c8d-1a22-4fa3-84c9-\
6c6be868c2d5"]
}, Open  ]]
},
WindowSize->{2560, 1357},
WindowMargins->{{-8, Automatic}, {Automatic, -8}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"12.0 for Microsoft Windows (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 538, 10, 69, "Subsubsection",ExpressionUUID->"e0dd5b4c-3a91-4051-9a25-a39ac98e766a"],
Cell[1121, 34, 1194, 23, 232, "Text",ExpressionUUID->"c61c22a2-f7f7-4bd3-b074-cb3183ff65e0"],
Cell[2318, 59, 28991, 692, 1872, "Input",ExpressionUUID->"83ce1c8d-1a22-4fa3-84c9-6c6be868c2d5"]
}, Open  ]]
}
]
*)

